@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _accessmanager.py
 #
 # $Id: _accessmanager.py,v 1.11 2004/10/04 19:57:06 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
@@ -35,18 +35,18 @@ import urllib
 import _globals
 
 
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _accessmanager.user_folder_meta_types:
 #
 #  User Folder Meta-Types.
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 user_folder_meta_types = ['LDAPUserFolder','User Folder','Simple User Folder']
 
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _accessmanager.role_defs:
 #
 #  Role Definitions.
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 role_defs = {
    'ZMSAdministrator':{}
   ,'ZMSEditor':{'revoke':['Change DTML Methods','ZMS Administrator','ZMS UserAdministrator']}
@@ -55,9 +55,9 @@ role_defs = {
   ,'ZMSUserAdministrator':{'revoke':['Change DTML Methods','Import/Export objects','ZMS Administrator','ZMS Author']}
 }
 
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _accessmanager.getUserId:
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getUserId(user):
   if type(user) is dict:
     user = user['__id__']
@@ -65,11 +65,11 @@ def getUserId(user):
     user = user.getId()
   return user
 
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _accessmanager.role_permissions:
 #
 #  Role Permissions.
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def role_permissions(self, role):
   permissions = map(lambda x: x['name'],self.permissionsOfRole('Manager'))
   if role_defs.has_key(role):
@@ -82,13 +82,12 @@ def role_permissions(self, role):
       permissions = role_def['grant']
   return permissions
 
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _accessmanager.insertUser:
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def insertUser(self, newId, newPassword, newEmail, REQUEST):
   id = ''
   lang = REQUEST['lang']
-  manage_lang = REQUEST['manage_lang']
   userFldr = self.getUserFolder()
   
   # Init user.
@@ -106,12 +105,11 @@ def insertUser(self, newId, newPassword, newEmail, REQUEST):
 
   return id
 
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _accessmanager.deleteUser:
-# -------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def deleteUser(self, id, REQUEST):
   lang = REQUEST['lang']
-  manage_lang = REQUEST['manage_lang']
   userFldr = self.getUserFolder()
   
   userObj = userFldr.getUser(id)
@@ -135,18 +133,18 @@ def deleteUser(self, id, REQUEST):
   return id
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   C l a s s   A c c e s s a b l e O b j e c t
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class AccessableObject: 
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableObject.getUsers:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getUsers(self, REQUEST):
       users = {}
       d = self.getConfProperty('ZMS.security.users',{})
@@ -157,40 +155,36 @@ class AccessableObject:
           users[ user] = {'roles':roles,'langs':langs}
       return users
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableObject.hasAccess:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def hasAccess(self, REQUEST):
       access = True
       auth_user = REQUEST.get('AUTHENTICATED_USER')
-      if REQUEST.get('URL','/manage').find('/manage') >= 0:
+      url = REQUEST.get('URL','/manage')
+      url = url[url.rfind('/'):]
+      if url.find('/manage') >= 0:
         if access:
-          rights = self.getObjProperty( 'attr_dc_accessrights', REQUEST)
+          rights = self.getObjProperty( 'attr_dc_accessrights_restrictededitors', REQUEST)
           if type( rights) is list and len( rights) > 0:
-            access = False
-            for right in self.getObjProperty('attr_dc_accessrights', REQUEST):
+            roles = auth_user.getRolesInContext(self)
+            access = len( filter( lambda x: x in roles, rights)) > 0
+            for right in rights:
               access = access or auth_user.has_role( right)
               access = access or auth_user.has_permission( right, self)
         if access and self.meta_type == 'ZMSCustom':
-          ob = self.getMetaobj( self.meta_id)
-          access = access and ((ob.get( 'access') is None) or (len( self.intersection_list( self.concat_list( ob.get( 'access').get( 'edit'), [ 'Manager']), self.getUserRoles(auth_user))) > 0))
-        access = access and auth_user.has_permission('ZMS Author', self)
+          ob_access = self.getObjProperty('manage_access',REQUEST)
+          access = access and ((not type(ob_access) is dict) or (ob_access.get( 'edit') is None) or (len( self.intersection_list( self.concat_list( ob_access.get( 'edit'), [ 'Manager']), self.getUserRoles(auth_user))) > 0))
+        access = access and auth_user.has_permission( 'ZMS Author', self) in [ 1, True]
       else:
-        if access:
-          has_access = self.getObjProperty( 'attr_has_access', REQUEST)
-          if has_access == 0:
-            has_access = False
-          elif has_access == 1:
-            has_access = True
-          if has_access in [ True, False]:
-            access = access and has_access
-        if access:
-          access = access and auth_user.has_permission( 'View', self)
+        access = access and auth_user.has_permission( 'View', self) in [ 1, True]
+        if not access:
+          access = access or self.hasPublicAccess() 
       return access
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableObject.getUserRoles:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getUserRoles(self, userObj, aq_parent=1):
       roles = []
       try:
@@ -212,9 +206,9 @@ class AccessableObject:
           ob = None
       return roles
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableObject.getUserLangs:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getUserLangs(self, userObj, aq_parent=1):
       langs = []
       try:
@@ -236,47 +230,53 @@ class AccessableObject:
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
-    ###   P u b l i c   A c c e s s   ( S u b s c r i b e r s )
+    ###   Public Access (Subscribers)
     ###
-    ###############################################################################################
+    ############################################################################
     """
     
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableObject.viewPermission:
     #
     #  Raises exception.
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     viewPermission__roles__ = ['ZMSAdministrator','ZMSEditor','ZMSAuthor','ZMSSubscriber']
     def viewPermission(self): pass
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableObject.hasRestrictedAccess:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def hasRestrictedAccess(self):
-      if 'attr_has_subscriber' in self.getObjAttrs().keys():
+      restricted = False
+      if 'attr_dc_accessrights_restricted' in self.getObjAttrs().keys():
         req = {'lang':self.getPrimaryLanguage()}
-        return self.getObjProperty('attr_has_subscriber',req) in [ 1, True]
-      return False
+        restricted = restricted or self.getObjProperty( 'attr_dc_accessrights_restricted', req) in [ 1, True]
+      return restricted
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableObject.hasPublicAccess:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def hasPublicAccess(self):
-      has_public_access = not self.hasRestrictedAccess()
+      if 'attr_dc_accessrights_public' in self.getObjAttrs().keys():
+        req = {'lang':self.getPrimaryLanguage()}
+        if self.getObjProperty( 'attr_dc_accessrights_public', req) in [ 1, True]:
+          return True
+      public = not self.hasRestrictedAccess()
       parent = self.getParentNode()
       if parent is not None and isinstance( parent, AccessableObject):
-        has_public_access = has_public_access and parent.hasPublicAccess()
-      return has_public_access
+        public = public and parent.hasPublicAccess()
+      return public
 
-    # --------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableObject.synchronizePublicAccess:
-    # --------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def synchronizePublicAccess(self):
-      # This is ugly, but necessary since ZMSObject is inherited from AccessableObject and 
-      # ZMSContainerObject is inherited from AccessableContainer!
-      restricted = False
+      # This is ugly, but necessary since ZMSObject is inherited from 
+      # AccessableObject and ZMSContainerObject is inherited from 
+      # AccessableContainer!
+      restricted = self.hasRestrictedAccess()
       if self.meta_type == 'ZMSLinkElement' and self.isEmbedded( self.REQUEST):
         ob = self.getRefObj()
         if ob is not None:
@@ -286,7 +286,6 @@ class AccessableObject:
               break
       else:
         ob = self
-        restricted = restricted or self.hasRestrictedAccess()
       if isinstance( ob, AccessableContainer):
         if restricted:
           self.revokePublicAccess()
@@ -295,52 +294,59 @@ class AccessableObject:
       
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###   P r o p e r t i e s
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
-    ###############################################################################################
+    ############################################################################
     #  AccessableObject.manage_user:
     #
     #  Change user.
-    ###############################################################################################
+    ############################################################################
     manage_userForm = HTMLFile('dtml/zms/manage_user', globals())
-    def manage_user(self, btn, lang, manage_lang, REQUEST, RESPONSE):
+    def manage_user(self, btn, lang, REQUEST, RESPONSE):
       """ AccessManager.manage_user """
       message = ''
       
       # Change.
       # -------
-      if btn == self.getLangStr('BTN_CHANGE',manage_lang):
-        userObj = self.findUser(getUserId(REQUEST['AUTHENTICATED_USER']))
+      if btn == self.getZMILangStr('BTN_CHANGE'):
+        id = getUserId(REQUEST['AUTHENTICATED_USER'])
+        userObj = self.findUser(id)
         password = REQUEST.get('password','******')
         confirm = REQUEST.get('confirm','')
         if password!='******' and password==confirm:
-           userObj.__ = password
+          try:
+            userFldr = self.getUserFolder()
+            roles = userObj.getRoles()
+            domains = userObj.getDomains()
+            userFldr.userFolderEditUser(id, password, roles, domains)
+          except: 
+            _globals.writeException(self,'[manage_user]: can\'t change password')
         self.setUserAttr(userObj,'email',REQUEST.get('email','').strip())
         #-- Assemble message.
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_userForm?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(lang,manage_lang,message))
+      return RESPONSE.redirect('manage_userForm?lang=%s&manage_tabs_message=%s'%(lang,message))
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   C l a s s   A c c e s s a b l e C o n t a i n e r
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class AccessableContainer(AccessableObject): 
     
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableContainer.restrictAccess:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def restrictAccess(self):
       for lang in self.getLangIds():
         for key in ['index_%s.html','index_print_%s.html','search_%s.html','sitemap_%s.html']:
@@ -351,9 +357,9 @@ class AccessableContainer(AccessableObject):
             for role in ['Manager']: 
               ob.manage_role(role_to_manage=role,permissions=role_permissions(ob,role))
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableContainer.grantPublicAccess:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def grantPublicAccess(self):
       self.restrictAccess()
       self.manage_acquiredPermissions(role_permissions(self,'Manager'))
@@ -369,9 +375,9 @@ class AccessableContainer(AccessableObject):
       self.manage_role(role_to_manage='Anonymous',permissions=permissions)
       self.manage_role(role_to_manage='Authenticated',permissions=permissions)
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessableContainer.revokePublicAccess:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def revokePublicAccess(self):
       self.restrictAccess()
       self.manage_acquiredPermissions([])
@@ -383,18 +389,18 @@ class AccessableContainer(AccessableObject):
       self.manage_role(role_to_manage='Authenticated',permissions=permissions)
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   C l a s s   A c c e s s M a n a g e r
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class AccessManager(AccessableContainer): 
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.getValidUserids:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getValidUserids(self):
       valid_userids = []
       for userFldr in self.getUserFolders():
@@ -409,9 +415,9 @@ class AccessManager(AccessableContainer):
               valid_userids.append({'localUserFldr':userFldr,'name':userName})
       return valid_userids
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.setUserAttr:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def setUserAttr(self, user, name, value):
       user = getUserId(user)
       d = self.getConfProperty('ZMS.security.users',{})
@@ -420,9 +426,9 @@ class AccessManager(AccessableContainer):
       d[user] = i.copy()
       self.setConfProperty('ZMS.security.users',d.copy())
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.getLDAPUserAttr:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLDAPUserAttr(self, user, name):
       user = getUserId(user)
       userFldr = self.getUserFolder()
@@ -439,9 +445,9 @@ class AccessManager(AccessableContainer):
                 return value
       return None
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.getUserAttr:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getUserAttr(self, user, name, default, flag=0):
       user = getUserId(user)
       if name not in [ 'nodes']:
@@ -472,9 +478,9 @@ class AccessManager(AccessableContainer):
               v[newNode] = w[node]
       return v
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.delUserAttr:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def delUserAttr(self, user):
       user = getUserId(user)
       d = self.getConfProperty('ZMS.security.users',{})
@@ -484,11 +490,11 @@ class AccessManager(AccessableContainer):
       except:
         _globals.writeException(self,'[delUserAttr]: user=%s not deleted!'%user)
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.initRoleDefs:
     #
     #  Init Role-Definitions and Permission Settings
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def initRoleDefs(self):
     
       # Init Roles.
@@ -506,9 +512,9 @@ class AccessManager(AccessableContainer):
       self.synchronizePublicAccess()
 
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.findUser:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def findUser(self, name):
       for userFldr in self.getUserFolders():
         userObj = None
@@ -523,9 +529,9 @@ class AccessManager(AccessableContainer):
           return userObj
       return None
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.getUserFolder:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getUserFolder(self):
       homeElmnt = self.getHome()
       userFldrs = homeElmnt.objectValues(user_folder_meta_types)
@@ -541,9 +547,9 @@ class AccessManager(AccessableContainer):
       return userFldr
 
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.getUserFolders:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getUserFolders(self):
       userFolders = []
       ob = self
@@ -562,16 +568,16 @@ class AccessManager(AccessableContainer):
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###   L o c a l   U s e r s
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.setLocalUser:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def setLocalUser(self, id, node, roles, langs):
       #-- Insert node to user-properties.
       nodes = self.getUserAttr(id,'nodes',{})
@@ -588,9 +594,9 @@ class AccessManager(AccessableContainer):
         _globals.writeException(self,'[setLocalUser]: node=%s does not exist!'%node)
 
 
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  AccessManager.delLocalUser:
-    # -------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def delLocalUser(self, id, node):
       #-- Delete node from user-properties.
       nodes = self.getUserAttr(id,'nodes',{})
@@ -606,30 +612,31 @@ class AccessManager(AccessableContainer):
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###   P r o p e r t i e s
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
     # Management Interface.
     # ---------------------
     manage_users = HTMLFile('dtml/zms/manage_users', globals())
+    manage_users_sitemap = HTMLFile('dtml/zms/manage_users_sitemap', globals())
 
-    ###############################################################################################
+    ############################################################################
     #  AccessManager.manage_roleProperties:
     #
     #  Change or delete roles.
-    ###############################################################################################
-    def manage_roleProperties(self, btn, key, lang, manage_lang, REQUEST, RESPONSE=None):
+    ############################################################################
+    def manage_roleProperties(self, btn, key, lang, REQUEST, RESPONSE=None):
       """ AccessManager.manage_roleProperties """
       message = ''
       id = REQUEST.get('id','')
       
       # Insert.
       # -------
-      if btn == self.getLangStr('BTN_INSERT',manage_lang):
+      if btn == self.getZMILangStr('BTN_INSERT'):
         if key=='obj':
           #-- Add local role.
           id = REQUEST.get('newId').strip()
@@ -640,7 +647,7 @@ class AccessManager(AccessableContainer):
           security_roles = security_roles.copy()
           self.setConfProperty('ZMS.security.roles',security_roles)
           #-- Assemble message.
-          message = self.getLangStr('MSG_INSERTED',manage_lang)%self.getLangStr('ATTR_ROLE',manage_lang)
+          message = self.getZMILangStr('MSG_INSERTED')%self.getZMILangStr('ATTR_ROLE')
         elif key=='attr':
           #-- Insert node to config-properties.
           node = REQUEST.get('node')
@@ -659,11 +666,11 @@ class AccessManager(AccessableContainer):
             permissions = ob.concat_list(permissions,role_permissions(self,role.replace(' ','')))
           ob.manage_role(role_to_manage=id,permissions=permissions)
           #-- Assemble message.
-          message = self.getLangStr('MSG_INSERTED',manage_lang)%self.getLangStr('ATTR_NODE',manage_lang)
+          message = self.getZMILangStr('MSG_INSERTED')%self.getZMILangStr('ATTR_NODE')
       
       # Delete.
       # -------
-      elif btn in ['delete', self.getLangStr('BTN_DELETE',manage_lang)]:
+      elif btn in ['delete', self.getZMILangStr('BTN_DELETE')]:
         if key=='obj':
           #-- Delete local role.
           self._delRoles(roles=[id],REQUEST=REQUEST)
@@ -688,32 +695,32 @@ class AccessManager(AccessableContainer):
           if ob is not None:
             ob.manage_role(role_to_manage=id,permissions=permissions)
         #-- Assemble message.
-        message = self.getLangStr('MSG_DELETED',manage_lang)%int(1)
+        message = self.getZMILangStr('MSG_DELETED')%int(1)
       
       # Return with message.
       if RESPONSE:
         message = urllib.quote(message)
-        return RESPONSE.redirect('manage_users?lang=%s&manage_lang=%s&manage_tabs_message=%s&id=%s'%(lang,manage_lang,message,id))
+        return RESPONSE.redirect('manage_users?lang=%s&manage_tabs_message=%s&id=%s'%(lang,message,id))
 
 
-    ###############################################################################################
+    ############################################################################
     #  AccessManager.manage_userProperties:
     #
     #  Change or delete users.
-    ###############################################################################################
-    def manage_userProperties(self, btn, key, lang, manage_lang, REQUEST, RESPONSE=None):
+    ############################################################################
+    def manage_userProperties(self, btn, key, lang, REQUEST, RESPONSE=None):
       """ AccessManager.manage_userProperties """
       message = ''
       id = REQUEST.get('id','')
       
       # Cancel.
       # -------
-      if btn in [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]:
+      if btn in [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]:
         id = ''
 
       # Insert.
       # -------
-      if btn == self.getLangStr('BTN_INSERT',manage_lang):
+      if btn == self.getZMILangStr('BTN_INSERT'):
         if key=='obj':
           #-- Insert user.
           newId = REQUEST.get('newId','').strip()
@@ -722,7 +729,7 @@ class AccessManager(AccessableContainer):
           newEmail = REQUEST.get('newEmail','').strip()
           id = insertUser(self,newId,newPassword,newEmail,REQUEST)
           #-- Assemble message.
-          message = self.getLangStr('MSG_INSERTED',manage_lang)%self.getLangStr('ATTR_USER',manage_lang)
+          message = self.getZMILangStr('MSG_INSERTED')%self.getZMILangStr('ATTR_USER')
         elif key=='attr':
           #-- Insert local user.
           langs = REQUEST.get('langs',[])
@@ -735,32 +742,38 @@ class AccessManager(AccessableContainer):
           node = docElmnt.getRefObjPath(ob)
           docElmnt.setLocalUser(id, node, roles, langs)
           #-- Assemble message.
-          message = self.getLangStr('MSG_INSERTED',manage_lang)%self.getLangStr('ATTR_NODE',manage_lang)
+          message = self.getZMILangStr('MSG_INSERTED')%self.getZMILangStr('ATTR_NODE')
       
       # Change.
       # -------
-      elif btn == self.getLangStr('BTN_CHANGE',manage_lang):
+      elif btn == self.getZMILangStr('BTN_CHANGE'):
         userObj = self.findUser(id)
         if key=='obj':
           password = REQUEST.get('password','******')
           confirm = REQUEST.get('confirm','')
           if password!='******' and password==confirm:
-             userObj.__ = password
+            try:
+              userFldr = self.getUserFolder()
+              roles = userObj.getRoles()
+              domains = userObj.getDomains()
+              userFldr.userFolderEditUser(id, password, roles, domains)
+            except: 
+              _globals.writeException(self,'[manage_user]: can\'t change password')
           self.setUserAttr(userObj,'email',REQUEST.get('email','').strip())
           self.setUserAttr(userObj,'profile',REQUEST.get('profile','').strip())
         elif key=='attr':
           pass
         #-- Assemble message.
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       # Delete.
       # -------
-      elif btn in ['delete', self.getLangStr('BTN_DELETE',manage_lang)]:
+      elif btn in ['delete', self.getZMILangStr('BTN_DELETE')]:
         if key=='obj':
           #-- Delete user.
           id = deleteUser(self,id,REQUEST)
           #-- Assemble message.
-          message = self.getLangStr('MSG_DELETED',manage_lang)%int(1)
+          message = self.getZMILangStr('MSG_DELETED')%int(1)
         elif key=='attr':
           #-- Delete local user.
           node = REQUEST.get('nodekey')
@@ -778,11 +791,11 @@ class AccessManager(AccessableContainer):
           except:
             pass
           #-- Assemble message.
-          message = self.getLangStr('MSG_DELETED',manage_lang)%int(1)
+          message = self.getZMILangStr('MSG_DELETED')%int(1)
       
       # Invite.
       # -------
-      elif btn == self.getLangStr('BTN_INVITE',manage_lang):
+      elif btn == self.getZMILangStr('BTN_INVITE'):
         if key=='obj':
           email = self.getUserAttr(id,'email','')
           nodekeys = REQUEST.get('nodekeys',[])
@@ -796,17 +809,13 @@ class AccessManager(AccessableContainer):
             mbody = []
             mbody.append(self.getTitle(REQUEST)+' '+self.getHref2IndexHtml(REQUEST))
             mbody.append('\n')
-            mbody.append('\n%s: %s'%(self.getLangStr('ATTR_ID',manage_lang),id))
-            try:
-              mbody.append('\n%s: %s'%(self.getLangStr('ATTR_PASSWORD',manage_lang),userObj._getPassword()))
-            except:
-              pass
+            mbody.append('\n%s: %s'%(self.getZMILangStr('ATTR_ID'),id))
             mbody.append('\n')
             for nodekey in nodekeys:
               ob = self.getLinkObj(nodekey,REQUEST)
               mbody.append('\n * '+ob.getTitlealt(REQUEST)+' ['+ob.display_type(REQUEST)+']: '+ob.absolute_url()+'/manage')
             mbody.append('\n')
-            mbody.append('\n' + self.getLangStr('WITH_BEST_REGARDS',manage_lang))
+            mbody.append('\n' + self.getZMILangStr('WITH_BEST_REGARDS'))
             mbody.append('\n' + str(REQUEST['AUTHENTICATED_USER']))
             mbody.append('\n-------------------------------')
             mbody = ''.join(mbody)
@@ -815,11 +824,11 @@ class AccessManager(AccessableContainer):
             #-- Send
             self.sendMail(mto,msubject,mbody,REQUEST)
             #-- Assemble message.
-            message = self.getLangStr('MSG_CHANGED',manage_lang)
+            message = self.getZMILangStr('MSG_CHANGED')
 
       # Return with message.
       if RESPONSE:
         message = urllib.quote(message)
-        return RESPONSE.redirect('manage_users?lang=%s&manage_lang=%s&manage_tabs_message=%s&id=%s'%(lang,manage_lang,message,id))
+        return RESPONSE.redirect('manage_users?lang=%s&manage_tabs_message=%s&id=%s'%(lang,message,id))
 
-###################################################################################################
\ No newline at end of file
+################################################################################
