@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _blobfields.py
 #
 # $Id: _blobfields.py,v 1.10 2004/11/30 20:03:16 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
@@ -39,83 +39,107 @@ import _globals
 import _mimetypes
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.StringType:
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 StringType=type('')
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.hex2bin:
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def hex2bin(m):
   return ''.join(map(lambda x: chr(16*int('0x%s'%m[x*2],0)+int('0x%s'%m[x*2+1],0)),range(len(m)/2)))
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.bin2hex:
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def bin2hex(m):
   return ''.join(map(lambda x: hex(ord(x)/16)[-1]+hex(ord(x)%16)[-1],m))
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.recurse_downloadRessources:
 #
 #  Download from ZODB to file-system during Export.
-# ----------------------------------------------------------------------------------------------
-def recurse_downloadRessources(self, base, folder='.', deep=True):
+# ------------------------------------------------------------------------------
+def recurse_downloadRessources(self, base_path, REQUEST, incl_embedded):
+  # Check Constraints.
+  root = getattr( self, '__root__', None)
+  if root is not None or self.meta_type == 'ZMSTrashcan':
+    return []
+  ob = self
+  if ob.meta_type != 'ZMS':
+    base_path += self.id + '/'
+  if ob.meta_type == 'ZMSLinkElement' and ob.isEmbedded( REQUEST) and incl_embedded:
+    ob = ob.getRefObj()
   ressources = []
-  obj_attrs = self.getObjAttrs()
   # Attributes.
-  for key in obj_attrs.keys():
-    obj_attr = self.getObjAttr(key)
+  keys = ob.getObjAttrs().keys()
+  for key in keys:
+    obj_attr = ob.getObjAttr(key)
     datatype = obj_attr['datatype_key']
     if datatype in _globals.DT_BLOBS:
-      for lang in base.getLangIds():
+      for lang in ob.getLangIds():
         try:
-          if obj_attr['multilang']==1 or lang==self.getPrimaryLanguage() or (obj_attr['multilang']==0 and lang!=self.getPrimaryLanguage()):
+          if obj_attr['multilang']==1 or lang==ob.getPrimaryLanguage() or (obj_attr['multilang']==0 and lang!=ob.getPrimaryLanguage()):
             req = {'lang':lang,'preview':'preview'}
-            obj_vers = self.getObjVersion(req)
-            blob = self._getObjAttrValue(obj_attr,obj_vers,lang)
+            obj_vers = ob.getObjVersion(req)
+            blob = ob._getObjAttrValue(obj_attr,obj_vers,lang)
             if blob is not None: 
-              filepath = self.absolute_url()[len(base.absolute_url())+1:]
               filename = blob.getFilename()
-              filename = getLangFilename(self,filename,lang)
-              filename = '%s/%s/%s'%(folder,filepath,filename)
+              filename = getLangFilename(ob,filename,lang)
+              filename = '%s%s'%(base_path,filename)
               filename = _fileutil.getOSPath(filename)
               _fileutil.exportObj(blob,filename)
               ressources.append( { 'filepath':filename, 'content_type':blob.getContentType()})
         except:
-          _globals.writeException(self,"[recurse_downloadRessources]: Can't export %s"%key)
-  if self.meta_type == 'ZMSCustom':
-    metaObjId = self.meta_id
-    for metaObjAttrId in self.getMetaobjAttrIds( metaObjId):
-      metaObjAttr = self.getMetaobjAttr( metaObjId, metaObjAttrId)
+          _globals.writeException(ob,"[recurse_downloadRessources]: Can't export %s"%key)
+    elif datatype == _globals.DT_LIST and obj_attr.get('type') in ['image','file']:
+      for lang in ob.getLangIds():
+        try:
+          if obj_attr['multilang']==1 or lang==ob.getPrimaryLanguage() or (obj_attr['multilang']==0 and lang!=ob.getPrimaryLanguage()):
+            req = {'lang':lang,'preview':'preview'}
+            obj_vers = ob.getObjVersion(req)
+            blobs = ob._getObjAttrValue(obj_attr,obj_vers,lang)
+            i = 0
+            for blob in blobs:
+              filename = blob.getFilename()
+              filename = getLangFilename(ob,filename,lang)
+              filename = '%s@%i/%s'%(base_path,i,filename)
+              filename = _fileutil.getOSPath(filename)
+              _fileutil.exportObj(blob,filename)
+              ressources.append( { 'filepath':filename, 'content_type':blob.getContentType()})
+              i += 1
+        except:
+          _globals.writeException(ob,"[recurse_downloadRessources]: Can't export %s"%key)
+  if ob.meta_type == 'ZMSCustom':
+    metaObjId = ob.meta_id
+    for metaObjAttrId in ob.getMetaobjAttrIds( metaObjId):
+      metaObjAttr = ob.getMetaobjAttr( metaObjId, metaObjAttrId)
       if metaObjAttr['type'] == 'resource':
         try:
           blob = metaObjAttr['custom']
-          filepath = self.absolute_url()[len(base.absolute_url())+1:]
           filename = blob.getFilename()
-          filename = '%s/%s/%s'%(folder,filepath,filename)
+          filename = '%s%s'%(base_path,filename)
           filename = _fileutil.getOSPath(filename)
           _fileutil.exportObj(blob,filename)
           ressources.append( { 'filepath':filename, 'content_type':blob.getContentType()})
         except:
-          _globals.writeException( self, "[recurse_downloadRessources]: Can't export %s.%s"%(metaObjId,metaObjAttrId))
+          _globals.writeException( ob, "[recurse_downloadRessources]: Can't export %s.%s"%(metaObjId,metaObjAttrId))
   # Process children.
-  for child in self.getChildNodes():
-    if deep or child.isPageElement():
-      ressources.extend( recurse_downloadRessources( child, base, folder, deep))
+  for child in ob.getChildNodes():
+    ressources.extend( recurse_downloadRessources( child, base_path, REQUEST, incl_embedded))
   # Return list of ressources.
   return ressources
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.recurse_uploadRessources:
 #
 #  Upload from file-system to ZODB during Import.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def recurse_uploadRessources(self, folder='.', mediadbStorable=True):
   message = ''
   # Upload blob-fields.
@@ -127,11 +151,11 @@ def recurse_uploadRessources(self, folder='.', mediadbStorable=True):
   return message
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.uploadRessources:
 #
 #  Upload blob-fields from file-system to ZODB during import.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def uploadRessources(self, folder='.', mediadbStorable=True):
   obj_attrs = self.getObjAttrs()
   for key in obj_attrs.keys():
@@ -167,7 +191,7 @@ def uploadRessources(self, folder='.', mediadbStorable=True):
           _globals.writeException(self,"[uploadRessources]")
 
 
-# --------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.createBlobField:
 #
 #  Create blob-field of desired object-type and initialize it with given file.
@@ -176,7 +200,7 @@ def uploadRessources(self, folder='.', mediadbStorable=True):
 #	file		[ZPublisher.HTTPRequest.FileUpload|dictionary]
 #       mediadbStorable	[True|False]
 #  OUT:	blob		[MyImage|MyFile]
-# --------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def createBlobField(self, objtype, file='', mediadbStorable=True):
   if type( file) in StringTypes:
     blob = uploadBlobField( self, objtype, file)
@@ -191,9 +215,9 @@ def createBlobField(self, objtype, file='', mediadbStorable=True):
   return blob
 
 
-# --------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.uploadBlobField
-# --------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def uploadBlobField(self, objtype, file='', filename='', mediadbStorable=True):
   if objtype == _globals.DT_IMAGE:
     clazz = MyImage
@@ -209,7 +233,7 @@ def uploadBlobField(self, objtype, file='', filename='', mediadbStorable=True):
     maxlength = self.getConfProperty(maxlength_prop,'')
     if len(maxlength) > 0:
       size = blob.get_size()
-      if size > int(maxlength):          
+      if size > int(maxlength):
         raise 'Exception','size=%i > %s=%i' %(size,maxlength_prop,int(maxlength))
   # Store data in media-db.
   if self is not None and mediadbStorable:
@@ -221,11 +245,11 @@ def uploadBlobField(self, objtype, file='', filename='', mediadbStorable=True):
   return blob
 
 
-# --------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.getLangFilename:
 #  
 #  Returns filename concatenated with language suffix.
-# --------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getLangFilename(self, filename, lang):
   i = filename.rfind('.')
   name = filename[:i]
@@ -240,54 +264,54 @@ def getLangFilename(self, filename, lang):
 
 
 """
-###################################################################################################
+################################################################################
 ###
 ###   T H U M B N A I L S
 ###
-###################################################################################################
+################################################################################
 """
 
-# --------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.thumbnailImageFields:
 #
 #  Process image-fields and shrink superres to hires and hires to lores. 
-# --------------------------------------------------------------------------------------------------
-def thumbnailImageFields(self, lang, manage_lang,REQUEST):
-  message = ""
-  if self.getConfProperty('InstalledProducts.pil',0) == 1 and \
-     self.getConfProperty('InstalledProducts.pil.thumbnail',0) == 1:
+# ------------------------------------------------------------------------------
+def thumbnailImageFields(self, lang, REQUEST):
+  message = ''
+  if self.getConfProperty('InstalledProducts.pil') == 1:
     obj_attrs = self.getObjAttrs()
     for key in obj_attrs.keys():
       obj_attr = self.getObjAttr(key)
       datatype = obj_attr['datatype_key']
       if datatype == _globals.DT_IMAGE:
-        message += thumbnailImage(self,'%ssuperres'%key,'%shires'%key,self.getConfProperty('InstalledProducts.pil.hires.thumbnail.max',600),lang,manage_lang,REQUEST)
-        message += thumbnailImage(self,'%shires'%key,'%s'%key,self.getConfProperty('InstalledProducts.pil.thumbnail.max',100),lang,manage_lang,REQUEST)
+        message += thumbnailImage(self,'%ssuperres'%key,'%shires'%key,self.getConfProperty('InstalledProducts.pil.hires.thumbnail.max',600),lang,REQUEST)
+        message += thumbnailImage(self,'%shires'%key,'%s'%key,self.getConfProperty('InstalledProducts.pil.thumbnail.max',100),lang,REQUEST)
   return message
 
 
-# --------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _blobfields.thumbnailImage:
 #
-#  Process image-field and shrink attribute given by hiresKey to attribute given by loresKey. 
-# --------------------------------------------------------------------------------------------------
-def thumbnailImage(self, hiresKey, loresKey, maxdim, lang, manage_lang, REQUEST):
-  message = ""
+#  Process image-field and shrink attribute given by hiresKey to attribute given 
+#  by loresKey. 
+# ------------------------------------------------------------------------------
+def thumbnailImage(self, hiresKey, loresKey, maxdim, lang, REQUEST):
+  message = ''
   try:
     if hiresKey in self.getObjAttrs().keys():
       hiresImg = self.getObjProperty(hiresKey,REQUEST)
       if hiresImg is not None and REQUEST.get('generate_preview_%s_%s'%(hiresKey,lang),0) == 1:
         if _globals.debug( self): 
-          _globals.writeLog( self, "[manage_changeProperties]: Create >%s< from >%s<..."%(loresKey,hiresKey))
+          _globals.writeLog( self, '[thumbnailImage]: Create >%s< from >%s<...'%(loresKey,hiresKey))
         loresImg = _fileutil.createThumbnail(hiresImg,maxdim)
         self.setObjProperty(loresKey,loresImg,lang)
   except:
-    pass
+    _globals.writeException( self, '[thumbnailImage]')
   return message
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 class MyBlob:
 
@@ -297,10 +321,16 @@ class MyBlob:
     __version__ = '0.1' 
     
 
-    # >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+    __class_name__ = '{{MyBlob}}'
+    
+    def __str__(self):
+      return self.__class_name__
+
+
+    # >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
     #  <BO> Copied from OFS/Image.py:
     #  Modifications: self._p_mtime -> self.aq_parent._p_mtime
-    # >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+    # >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
 
     def _if_modified_since_request_handler(self, REQUEST, RESPONSE):
         # HTTP If-Modified-Since header handling: return True if
@@ -526,14 +556,14 @@ class MyBlob:
                     RESPONSE.write('\r\n--%s--\r\n' % boundary)
                     return True
 
-    # <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
+    # <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
     #  <EO> Copied from OFS/Image.py
-    # <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
+    # <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # 	MyBlob.equals:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def equals(self, ob):
       b = ob is not None
       try:
@@ -547,11 +577,12 @@ class MyBlob:
       return b
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # 	MyBlob._createCopy:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _createCopy(self, aq_parent, key):
       value = self._getCopy()
+      value.is_blob = True
       value.aq_parent = aq_parent
       value.base_url = aq_parent.base_url()
       value.key = key
@@ -559,9 +590,9 @@ class MyBlob:
       return value
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyBlob.__call__: 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __bobo_traverse__(self, TraversalRequest, name):
       return self
 
@@ -574,8 +605,7 @@ class MyBlob:
         RESPONSE = REQUEST.RESPONSE
         parent = self.aq_parent
         
-        if not parent.hasAccess( REQUEST) and \
-           not parent.getConfProperty( 'ZMS.blobfields.grant_public_access', 0) == 1:
+        if not parent.hasAccess( REQUEST) and not parent.getConfProperty( 'ZMS.blobfields.grant_public_access', 0) == 1:
           # Raise unauthorized error.
           raise Unauthorized
         
@@ -632,17 +662,17 @@ class MyBlob:
     index_html=None
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyBlob.getObjAttrs:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getObjAttrs__roles__ = None
     def getObjAttrs(self, meta_type=None):
       return {}
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyBlob.getData:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getData__roles__ = None
     def getData(self, parent=None):
       data = ''
@@ -661,9 +691,9 @@ class MyBlob:
       return data
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyBlob.getHref:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getHref__roles__ = None
     def getHref(self, REQUEST):
       parent = self.aq_parent
@@ -695,21 +725,21 @@ class MyBlob:
       return href
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyBlob.getMediadbfile: 
     #
     #  Returns mediadb-filename.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getMediadbfile__roles__ = None
     def getMediadbfile(self):
       return getattr(self,'mediadbfile',None)
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyBlob.getFilename: 
     #
     #  Returns filename.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getFilename__roles__ = None
     def getFilename(self):
       filename = self.filename
@@ -719,47 +749,60 @@ class MyBlob:
       return filename
 
     
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
+    #  MyBlob.get_real_size: 
+    #
+    #  Returns real size in ZODB.
+    # --------------------------------------------------------------------------
+    get_real_size__roles__ = None
+    def get_real_size(self):
+      if self.mediadbfile is None:
+        return self.get_size()
+      else:
+        return len(self.mediadbfile)
+
+
+    # --------------------------------------------------------------------------
     #  MyBlob.getDataSizeStr: 
     #
     #  Returns display string of file-size (KB).
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getDataSizeStr__roles__ = None
     def getDataSizeStr(self):
       return _fileutil.getDataSizeStr(self.get_size())
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyBlob.getContentType:
     #
     #  MIME-type.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getContentType__roles__ = None
     def getContentType(self):
       return self.content_type
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyBlob.getMimeTypeIconSrc:
     #
     #  Image source for MIME-type.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getMimeTypeIconSrc__roles__ = None
     def getMimeTypeIconSrc(self):
       return '/misc_/zms/' + _mimetypes.dctMimeType.get( self.getContentType(), _mimetypes.content_unknown)
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyBlob.xmlGetTagName: 
     #
     #  Returns <XML> Tag-Name.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def xmlGetTagName(self):
       return 'data'
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 class MyImage(MyBlob,Image):
 
@@ -769,16 +812,13 @@ class MyImage(MyBlob,Image):
     __version__ = '0.1' 
     
 
-    __obj_attrs__ = ['content_type','size','data','filename','mediadbfile','width','height']
-    __xml_attrs__ = ['content_type','width','height']
-    
-    def __str__(self):
-      return '{{MyImage}}'
+    __obj_attrs__  = ['content_type','size','data','filename','mediadbfile','width','height']
+    __xml_attrs__  = ['content_type','width','height']
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # 	MyImage._getCopy:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _getCopy(self):
       self.getFilename() # Normalize filename
       ob = self
@@ -790,52 +830,51 @@ class MyImage(MyBlob,Image):
       return clone
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # 	MyImage.toXml:
-    # ---------------------------------------------------------------------------------------------
-    def toXml(self, sender=None, base=None, base_path=''):
+    # --------------------------------------------------------------------------
+    def toXml(self, sender=None, base_path='', data2hex=True):
       data = ''
       objtype = ''
       filename = _fileutil.getOSPath(_fileutil.extractFilename(getattr(self,'filename','')))
-      if base is None:
+      if data2hex:
         if getattr(self,'content_type','').find('text/') == 0:
           data = '<![CDATA[%s]]>'%str(self.getData( sender))
         else:
           data = bin2hex(self.getData( sender))
         objtype = ' type="image"'
       else:
-        filepath = sender.absolute_url()[len(base.absolute_url())+1:]
         filename = self.getFilename()
         filename = getLangFilename(sender,filename,self.lang)
-        filename = '%s/%s'%(filepath,filename)
+        filename = '%s%s'%(base_path,filename)
       xml = '\n<%s'%self.xmlGetTagName()
       xml += ' width="%s"'%str(getattr(self,'width',''))
       xml += ' height="%s"'%str(getattr(self,'height',''))
       xml += ' content_type="%s"'%str(getattr(self,'content_type',''))
-      xml += ' filename="%s%s"'%(base_path,filename)
+      xml += ' filename="%s"'%filename
       xml += objtype + '>' + data
       xml += '</%s>'%self.xmlGetTagName()
       return xml
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # 	MyImage.getWidth:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getWidth__roles__ = None
     def getWidth(self):
       return self.width
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # 	MyImage.getHeight:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     getHeight__roles__ = None
     def getHeight(self):
       return self.height
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 class MyFile(MyBlob,File):
 
@@ -845,16 +884,13 @@ class MyFile(MyBlob,File):
     __version__ = '0.1' 
     
 
-    __obj_attrs__ = ['content_type','size','data','filename','mediadbfile']
-    __xml_attrs__ = ['content_type']
+    __obj_attrs__  = ['content_type','size','data','filename','mediadbfile']
+    __xml_attrs__  = ['content_type']
+    __class_name__ = '{{MyFile}}'
 
-    def __str__(self):
-      return '{{MyFile}}'
-
-
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # 	MyFile._getCopy:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _getCopy(self):
       self.getFilename() # Normalize filename
       ob = self
@@ -866,29 +902,28 @@ class MyFile(MyBlob,File):
       return clone
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # 	MyFile.toXml:
-    # ---------------------------------------------------------------------------------------------
-    def toXml(self, sender=None, base=None, base_path=''):
+    # --------------------------------------------------------------------------
+    def toXml(self, sender=None, base_path='', data2hex=True):
       data = ''
       objtype = ''
       filename = _fileutil.getOSPath(_fileutil.extractFilename(getattr(self,'filename','')))
-      if base is None:
+      if data2hex:
         if getattr(self,'content_type','').find('text/') == 0:
           data = '<![CDATA[%s]]>'%str(self.getData( sender))
         else:
           data = bin2hex(self.getData( sender))
         objtype = ' type="file"'
       else:
-        filepath = sender.absolute_url()[len(base.absolute_url())+1:]
         filename = self.getFilename()
         filename = getLangFilename(sender,filename,self.lang)
-        filename = '%s/%s'%(filepath,filename)
+        filename = '%s%s'%(base_path,filename)
       xml = '\n<%s'%self.xmlGetTagName()
       xml += ' content_type="%s"'%str(getattr(self,'content_type',''))
-      xml += ' filename="%s%s"'%(base_path,filename)
+      xml += ' filename="%s"'%filename
       xml += objtype + '>' + data
       xml += '</%s>'%self.xmlGetTagName()
       return xml
 
-###################################################################################################
+################################################################################
