@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _confmanager.py
 #
 # $Id: _confmanager.py,v 1.9 2004/11/30 20:03:17 zmsdev Exp $
@@ -21,18 +21,20 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
 from cStringIO import StringIO
 from App.Common import package_home
 from Globals import HTMLFile
+from OFS.CopySupport import absattr
 from OFS.Image import Image
 import os
 import stat
 import urllib
 # Product imports.
+import _charformatmanager
 import _globals
 import _fileutil
 import _filtermanager
@@ -49,16 +51,48 @@ import zmslog
 
 
 """
-###################################################################################################
+################################################################################
 ###
 ###   Initialization
 ###
-###################################################################################################
+################################################################################
 """
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+#  _confmanager.initCSS:
+# ------------------------------------------------------------------------------
+def initCSS(self):
+  stylesheet_css = getattr( self, 'stylesheet.css', None)
+  if stylesheet_css is not None:
+    container = getattr( self.getHome(), 'common', None)
+    folder = getattr( container, 'css', None)
+    if folder is not None:
+      container = getattr( self.getHome(), 'instance', None)
+      if container is None:
+        self.getHome().manage_addFolder( id='instance', title='Local Graphics and Assets')
+        container = getattr( self.getHome(), 'instance', None)
+      folder = getattr( container, 'css', None)
+    if folder is None:
+      container.manage_addFolder( id='css', title='Cascading Style-Sheets')
+      folder = getattr( container, 'css', None)
+    ids = self.objectIds(['DTML Method'])
+    excl_ids = filter( lambda x: x in ids, [ 'stylesheet.css'] + map( lambda x: 'stylesheet_%s.css'%x, self.getLangIds()))
+    move_ids = filter( lambda x: x not in excl_ids and x.find('.css') > 0, ids)
+    id = 'style.css'
+    title = 'Default CSS'
+    data = stylesheet_css.raw
+    if data.find( '<dtml-var') >= 0:
+      data = '<dtml-with content\n><dtml-call "REQUEST.RESPONSE.setHeader(\'Cache-Control\',\'public, max-age=3600\')"\n><dtml-var f_standard_html_request\n><dtml-var f_css_defaults>\n'+data+'\n</dtml-with>'
+    if id not in folder.objectIds():
+      folder.manage_addDTMLMethod( id, title, data)
+    self.manage_delObjects( ids=excl_ids)
+    cb_copy_data = self.manage_cutObjects(move_ids,REQUEST)
+    trashcan.manage_pasteObjects(cb_copy_data=None,REQUEST=REQUEST)
+
+
+# ------------------------------------------------------------------------------
 #  _confmanager.initConf:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def initConf(self, profile, REQUEST):
   createIfNotExists = 1
   filenames = self.getConfFiles()
@@ -70,22 +104,22 @@ def initConf(self, profile, REQUEST):
         self.importConf(filename,REQUEST,createIfNotExists)
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _confmanager.updateConf:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def updateConf(self, REQUEST):
   filenames = self.getConfFiles()
   for filename in filenames:
     self.importConf(filename,REQUEST,0)
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class ConfManager:
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class ConfManager(
 	_multilangmanager.MultiLanguageManager,		# Languages
 	_metadictmanager.MetadictManager,		# Metadata
@@ -93,7 +127,8 @@ class ConfManager(
 	_metapatternmanager.MetapatternManager,		# Modules
 	_metacmdmanager.MetacmdManager,			# Actions
 	_workflowmanager.WorkflowManager,		# Workflow
-	_textformatmanager.TextFormatManager,		# Formats
+	_textformatmanager.TextFormatManager,		# Text-Formats
+	_charformatmanager.CharFormatManager,		# Char-Formats
 	_filtermanager.FilterManager,			# Filters (XML Im-/Export)
 	):
         
@@ -103,9 +138,9 @@ class ConfManager(
     manage_customizeDesignForm = HTMLFile('dtml/zms/manage_customizedesignform', globals()) 
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.importConfPackage:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def importConfPackage(self, file, REQUEST, createIfNotExists=0):
       if type( file) is type(''):
         filename = file
@@ -116,9 +151,9 @@ class ConfManager(
         self.importConf(f,REQUEST,createIfNotExists)
       
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.importConf:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def importConf(self, file, REQUEST, createIfNotExists=0):
       if type(file) is dict:
         filename = file['filename']
@@ -127,7 +162,9 @@ class ConfManager(
         filename = file
         filepath = package_home(globals())+'/import/'
         xmlfile = open(_fileutil.getOSPath(filepath+filename),'rb')
-      if filename.find('.filter.') > 0:
+      if filename.find('.charfmt.') > 0:
+        _charformatmanager.importXml(self, xmlfile, REQUEST, 1, createIfNotExists)
+      elif filename.find('.filter.') > 0:
         _filtermanager.importXml(self, xmlfile, REQUEST, 1, createIfNotExists)
       elif filename.find('.metadict.') > 0:
         _metadictmanager.importXml(self, xmlfile, REQUEST, 1, createIfNotExists)
@@ -137,14 +174,16 @@ class ConfManager(
         _metacmdmanager.importXml(self, xmlfile, REQUEST, 1, createIfNotExists)
       elif filename.find('.langdict.') > 0:
         _multilangmanager.importXml(self, xmlfile, REQUEST, 1, createIfNotExists)
+      elif filename.find('.textfmt.') > 0:
+        _textformatmanager.importXml(self, xmlfile, REQUEST, 1, createIfNotExists)
       xmlfile.close()
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.getConfFiles:
     #
     #  Returns configuration-files from $ZMS_HOME/import-Folder
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getConfFiles(self, pattern=None):
       filenames = []
       filepath = package_home(globals())+'/import/'
@@ -159,18 +198,18 @@ class ConfManager(
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   Configuration-Properties Getters
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.getSequence:
     #
     #  Returns sequence.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getSequence(self):
       id = 'acl_sequence'
       if id not in self.objectIds(['Sequence']):
@@ -178,116 +217,115 @@ class ConfManager(
       ob = getattr(self,id)
       return ob
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.getMediaDb:
     #
     #  Returns mediadb.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMediaDb(self):
       return getattr(self,'acl_mediadb',None)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.getStylesheet:
     #
     #  Returns stylesheet.
-    # ---------------------------------------------------------------------------------------------
-    def getStylesheet(self, defaultCSS=''):
-      id = 'stylesheet.css'
-      title = '*** DO NOT DELETE OR MODIFY ***'
-      ob = None
-      if id not in self.objectIds(['DTML Method']):
-        portalMaster = self.getPortalMaster()
-        if portalMaster is not None:
-          ob = portalMaster.getStylesheet()
-        else:
-          raw = ''
-          self.manage_addDTMLMethod(id,title,raw)
-      if ob is None:
-        ob = getattr(self,id)
-      if len(defaultCSS)>0:
-        ob.manage_edit(defaultCSS,title)
-      return ob
+    # --------------------------------------------------------------------------
+    def getStylesheet(self, id=None):
+      stylesheets = self.getStylesheets()
+      if id is None:
+        return stylesheets[0]
+      else:
+        for css in stylesheets:
+          if absattr( css.id) == id:
+            return css
 
-
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.getStylesheets:
     #
     #  Returns list of stylesheets.
-    # ---------------------------------------------------------------------------------------------
-    def getStylesheets(self, acquired=True):
+    # --------------------------------------------------------------------------
+    def getStylesheets(self):
+      ids = []
       obs = []
-      for ob in self.objectValues(['DTML Method']):
-        id = ob.id()
-        if id == 'stylesheet.css':
-          obs.append( ob)
-        elif id.find('.css') > 0:
-          b = ob in obs
-          for lang in self.getLangIds():
-            b = b or id.find('_%s.css'%lang)>0
-          if not b:
-            obs.append( ob)
-      if len( obs) == 0 and acquired:
-        portalMaster = self.getPortalMaster()
-        if portalMaster is not None:
-          obs = portalMaster.getStylesheets()
+      for id in [ 'instance', 'common']:
+        container = getattr( self, id, None)
+        if container is not None:
+          folder = getattr( container, 'css', None)
+          if folder is not None:
+            for ob in folder.objectValues(['DTML Method','DTML Document']):
+              id = absattr( ob.id)
+              if id not in ids:
+                ids.append( id)
+                if absattr( ob.id) == self.getConfProperty('ZMS.stylesheet','style.css'):
+                  obs.insert( 0, ob)
+                else:
+                  obs.append( ob)
       return obs
       
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   Configuration-Tab Options
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
     
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.customize_manage_options:
-    # -------------------------------------------------------------------------------------------------
-    def customize_manage_options(self, lang, manage_lang, REQUEST):
+    # --------------------------------------------------------------------------
+    def customize_manage_options(self, lang, REQUEST):
       options = []
-      options.append({'label':self.getLangStr('TAB_SYSTEM',manage_lang),'action':'manage_customize'})
-      options.append({'label':self.getLangStr('TAB_LANGUAGES',manage_lang),'action':'manage_customizeLanguagesForm'})
-      options.append({'label':self.getLangStr('TAB_METADATA',manage_lang),'action':'manage_customizeMetadictForm'})
-      options.append({'label':self.getLangStr('TAB_METAOBJ',manage_lang),'action':'manage_customizeMetaobjForm'})
-      options.append({'label':self.getLangStr('TAB_METAPATTERN',manage_lang),'action':'manage_customizeMetapatternForm'})
-      options.append({'label':self.getLangStr('TAB_METACMD',manage_lang),'action':'manage_customizeMetacmdForm'})
-      options.append({'label':self.getLangStr('TAB_WORKFLOW',manage_lang),'action':'manage_customizeWorkflowForm'})
-      options.append({'label':self.getLangStr('TAB_TEXTFORMAT',manage_lang),'action':'manage_customizeTextFormatForm'})
-      options.append({'label':self.getLangStr('TAB_FILTER',manage_lang),'action':'manage_customizeFilterForm'})
-      options.append({'label':self.getLangStr('TAB_DESIGN',manage_lang),'action':'manage_customizeDesignForm'})
+      options.append({'label':self.getZMILangStr('TAB_SYSTEM'),'action':'manage_customize'})
+      options.append({'label':self.getZMILangStr('TAB_LANGUAGES'),'action':'manage_customizeLanguagesForm'})
+      options.append({'label':self.getZMILangStr('TAB_METADATA'),'action':'manage_customizeMetadictForm'})
+      options.append({'label':self.getZMILangStr('TAB_METAOBJ'),'action':'manage_customizeMetaobjForm'})
+      options.append({'label':self.getZMILangStr('TAB_METAPATTERN'),'action':'manage_customizeMetapatternForm'})
+      options.append({'label':self.getZMILangStr('TAB_METACMD'),'action':'manage_customizeMetacmdForm'})
+      options.append({'label':self.getZMILangStr('TAB_WORKFLOW'),'action':'manage_customizeWorkflowForm'})
+      options.append({'label':self.getZMILangStr('TAB_TEXTFORMAT'),'action':'manage_customizeTextFormatForm'})
+      options.append({'label':self.getZMILangStr('TAB_FILTER'),'action':'manage_customizeFilterForm'})
+      options.append({'label':self.getZMILangStr('TAB_DESIGN'),'action':'manage_customizeDesignForm'})
       return options
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   Configuration-Properties
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.__get_attr_conf_dict__:
     #
     #  Returns property from configuration.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __get_attr_conf_dict__(self):
       return getattr( self, '__attr_conf_dict__', {})
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.getConfProperty:
     #
     #  Returns property from configuration.
-    # ---------------------------------------------------------------------------------------------
+    #
+    #  @param key	The key.
+    #  @param default	The default-value.
+    #  @return any
+    # --------------------------------------------------------------------------
     def getConfProperty(self, key, default=None):
       return self.__get_attr_conf_dict__().get( key, default)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ConfManager.setConfProperty:
     #
-    #  Returns property from configuration.
-    # ---------------------------------------------------------------------------------------------
+    #  Sets property into configuration.
+    #
+    #  @param key	The key.
+    #  @param value	The value.
+    #  @return void
+    # --------------------------------------------------------------------------
     def setConfProperty(self, key, value):
       attr_conf_dict = self.__get_attr_conf_dict__()
       if value is None:
@@ -300,19 +338,19 @@ class ConfManager(
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   Configuration-System
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    ###############################################################################################
+    ############################################################################
     #  ConfManager.manage_customizeSystem: 
     #
     #  Customize system properties.
-    ###############################################################################################
-    def manage_customizeSystem(self, btn, key, lang, manage_lang, REQUEST, RESPONSE): 
+    ############################################################################
+    def manage_customizeSystem(self, btn, key, lang, REQUEST, RESPONSE): 
       """ ConfManager.manage_customizeSystem """
       
       message = ''
@@ -322,7 +360,7 @@ class ConfManager(
       if key == 'ASP':
         self.setConfProperty('ZMSAdministrator.email',REQUEST.get('zmsadministrator_email',''))
         self.setConfProperty('ASP.ip_or_domain',REQUEST.get('asp_ip_or_domain',''))
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       ##### Import ####
       elif key == 'Import':
@@ -335,7 +373,7 @@ class ConfManager(
 	  else:
             filename = REQUEST['init']
 	    self.importConfPackage( filename, REQUEST, createIfNotExists)
-          message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%filename)
+          message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%filename)
 
       ##### History ####
       elif key == 'History':
@@ -354,15 +392,7 @@ class ConfManager(
           ob = self.getLinkObj( node)
           if ob is not None:
             message += '[%s: %i]'%(node,ob.packHistory())
-        message = self.getLangStr('MSG_CHANGED',manage_lang)+message
-      
-      ##### Catalog ####
-      elif key == 'Catalog':
-        if btn == 'Change':
-          self.setConfProperty('ZMS.CatalogAwareness.active',REQUEST.get('active',0))
-          message = self.getLangStr('MSG_CHANGED',manage_lang)
-        elif btn == 'Refresh':
-          message = self.reindexCatalog(REQUEST)
+        message = self.getZMILangStr('MSG_CHANGED')+message
       
       ##### Clients ####
       elif key == 'Clients':
@@ -376,14 +406,14 @@ class ConfManager(
             if s in self.getHome().objectIds(['Folder']):
               l.append(s)
           self.setConfProperty('Portal.Clients',l)
-          message = self.getLangStr('MSG_CHANGED',manage_lang)
+          message = self.getZMILangStr('MSG_CHANGED')
       
       ##### MediaDb ####
       elif key == 'MediaDb':
         if btn == 'Create':
           location = REQUEST['mediadb_location'].strip()
           _mediadb.manage_addMediaDb(self,location)
-          message = self.getLangStr('MSG_CHANGED',manage_lang)
+          message = self.getZMILangStr('MSG_CHANGED')
         elif btn == 'Pack':
           message = _mediadb.manage_packMediaDb(self)
         elif btn == 'Remove':
@@ -400,25 +430,22 @@ class ConfManager(
               self.setConfProperty( k, v)
             except:
               _globals.writeException( self, "[manage_customizeSystem]: can't set conf-property %s=%s"%(str(k),str(v)))
-            message = self.getLangStr('MSG_CHANGED',manage_lang)
+            message = self.getZMILangStr('MSG_CHANGED')
             params.append( 'conf_key')
           else:
             k = REQUEST.get( 'option')
             v = REQUEST.get( 'value', '')
             self.setConfProperty( k, v)
-            message = self.getLangStr('MSG_CHANGED',manage_lang)
+            message = self.getZMILangStr('MSG_CHANGED')
             params.append( 'option')
       
       ##### InstalledProducts ####
       elif key == 'InstalledProducts':
         if btn == 'Change':
           self.setConfProperty('InstalledProducts.pil',REQUEST.get('pil',None))
-          self.setConfProperty('InstalledProducts.pil.scale',REQUEST.get('pil_scale',0))
-          self.setConfProperty('InstalledProducts.pil.thumbnail',REQUEST.get('pil_thumbnail',0))
           self.setConfProperty('InstalledProducts.pil.thumbnail.max',REQUEST.get('pil_thumbnail_max',100))
-          self.setConfProperty('InstalledProducts.pil.superres',REQUEST.get('pil_superres',0))
-          self.setConfProperty('InstalledProducts.pil.hires.thumbnail.max',REQUEST.get('pil_hires_thumbnail_max',600))
-          message = self.getLangStr('MSG_CHANGED',manage_lang)
+          self.setConfProperty('InstalledProducts.pil.hires.thumbnail.max',REQUEST.get('pil_hires_thumbnail_max',0))
+          message = self.getZMILangStr('MSG_CHANGED')
       
       ##### StandardObjects ####
       elif key == 'StandardObjects':
@@ -427,7 +454,7 @@ class ConfManager(
         meta_types.extend(self.getMetaobjIds())
         for meta_type in meta_types:
           self.setConfProperty('%s.enabled'%meta_type,meta_type in REQUEST.get('meta_types',[]))
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       ##### Log ####
       elif key == 'Log':
@@ -442,7 +469,6 @@ class ConfManager(
       # Return with message.
       d = {
       	'lang': lang,
-      	'manage_lang': manage_lang,
       	'manage_tabs_message': message,
       }
       for param in params:
@@ -451,70 +477,73 @@ class ConfManager(
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   Configuration-Design
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    ###############################################################################################
+    ############################################################################
     #  ConfManager.manage_customizeDesign: 
     #
     #  Customize design properties.
-    ###############################################################################################
-    def manage_customizeDesign(self, btn, lang, manage_lang, REQUEST, RESPONSE):
+    ############################################################################
+    def manage_customizeDesign(self, btn, lang, REQUEST, RESPONSE):
       """ ConfManager.manage_customizeDesign """
       message = ''
       cssId = REQUEST.get('cssId','')
       
       # Insert.
       # -------
-      if btn == self.getLangStr('BTN_INSERT',manage_lang):
+      if btn == self.getZMILangStr('BTN_INSERT'):
         #-- Stylesheet.
         if REQUEST.has_key('newCssId'):
-          self.manage_addDTMLMethod( REQUEST.get('newCssId'), '*** DO NOT DELETE OR MODIFY ***', '')
-          message = self.getLangStr('MSG_INSERTED',manage_lang)%REQUEST.get('newCssId')
+          title = 'CSSschema'
+          data = '<dtml-with content\n><dtml-call "REQUEST.RESPONSE.setHeader(\'Cache-Control\',\'public, max-age=3600\')"\n><dtml-var f_standard_html_request\n><dtml-var f_css_defaults>\n\n</dtml-with>'
+          self.common.css.manage_addDTMLMethod( REQUEST.get('newCssId'), title, data)
+          message = self.getZMILangStr('MSG_INSERTED')%REQUEST.get('newCssId')
           cssId = REQUEST.get('newCssId')
         
       # Delete.
       # -------
-      if btn == self.getLangStr('BTN_DELETE',manage_lang):
+      if btn == self.getZMILangStr('BTN_DELETE'):
         #-- Stylesheet.
         if REQUEST.has_key('cssId'):
-          self.manage_delObjects(ids=[REQUEST.get('cssId')])
-          message = self.getLangStr('MSG_DELETED',manage_lang)%int(1)
+          self.common.css.manage_delObjects(ids=[REQUEST.get('cssId')])
+          message = self.getZMILangStr('MSG_DELETED')%int(1)
           cssId = ''
         
       # Change.
       # -------
-      if btn == self.getLangStr('BTN_CHANGE',manage_lang):
+      if btn == self.getZMILangStr('BTN_CHANGE'):
         #-- Stylesheet.
         if REQUEST.has_key('cssId'):
-          method = getattr( self, REQUEST.get('cssId'))
+          if REQUEST.get('default'):
+            self.setConfProperty('ZMS.stylesheet',REQUEST.get('cssId'))
+          css = self.getStylesheet( REQUEST.get('cssId'))
           data = REQUEST.get('stylesheet')
-          title = method.title
-          method.manage_edit(data,title)
+          title = css.title
+          css.manage_edit(data,title)
+          message = self.getZMILangStr('MSG_CHANGED')
         #-- Sitemap.
         if REQUEST.has_key('attr_layoutsitemap'):
           if len(REQUEST['attr_layoutsitemap'])>0:
             self.attr_layoutsitemap = int(REQUEST['attr_layoutsitemap'])
           elif hasattr(self,'attr_layoutsitemap'):
             delattr(self,'attr_layoutsitemap')
-        #-- Skin.
-        self.setConfProperty('ZMS.skin',REQUEST.get('skin',''))
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+          message = self.getZMILangStr('MSG_CHANGED')
       
       # Upload.
       # -------
-      elif btn == self.getLangStr('BTN_UPLOAD',manage_lang):
+      elif btn == self.getZMILangStr('BTN_UPLOAD'):
         #-- Logo.
         self.logo = Image(id='logo', title='', file='')
         self.logo.manage_upload(REQUEST['file'],REQUEST)
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_customizeDesignForm?lang=%s&manage_lang=%s&manage_tabs_message=%s&cssId=%s'%(lang,manage_lang,message,cssId))
+      return RESPONSE.redirect('manage_customizeDesignForm?lang=%s&manage_tabs_message=%s&cssId=%s'%(lang,message,cssId))
 
-###################################################################################################
+################################################################################
