@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _exportable.py
 #
 # $Id: _exportable.py,v 1.9 2004/11/30 20:03:17 zmsdev Exp $
@@ -21,11 +21,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from App.Common import package_home
 from OFS.Image import Image
+import copy
 import urllib
 import tempfile
 import os
@@ -38,28 +39,30 @@ import _globals
 import _xmllib
 
 
-# ---------------------------------------------------------------------------------------------
-#  _exportable.exportCommon:
-# ---------------------------------------------------------------------------------------------
-def exportCommon(root, path, id):
+# ------------------------------------------------------------------------------
+#  _exportable.exportFolder:
+# ------------------------------------------------------------------------------
+def exportFolder(self, root, path, id, REQUEST):
   if hasattr(root,id):
     folder = getattr(root,id)
     if folder.meta_type == 'Folder':
       for ob in folder.objectValues():
         if ob.meta_type == 'Folder':
           ob_id = ob.id
-          exportCommon(ob,'%s/%s'%(path,id),ob_id)
+          exportFolder(self, ob,'%s/%s'%(path,id),ob_id,REQUEST)
         else:
           try:
             ob_id = ob.id()
           except:
             ob_id = str(ob.id)
+          if ob.meta_type in [ 'DTML Document', 'DTML Method']:
+            ob = _globals.dt_html(self,ob.raw,REQUEST)
           _fileutil.exportObj(ob,'%s/%s/%s'%(path,id,ob_id))
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _exportable.findDelimiter:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def findDelimiter(s, delimiters=['"',"'"]):
   rtn = -1
   for delimiter in delimiters:
@@ -71,9 +74,9 @@ def findDelimiter(s, delimiters=['"',"'"]):
   return rtn
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _exportable.rfindDelimiter:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def rfindDelimiter(s, delimiters=['"',"'"]):
   rtn = -1
   for delimiter in delimiters:
@@ -82,62 +85,21 @@ def rfindDelimiter(s, delimiters=['"',"'"]):
   return rtn
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _exportable.localHtml:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def localHtml(self, obj, html, REQUEST):
   
-  # Process relative links to Blob-Fields (Images and Files).
-  # ---------------------------------------------------------
-  
-  # [i]
-  for s_blob in [ 'f_zoomImage?']:
-    i = html.find(s_blob)
-    while i > 0:
-      k = rfindDelimiter(html[:i])
-      j = html[k:i-1].rfind('/')
-      if j < 0:
-        s_blob_id = obj.id
-        o_blob = obj
-        s_new = '"'
-      else:
-        s_blob_id = html[k+j+1:i-1]
-        o_blob = self.findObjId(s_blob_id,REQUEST)
-        s_new = '%s/'%s_blob_id
-      s_old = s_new + s_blob
-      if o_blob is not None:
-        l = html[i:].find('key=')
-        m = html[i+l:].find('&')
-        s_key = html[i+l+4:i+l+m]
-        value = o_blob.getObjProperty(s_key,REQUEST)
-        filename = getattr(value,'filename',None)
-        if filename is not None:
-          s_new += filename
-      s_new += '?'
-      if len(s_old) > 0: html = html.replace(s_old,s_new)
-      i = html.find(s_blob)
-  
-  # [ii]
-  s_blob = '?key='
-  i = html.find(s_blob)
-  while i > 0:
-    k = findDelimiter(html[i:])
-    s_old = html[i:i+k]
-    s_new = ''
-    if len(s_old) > 0: html = html.replace(s_old,s_new)
-    i = html.find(s_blob)
-  
   # Process relative links to JavaScript.
-  # -------------------------------------
-  for js in [ 'comlib', 'datelib', 'formlib', 'managelib', 'styleswitcher']:
-    html = re.sub( '"(.*?)\_js(|\?lang=%s|\?lang=%s&manage_lang=%s)"'%(REQUEST['lang'],REQUEST['lang'],REQUEST['manage_lang']), '"\\1.js"', html)
+  for js in [ 'comlib', 'datelib', 'formlib', 'zmilib', 'styleswitcher']:
+    html = re.sub( '"(.*?)\_js(|\?lang=(.*?))"', '"\\1.js"', html)
   
   return html
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _exportable.localIndexHtml:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def localIndexHtml(self, obj, level, html, REQUEST):
    
    sRoot = ''
@@ -153,14 +115,16 @@ def localIndexHtml(self, obj, level, html, REQUEST):
    s_old = '%s/'%self.getHome().absolute_url()
    html = html.replace( s_old, s_new)
    
-   # Process links to common-Folder (resource-Directory: Images and Assets).
-   s_new = '"%scommon/'%sRoot
-   s_old = '"./common/'
-   html = html.replace(s_old,s_new)
-   s_old = '"common/'
-   html = html.replace(s_old,s_new)
+   # Process links to resource-folders: images and assets.
+   for id in [ 'common', 'instance']:
+     if hasattr( self, id):
+       s_new = '"%s%s/'%(sRoot,id)
+       s_old = '"./%s/'%(id)
+       html = html.replace(s_old,s_new)
+       s_old = '"%s/'%(id)
+       html = html.replace(s_old,s_new)
    
-   # Process links to Product-Folder (resource-Directory: Images and Assets).
+   # Process links to product-folder: images and assets.
    s_new = '"%smisc_/zms/'%sRoot
    s_old = '"/misc_/zms/'
    html = html.replace(s_old,s_new)
@@ -178,7 +142,8 @@ def localIndexHtml(self, obj, level, html, REQUEST):
      html = re.sub('(\?|&)preview=preview','',html)
    
    # Process declarative URLs
-   if self.getConfProperty('ZMS.pathhandler',0) != 0:
+   if self.getConfProperty('ZMS.pathhandler',0) != 0 and \
+      self.getConfProperty('ZMS.export.pathhandler',0) == 1:
      newTmp = '..\\'
      oldTmp = '../'
      # Save links to root.
@@ -205,21 +170,21 @@ def localIndexHtml(self, obj, level, html, REQUEST):
    return html
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class Exportable
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class Exportable:
 
-    ###############################################################################################    
+    ############################################################################    
     #  Exportable.manage_export:
     #
     #  Exports ZMS-object.
-    ###############################################################################################    
-    def manage_export(self, export_format, lang, manage_lang, REQUEST, RESPONSE):
+    ############################################################################    
+    def manage_export(self, export_format, lang, REQUEST, RESPONSE):
       """ Exportable.manage_export """
       
       title = self.getHome().id + '_' + _globals.id_quote( self.getTitlealt( REQUEST))
@@ -245,11 +210,24 @@ class Exportable:
         content_type = 'application/zip'
       
       # XML.
-      elif export_format == 2: 
+      elif export_format in [ 2, 4]: 
+        incl_embedded = export_format == 4
         filename = '%s_xml.zip'%title
-        export = self.toZippedXml( REQUEST, get_data)
+        export = self.toZippedXml( REQUEST, get_data, incl_embedded)
         content_type = 'application/zip'
       
+      # myXML.
+      elif export_format == 3: 
+        instance_home = INSTANCE_HOME
+        software_home = os.path.join(SOFTWARE_HOME, '..%s..' % os.sep)
+        software_home = os.path.normpath(software_home)  
+        REQUEST.set( 'ZMS_FILTER_SOFTWARE_HOME', software_home)
+        REQUEST.set( 'ZMS_FILTER_INSTANCE_HOME', instance_home)
+        REQUEST.set( 'ZMS_FILTER_PACKAGE_HOME', package_home(globals()))
+        filename = '%s.xml'%title
+        export = self.getXmlHeader() + getattr( self, 'getObjToXml_DocElmnt')(context=self)
+        content_type = 'text/xml'
+      
       # Export Filter.
       elif export_format in self.getFilterIds():
         filename, export, content_type = _filtermanager.exportFilter(self, export_format, REQUEST)
@@ -262,23 +240,51 @@ class Exportable:
       else:
         message = 'Exported to %s (%s)'%(export,content_type)
         url = '%s/manage_importexport'%self.absolute_url()
-        url = self.url_append_params( url, { 'lang': lang, 'manage_lang': manage_lang, 'manage_tabs_message': message})
+        url = self.url_append_params( url, { 'lang': lang, 'manage_tabs_message': message})
         RESPONSE.redirect( url)
 
 
-    ###############################################################################################    
+    ############################################################################    
     #  Exportable.pub_export:
     #
     #  Exports ZMS-object.
-    ###############################################################################################    
-    def pub_export(self, export_format, lang, manage_lang, REQUEST, RESPONSE):
+    ############################################################################    
+    def pub_export(self, export_format, lang, REQUEST, RESPONSE):
       """ Exportable.pub_export """
-      return self.manage_export( export_format, lang, manage_lang, REQUEST, RESPONSE)
+      self.f_standard_html_request( self, REQUEST)
+      return self.manage_export( export_format, lang, REQUEST, RESPONSE)
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
+    #  Exportable.getObjToXml:
+    #
+    #  myXML
+    # --------------------------------------------------------------------------
+    def getObjToXml(self):
+      xml = []
+      method = getattr( self, 'getObjToXml_%s'%self.meta_id_or_type(), None)
+      if method is not None:
+        xml.append( method( context=self))
+      return ''.join(xml)
+
+    # --------------------------------------------------------------------------
+    #  Exportable.getObjChildrenToXml:
+    #
+    #  myXML
+    # --------------------------------------------------------------------------
+    def getObjChildrenToXml(self):
+      REQUEST = self.REQUEST
+      xml = []
+      for context in self.filteredChildNodes(REQUEST):
+        xml.append( context.getObjToXml())
+      return ''.join(xml)
+          
+
+    # --------------------------------------------------------------------------
     #  Exportable.toXhtml:
-    # ---------------------------------------------------------------------------------------------
+    #
+    #  (X)HTNL
+    # --------------------------------------------------------------------------
     def toXhtml(self, REQUEST, deep=True):
       if _globals.debug( self):
         _globals.writeLog( self, '[toXhtml]')
@@ -304,29 +310,22 @@ class Exportable:
       return html
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  Exportable.toXml:
-    # ---------------------------------------------------------------------------------------------
-    def toXml(self, REQUEST, deep=True, base_path='', xml_header=True, data2hex=False):
-      if _globals.debug( self):
-        _globals.writeLog( self, '[toXml]')
+    # --------------------------------------------------------------------------
+    def toXml(self, REQUEST, incl_embedded=False, deep=True, data2hex=False):
       xml = ''
-      if xml_header:
-        xml += _xmllib.xml_header()
-      if data2hex:
-        base = None
-      else:
-        base = self
-      xml += _xmllib.getObjToXml( self, base, REQUEST, deep, base_path)
+      xml += _xmllib.xml_header()
+      xml += _xmllib.getObjToXml( self, REQUEST, incl_embedded, deep, base_path='', data2hex=data2hex)
       return xml 
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  Exportable.exportRessources:
     #
     #  Returns list of exported resources (Images, StyleSheets, etc.)
-    # ---------------------------------------------------------------------------------------------
-    def exportRessources(self, tempfolder, REQUEST, from_content=True, from_zms=False, from_common=False, deep=True):
+    # --------------------------------------------------------------------------
+    def exportRessources(self, tempfolder, REQUEST, from_content=True, from_zms=False, from_common=False, incl_embedded=False):
       ressources = []
       
       if from_zms:
@@ -335,57 +334,38 @@ class Exportable:
           _fileutil.exportObj(self.misc_.zms[obj_id],'%s/%s/%s'%(tempfolder,folder,obj_id))
       
       if from_common:
-        exportCommon( self.getHome(), tempfolder, 'common')
+        for id in [ 'common', 'instance']:
+          exportFolder( self, self.getHome(), tempfolder, id, REQUEST)
       
       if from_content:
-        ressources.extend( self.exportContentRessources( self, tempfolder, REQUEST, deep))
+        ressources.extend( self.exportContentRessources( tempfolder, REQUEST, incl_embedded))
       
       return ressources
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  Exportable.exportContentRessources:
     #
     #  Returns list of exported resources (Images, StyleSheets, etc.)
-    # ---------------------------------------------------------------------------------------------
-    def exportContentRessources(self, base, tempfolder, REQUEST, deep=True):
+    # --------------------------------------------------------------------------
+    def exportContentRessources(self, tempfolder, REQUEST, incl_embedded):
       
       if REQUEST is not None:
       
-        #-- StyleSheet
-        bk_lang = REQUEST.get( 'lang')
-        bk_preview = REQUEST.get( 'preview')
-        for lang in self.getLangIds():
-          REQUEST.set( 'ZMS_HTML_EXPORT', 1)
-          REQUEST.set( 'lang', lang)
-          REQUEST.set ('preview', None)
-          filename = 'stylesheet_%s.css'%lang
-          obj = getattr( self, filename, None)
-          if obj is not None:
-            data = obj( self, REQUEST)
-            root = './'
-            old = self.MISC_ZMS
-            new = '%s%s'%( root, self.MISC_ZMS)
-            data = data.replace( old, new)
-            ressource = '%s/%s'%(tempfolder,filename)
-            _fileutil.exportObj( data, ressource)
-        REQUEST.set('lang',bk_lang)
-        REQUEST.set('preview',bk_preview)
-        
         #-- JavaScript
-        for js in [ 'comlib', 'formlib', 'datelib', 'formlib', 'managelib', 'styleswitcher']:
+        for js in [ 'comlib', 'formlib', 'datelib', 'formlib', 'zmilib', 'styleswitcher']:
           data = getattr(self,'%s_js'%(js))(self,REQUEST)
           filename = '%s.js'%js
           ressource = '%s/%s'%(tempfolder,filename)
           _fileutil.exportObj( data, ressource)
       
       # Download ressources (images & files)
-      return _blobfields.recurse_downloadRessources( self, base, tempfolder, deep)
+      return _blobfields.recurse_downloadRessources( self, tempfolder+'/', REQUEST, incl_embedded)
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	Exportable.exportExternalResources
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def exportExternalResources(self, obj, html, path, REQUEST):
       domains = []
       for domain in self.getConfProperty('ZMS.export.domains','').split(','):
@@ -438,11 +418,10 @@ class Exportable:
       return html
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	Exportable.recurse_downloadHtmlPages:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def recurse_downloadHtmlPages(self, obj, path, lang, REQUEST):
-      
       try:
         os.mkdir(path)
       except:
@@ -455,13 +434,34 @@ class Exportable:
         # Get html.
         REQUEST.set('op',dctOp[key])
         REQUEST.set('ZMS_PATH_HANDLER', True)
+        
         try:
-          html = obj.index_html( obj, REQUEST)
+
+          # Remember others.
+          others = copy.copy(REQUEST.other.keys())
+
+          root = getattr( obj, '__root__', None)
+          if root is not None:
+            REQUEST.set('ZMS_PROXY_%s'%root.id,obj)
+            html = root.index_html( root, REQUEST)
+          else:
+            html = obj.index_html( obj, REQUEST)
+
+          # Remove new others.
+          for rk in REQUEST.other.keys():
+            if rk not in others:
+              try:
+                del REQUEST.other[rk]
+              except:
+                pass
+          
           html = localHtml( self, obj, html, REQUEST)
           
           # Save html to file.
           if key == 'index' and \
-             level > 0 and self.getConfProperty('ZMS.pathhandler',0) != 0:
+             level > 0 and \
+             self.getConfProperty('ZMS.pathhandler',0) != 0 and \
+             self.getConfProperty('ZMS.export.pathhandler',0) == 1:
             html = localIndexHtml( self, obj, level - 1, html, REQUEST)
             filename = '%s/../%s%s'%( path, obj.getDeclId(REQUEST), obj.getPageExt(REQUEST))
           else:
@@ -513,20 +513,18 @@ class Exportable:
         self.recurse_downloadHtmlPages(child,'%s/%s'%(path,child.getDeclId(REQUEST)),lang,REQUEST)
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	Exportable.toZippedHtml:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def toZippedHtml(self, REQUEST, get_data=True):
       
       #-- Create temporary folder.
-      from_content = True
-      from_zms = self.getLevel()==0
-      from_common = True
       tempfolder = tempfile.mktemp()
-      ressources = self.exportRessources( tempfolder, REQUEST, from_content, from_zms, from_common)
+      ressources = self.exportRessources( tempfolder, REQUEST, from_zms=self.getLevel()==0, from_common=True)
       
       #-- Download HTML-pages.
       for lang in self.getLangIds():
+        REQUEST.set('ZMS_INDEX_HTML',1)
         REQUEST.set('ZMS_HTML_EXPORT',1)
         REQUEST.set('lang',lang)
         REQUEST.set('preview',None)
@@ -537,22 +535,23 @@ class Exportable:
       rtn = _fileutil.buildZipArchive( zipfiles, get_data)
       
       #-- Remove temporary folder.
-      _fileutil.remove( tempfolder, deep=1)
+      if not _globals.debug( self):
+        _fileutil.remove( tempfolder, deep=1)
       
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  Exportable.toZippedXml:
-    # ---------------------------------------------------------------------------------------------
-    def toZippedXml(self, REQUEST, get_data=True):
-      
+    # --------------------------------------------------------------------------
+    def toZippedXml(self, REQUEST, get_data=True, incl_embedded=False):
+
       #-- Create temporary folder.
       tempfolder = tempfile.mktemp()
-      ressources = self.exportRessources( tempfolder, REQUEST)
+      ressources = self.exportRessources( tempfolder, REQUEST, incl_embedded=incl_embedded)
       
       #-- Get xml-export.
-      xml = self.toXml(REQUEST)
+      xml = self.toXml(REQUEST,incl_embedded)
       
       #-- Write xml-export to file.
       xmlfilename = _fileutil.getOSPath('%s/%s_%s.xml'%(tempfolder,self.getHome().id,self.meta_type))
@@ -563,9 +562,9 @@ class Exportable:
       rtn = _fileutil.buildZipArchive( zipfiles, get_data)
       
       #-- Remove temporary folder.
-      _fileutil.remove( tempfolder, deep=1)
+      if not _globals.debug( self):
+        _fileutil.remove( tempfolder, deep=1)
       
       return rtn
 
-
-###################################################################################################
+################################################################################
