@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _fileutil.py
 #
 # $Id: _fileutil.py,v 1.9 2004/11/30 20:03:17 zmsdev Exp $
@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from App.Common import package_home
@@ -30,17 +30,18 @@ except: # < Zope-2.10
   from zope.app.content_types import guess_content_type
 import fnmatch
 import os
+import shutil
 import stat
 import tempfile
 import urllib
 import zipfile
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.importZexp:
 #
 # Import file from specified path.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def importZexp(self, path, filename):
   src_filename = path + filename
   dst_filename = INSTANCE_HOME + '/import/' + filename
@@ -48,60 +49,63 @@ def importZexp(self, path, filename):
     try: 
       os.stat(getOSPath(dst_filename)) 
     except OSError: 
-      cpFile(src_filename,dst_filename)
+      shutil.copy(src_filename,dst_filename)
   self.manage_importObject(filename)
   remove(dst_filename)
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.extractFilename:
 #
 #  Extract filename from path.
 #  IN:  path
-# -------------------------------------------------------------------------------------------------
-def extractFilename(path):
-  items = getOSPath(path).split(os.sep)
+# ------------------------------------------------------------------------------
+def extractFilename(path, sep=None):
+  if sep is None:
+    path = getOSPath(path) 
+  items = path.split( os.sep)
   lastitem = items[len(items)-1]
   return lastitem
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.extractFileExt:
 # 
 #  Extract fileextension from path.
 #  IN:  path
 #  OUT: extension
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def extractFileExt(path):
   items = path.split('.')
   lastitem = items[len(items)-1]
   return lastitem
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.getOSPath:
 # 
 #  Return path with OS separators.
-# -------------------------------------------------------------------------------------------------
-def getOSPath(path, sep=None):
+# ------------------------------------------------------------------------------
+def getOSPath(path, sep=None, chs=range(32)+[34,60,62,63,127]):
   if sep is None: sep = os.sep
   path = path.replace('\\',sep)
   path = path.replace('/',sep)
-  if type(path) is type(''):
+  if type( path) is type( ''):
     path = unicode(path, 'latin-1')
   path = path.encode('ascii', 'replace') # replace => uncodierbare Zeichen durch ? (63) ersetzen 
-  for ch in range(32)+[34,60,62,63,127]:
-    path = path.replace(chr(ch),'')
+  if len( chs) > 0:
+    for ch in chs:
+      path = path.replace(chr(ch),'')
   return path
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.getFilePath:
 #
 #  Extract filepath from path (cut-off filename).
 #  IN:  path
 #  OUT: filepath
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getFilePath(path):
   items = getOSPath(path).split(os.sep)
   filepath = ''
@@ -113,15 +117,15 @@ def getFilePath(path):
   return filepath
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.findExtension:
 #
-#  Searches path and all subdirectories for file with extension and returns complete filepath.
-#  Returns None if no file with specified extension exists.
+#  Searches path and all subdirectories for file with extension and returns 
+#  complete filepath. Returns None if no file with specified extension exists.
 #  IN:  extension
 #       path
 #  OUT: filepath
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def findExtension(extension, path, deep=1):
   rtn = None
   path = getOSPath(path)
@@ -138,30 +142,17 @@ def findExtension(extension, path, deep=1):
   return rtn
 
 
-# -------------------------------------------------------------------------------------------------
-#  _fileutil.cpFile:
-#
-#  Copies src to dst.
-# -------------------------------------------------------------------------------------------------
-def cpFile(src, dst):
-  f_src = open(getOSPath(src),'rb')
-  f_dst = open(getOSPath(dst),'wb')
-  f_dst.write(f_src.read())
-  f_dst.close()
-  f_src.close()
-
-
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.readPath:
 #
 #  Reads path.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def readPath(path, data=True, recursive=True):
   l = []
-  path = getOSPath(path)
-  filter = extractFilename(path)
-  if filter.find('*') >= 0 and \
-     filter.find('.') >= 0:
+  path = path.replace('\\',os.sep)
+  path = path.replace('/',os.sep)
+  filter = extractFilename(path, os.sep)
+  if filter.find('*') >= 0 and filter.find('.') >= 0:
     path = getFilePath( path)
   else:
     filter = None
@@ -172,8 +163,8 @@ def readPath(path, data=True, recursive=True):
       filename = extractFilename(local_filename)
       if filter is None or fnmatch.fnmatch(filename, filter):
         d = {}
-        d['local_filename']=local_filename
-        d['filename']=filename
+        d['local_filename']=unicode(local_filename,'latin-1').encode('utf-8')
+        d['filename']=unicode(filename,'latin-1').encode('utf-8')
         mode = os.stat(local_filename)[stat.ST_MODE]
         if stat.S_ISDIR(mode):
           if recursive:
@@ -186,7 +177,7 @@ def readPath(path, data=True, recursive=True):
         else:
           fdata = None
           if data:
-            fdata, mt, enc, fsize = readFile( local_filename)
+            fdata, mt, enc, fsize = readFile( local_filename, 'b', -1)
             d['data']=fdata
             d['content_type']=mt
             d['encoding']=enc
@@ -203,15 +194,14 @@ def readPath(path, data=True, recursive=True):
   return l
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.readFile:
 #
-#  Reads file.
-# -------------------------------------------------------------------------------------------------
-def readFile(filename, mode='b'):
-  threshold = 2 << 16 # 128 kb
+#  Reads file (threshold for filesteam_iterator is 128 kb).
+# ------------------------------------------------------------------------------
+def readFile(filename, mode='b', threshold=2 << 16):
   size = os.path.getsize( filename)
-  if size < threshold:
+  if size < threshold or -1 == threshold:
     try:
       f = open( filename, 'r'+mode)
       data = f.read()
@@ -223,11 +213,11 @@ def readFile(filename, mode='b'):
   return data, mt, enc, size
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.importPath:
 #
 #  Imports path.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def importPath(self, path):
   path = getOSPath(path)
   mode = os.stat(path)[stat.ST_MODE]
@@ -245,11 +235,11 @@ def importPath(self, path):
         f.close()
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.remove:
 #
 #  Removes path (and all its subdirectories if deep==1).
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def remove(path, deep=0):
   path = getOSPath(path)
   mode = os.stat(path)[stat.ST_MODE]
@@ -267,11 +257,11 @@ def remove(path, deep=0):
     os.remove(path)
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.getDataSizeStr: 
 #
 #  Display string for file-size.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getDataSizeStr(len):
   s = ''
   try:
@@ -280,30 +270,31 @@ def getDataSizeStr(len):
       len = len / 1024.0
       mod = mod + 1
     s = str(int(len))
+    n = str(int(10*(len - int(len))))
     if mod == 0:
       s = "%sBytes"%s
     elif mod == 1:
       s = "%sKB"%s
     elif mod == 2:
-      s = "%sMB"%s
+      s = "%s.%s MB"%(s,n)
     elif mod == 3:
-      s = "%sGB"%s
+      s = "%s.%s GB"%(s,n)
   except:
     pass
   return s
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.executeCommand:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def executeCommand(path, command):
   os.chdir(path)
   os.system(command)
 
     
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.exportObj:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def exportObj(obj, filename, filetype='b'):
     
   #-- Try to create directory-tree.
@@ -343,11 +334,11 @@ def exportObj(obj, filename, filetype='b'):
     objfile.close()
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.mkDir:
 #
 #  Make directory.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def mkDir(path):
   try:
     os.makedirs( path)
@@ -355,9 +346,9 @@ def mkDir(path):
     pass
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.readDir
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def readDir(path):
   obs = []
   path = getOSPath(path)
@@ -379,20 +370,20 @@ def readDir(path):
 
 
 """
-###################################################################################################
+################################################################################
 ###
 ###  P I L   I M A G I N G 
 ###
-###################################################################################################
+################################################################################
 """
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.createThumbnail:
 #
 #  Creates thumbnail of given image.
 #  IN:  img
 #  OUT: thumb
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def createThumbnail(img, maxdim=100):
   
   # Save image in temp-folder.
@@ -423,91 +414,19 @@ def createThumbnail(img, maxdim=100):
   return thumb
 
 
-# -------------------------------------------------------------------------------------------------
-#  _fileutil.resizeImage:
-#
-#  Resize given image.
-#  IN:  img
-#       perc
-#  OUT: resized
-# -------------------------------------------------------------------------------------------------
-def resizeImage(img, perc):
-  
-  # Save image in temp-folder.
-  tempfolder = tempfile.mktemp()
-  filename = urllib.quote(getOSPath('%s/%s'%(tempfolder,img.filename)), '/\:')
-  exportObj(img,filename)
-  
-  # Call PIL to generate resized image.
-  command = 'python ' + getOSPath(package_home(globals())+'/conf/pil/img_resize.py') + ' ' + str(img.width) + ' ' + str(img.height) + ' ' + filename
-  os.system(command)
-  
-  # Read resized image from file-system.
-  f = open(filename,'rb')
-  resized_data = f.read()
-  resized_filename = extractFilename(filename)
-  resized = {'data':resized_data,'filename':resized_filename}
-  f.close()
-  
-  # Remove temp-folder and images.
-  remove(tempfolder,deep=1)
-  
-  # Returns resized image.
-  return resized
-
-
-# -------------------------------------------------------------------------------------------------
-#  _fileutil.resizeImageXY:
-#
-#  Resize given image.
-#  IN:  img
-#       width
-#       height
-#  OUT: resized
-#  history:
-#       2004-06-12  <karsten@rohrbach.de>
-#                   created this function for precise scaling by width x height
-#                   corresponds to modified zmsgraphic.py and f_select_image.dtml
-#                   urllib.quote eliminates problems with spaces in filenames and such
-# -------------------------------------------------------------------------------------------------
-def resizeImageXY(img, width, height):
-  
-  # Save image in temp-folder.
-  tempfolder = tempfile.mktemp()
-  filename = urllib.quote(getOSPath('%s/%s'%(tempfolder,img.filename)), '/\:')
-  exportObj(img,filename)
-  
-  # Call PIL to generate resized image.
-  command = 'python ' + getOSPath(package_home(globals())+'/conf/pil/img_resize.py') + ' ' + str(img.width) + ' ' + str(img.height) + ' ' + filename
-  os.system(command)
-  
-  # Read resized image from file-system.
-  f = open(filename,'rb')
-  resized_data = f.read()
-  resized_filename = extractFilename(filename)
-  resized = {'data':resized_data,'filename':resized_filename}
-  f.close()
-  
-  # Remove temp-folder and images.
-  remove(tempfolder,deep=1)
-  
-  # Returns resized image.
-  return resized
-
-
 """
-###################################################################################################
+################################################################################
 ###
 ###  Z I P   A R C H I V E 
 ###
-###################################################################################################
+################################################################################
 """
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.getZipArchive:
 #
 #  Extract files from zip-archive and return list of extracted files.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getZipArchive(f):
   l = []
   
@@ -532,11 +451,11 @@ def getZipArchive(f):
   return l
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.extractZipArchive:
 #
 #  Unpack ZIP-Archive.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def extractZipArchive(file):
   zf = zipfile.ZipFile( file, 'r')
   for name in zf.namelist():
@@ -553,46 +472,49 @@ def extractZipArchive(file):
   zf.close()
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _fileutil.buildZipArchive:
 #
 #  Pack ZIP-Archive and return data.
-# -------------------------------------------------------------------------------------------------
-def _buildZipArchive( zf, folder, path, filter):
-  for file in os.listdir( folder + os.sep + path):
-    filepath = folder + os.sep + path + os.sep + file
+# ------------------------------------------------------------------------------
+def writeZipFile( zf, basepath, path, filter):
+  for file in os.listdir( path):
+    filepath = path+os.sep+file
     mode = os.stat( filepath)[stat.ST_MODE]
     if stat.S_ISDIR( mode): 
-      _buildZipArchive( zf, folder, filepath[ len( folder + os.sep): ], filter)
+      writeZipFile( zf, basepath, filepath, filter)
     else:
-      if fnmatch.fnmatch( extractFilename( filepath), filter):
-        zf.write( filepath, filepath[ len( folder + os.sep): ])
+      arcname = filepath[len( basepath)+1:]
+      match = False
+      for pattern in filter.split(';'):
+        match = match or fnmatch.fnmatch( arcname, pattern)
+      if match:
+        zf.write( filepath, arcname)
 
 def buildZipArchive( files, get_data=True):
   
-  # Create temporary zip-archive.
+  # Create temporary zip-file.
   zipfilename = tempfile.mktemp() + '.zip'
   
-  # Build temporary zip-archive.
+  # Write filtered files to zip-file.
   files = getOSPath( files)
-  folder = getFilePath( files)
+  path = getFilePath( files)
   filter = extractFilename( files)
-  path = ''
   zf = zipfile.ZipFile( zipfilename, 'w')
-  _buildZipArchive( zf, folder, path, filter)
+  writeZipFile( zf, path, path, filter)
   zf.close()
   
-  # Read data of zip-archive as return value.
+  # Read data from zip-file as return value.
   data = zipfilename
   if get_data:
     f = open( zipfilename, 'rb')
     data = f.read()
     f.close()
   
-    # Remove temporary zip-archive.
+    # Remove temporary zip-file.
     os.remove( zipfilename)
   
-  # Returns data of zip-archive.
+  # Returns filename or data of zip-file.
   return data
 
-###################################################################################################
+################################################################################
