@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _filtermanager.py
 #
 # $Id: _filtermanager.py,v 1.8 2004/11/24 21:02:52 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
@@ -40,16 +40,16 @@ import _globals
 
 
 """
-################################################################################################
+################################################################################
 #
 #   X M L   I M / E X P O R T
 #
-################################################################################################
+################################################################################
 """
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  importXml
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 def _importXml(self, item, zms_system=0, createIfNotExists=1):
   itemType = item.get('type')
@@ -96,9 +96,9 @@ def importXml(self, xml, REQUEST=None, zms_system=0, createIfNotExists=1):
   else:
     id = _importXml(self,v,zms_system,createIfNotExists)
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  exportXml
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def exportXml(self, REQUEST, RESPONSE):
   value = []
   ids = REQUEST.get('ids',[])
@@ -125,28 +125,28 @@ def exportXml(self, REQUEST, RESPONSE):
   return export
 
 """
-################################################################################################
+################################################################################
 #
 #   P R O C E S S E S
 #
-################################################################################################
+################################################################################
 """
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.getRawProcesses:
 #
 #  Returns raw dictionary of processes.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getRawProcesses(self):
   # Return attribute.
   return self.getConfProperty('ZMS.filter.processes',{})
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.setProcess:
 # 
 #  Set/add process specified by given Id.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def setProcess(self, newId, newAcquired=0, newName='', newType='process', newCommand=None, zms_system=0):
   if newCommand is None:
     if newType == 'DTML Method':
@@ -179,11 +179,11 @@ def setProcess(self, newId, newAcquired=0, newName='', newType='process', newCom
   return newId
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.delProcess:
 # 
 #  Delete process specified by given Id.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def delProcess(self, id):
   # Delete.
   cp = getRawProcesses(self)
@@ -205,18 +205,18 @@ def delProcess(self, id):
 
 
 """
-################################################################################################
+################################################################################
 #
 #   F I L T E R S
 #
-################################################################################################
+################################################################################
 """
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.getRawFilters:
 #
 #  Returns raw dictionary of filters.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getRawFilters(self):
   # Return attribute.
   raw = self.getConfProperty('ZMS.filter.filters',{})
@@ -227,11 +227,11 @@ def getRawFilters(self):
     f[ 'processes'] = processes
   return raw
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.setFilter:
 # 
 #  Set/add filter specified by given Id.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def setFilter(self, newId, newAcquired=0, newName='', newFormat='', newContentType='', newDescription='', newRoles=[], newMetaTypes=[], zms_system=0):
   # Set.
   obs = getRawFilters(self)
@@ -250,11 +250,11 @@ def setFilter(self, newId, newAcquired=0, newName='', newFormat='', newContentTy
   # Return with new id.
   return newId
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.delFilter:
 # 
 #  Delete filter specified by given Id.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def delFilter(self, id):
   # Delete.
   cp = getRawFilters(self)
@@ -269,18 +269,18 @@ def delFilter(self, id):
 
 
 """
-################################################################################################
+################################################################################
 #
 #   F I L T E R - P R O C E S S E S
 #
-################################################################################################
+################################################################################
 """
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.setFilterProcess:
 # 
 #  Set/add filter-process specified by given id.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def setFilterProcess(self, id, newProcessId, newProcessFile=None):
   # Set.
   obs = getRawFilters(self)
@@ -296,11 +296,11 @@ def setFilterProcess(self, id, newProcessId, newProcessFile=None):
   return len(pobs)-1
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.delFilterProcess:
 # 
 #  Delete filter-process specified by given Ids.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def delFilterProcess(self, id, pid):
   # Delete.
   obs = getRawFilters(self)
@@ -314,11 +314,11 @@ def delFilterProcess(self, id, pid):
   return -1
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.moveFilterProcess:
 # 
 #  Move filter-process specified by given Ids to specified position.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def moveFilterProcess(self, id, pid, pos):
   if _globals.debug( self):
     _globals.writeLog( self, '[moveFilterProcess]:id=%s; pid=%s; dir=%s'%(id,str(pid),str(dir)))
@@ -332,22 +332,22 @@ def moveFilterProcess(self, id, pid, pos):
   # Set attribute.
   self.setConfProperty('ZMS.filter.filters',obs.copy())
   # Return with new id.
-  return pid+dir
+  return pos
 
 
 """
-################################################################################################
+################################################################################
 #
 #   I M / E X P O R T
 #
-################################################################################################
+################################################################################
 """
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.processData:
 #
 #  Process data with custom transformation.
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def processData(self, processId, data, trans=None):
   # Create temporary folder.
   folder = tempfile.mktemp()
@@ -371,25 +371,19 @@ def processData(self, processId, data, trans=None):
   return data
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.processMethod:
 #
 #  Process DTML method.
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def processMethod(self, processId, filename, trans, REQUEST):
   if _globals.debug( self):
     _globals.writeLog( self, '[processMethod]: processId=%s'%processId)
   infilename = filename
   outfilename = filename
-  instance_home = INSTANCE_HOME
-  software_home = os.path.join(SOFTWARE_HOME, '..%s..' % os.sep)
-  software_home = os.path.normpath(software_home)  
   REQUEST.set( 'ZMS_FILTER_IN', infilename)
   REQUEST.set( 'ZMS_FILTER_OUT', outfilename)
   REQUEST.set( 'ZMS_FILTER_TRANS', trans)
-  REQUEST.set( 'ZMS_FILTER_SOFTWARE_HOME', software_home)
-  REQUEST.set( 'ZMS_FILTER_INSTANCE_HOME', instance_home)
-  REQUEST.set( 'ZMS_FILTER_HOME', _fileutil.getOSPath(package_home(globals())))
   REQUEST.set( 'ZMS_FILTER_CUR_DIR', _fileutil.getFilePath(infilename))
   try:
     value = getattr( self, processId)( self, REQUEST)
@@ -400,11 +394,11 @@ def processMethod(self, processId, filename, trans, REQUEST):
   return outfilename
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.processCommand:
 #
 #  Process file with command.
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def processCommand(self, filename, command):
   if _globals.debug( self):
     _globals.writeLog( self, '[processCommand]: infilename=%s'%filename)
@@ -457,11 +451,11 @@ def processCommand(self, filename, command):
   return outfilename
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.processFile:
 #
 #  Process file with custom transformation.
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def processFile(self, processId, filename, trans=None):
   if _globals.debug( self):
     _globals.writeLog( self, '[processFile]: processId=%s'%processId)
@@ -478,9 +472,9 @@ def processFile(self, processId, filename, trans=None):
   return filename
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.processFilter:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def processFilter(self, ob_filter, folder, filename, REQUEST):
   for process in ob_filter.get('processes',[]):
     processId = process.get( 'id')
@@ -500,9 +494,9 @@ def processFilter(self, ob_filter, folder, filename, REQUEST):
   return filename
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.importFilter:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def importFilter(self, filename, id, REQUEST):
   ob_filter = self.getFilter(id)
   folder = _fileutil.getFilePath(filename)
@@ -512,39 +506,58 @@ def importFilter(self, filename, id, REQUEST):
   return filename
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _filtermanager.exportFilter:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def exportFilter(self, id, REQUEST):
   ob_filter = self.getFilter(id)
+  ob_filter_format = ob_filter.get('format','')
+  incl_embedded = ob_filter_format == 'XML_incl_embedded'
   # Create temporary folder.
   tempfolder = tempfile.mktemp()
-  ressources = self.exportRessources( tempfolder, REQUEST)
-  if ob_filter.get('format','') == 'export':
+  ressources = self.exportRessources( tempfolder, REQUEST, from_content=True, from_zms=ob_filter_format=='XHTML', from_common=ob_filter_format=='XHTML', incl_embedded=incl_embedded)
+  # Set environment variables.
+  instance_home = INSTANCE_HOME
+  software_home = os.path.join(SOFTWARE_HOME, '..%s..' % os.sep)
+  software_home = os.path.normpath(software_home)  
+  REQUEST.set( 'ZMS_FILTER_SOFTWARE_HOME', software_home)
+  REQUEST.set( 'ZMS_FILTER_INSTANCE_HOME', instance_home)
+  REQUEST.set( 'ZMS_FILTER_PACKAGE_HOME', _fileutil.getOSPath(package_home(globals())))
+  # Export data to file.
+  if ob_filter_format == 'export':
     outfilename = _fileutil.getOSPath('%s/INDEX0'%tempfolder)
-  elif ob_filter.get('format','') == 'XHTML':
+  elif ob_filter_format in ['XML','XML_incl_embedded']:
+    # Set XML.
+    data = self.toXml( REQUEST, incl_embedded)
+    outfilename = _fileutil.getOSPath('%s/export.xml'%tempfolder)
+    _fileutil.exportObj( data, outfilename)
+  elif ob_filter_format == 'XHTML':
     # Set XHTML.
     data = self.toXhtml( REQUEST)
     outfilename = _fileutil.getOSPath('%s/export.html'%tempfolder)
     _fileutil.exportObj( data, outfilename)
-  elif ob_filter.get('format','') == 'XML':
-    # Set XML.
-    data = self.toXml( REQUEST)
+  elif ob_filter_format == 'myXML':
+    # Set myXML.
+    data = self.getXmlHeader() + getattr( self, 'getObjToXml_DocElmnt')(context=self)
     outfilename = _fileutil.getOSPath('%s/export.xml'%tempfolder)
     _fileutil.exportObj( data, outfilename)
   else:
-    raise "Unkown formmat '%s'"%ob_filter.get('format','')
+    raise "Unknown format '%s'"%ob_filter.get('format','')
   # Process filter.
   outfilename = processFilter(self, ob_filter, tempfolder, outfilename, REQUEST)
   # Return values.
   content_type = ob_filter.get('content_type','content/unknown')
   filename = 'exportFilter.%s'%content_type[content_type.find('/')+1:]
+  # Zip File.
+  if content_type == 'application/zip':
+    data = _fileutil.buildZipArchive( outfilename, get_data=True)
   # Read File.
-  if _globals.debug( self):
-    _globals.writeLog( self, '[exportFilter]: Read %s'%outfilename)
-  f = open(outfilename, 'rb')
-  data = f.read()
-  f.close()
+  else:
+    if _globals.debug( self):
+      _globals.writeLog( self, '[exportFilter]: Read %s'%outfilename)
+    f = open(outfilename, 'rb')
+    data = f.read()
+    f.close()
   # Remove temporary folder.
   if not _globals.debug( self):
     _fileutil.remove( tempfolder, deep=1)
@@ -552,13 +565,13 @@ def exportFilter(self, id, REQUEST):
   return filename, data, content_type
 
 
-################################################################################################
-################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class FilterManager
 ###
-################################################################################################
-################################################################################################
+################################################################################
+################################################################################
 class FilterManager: 
 
     # Management Interface.
@@ -566,11 +579,11 @@ class FilterManager:
     manage_customizeFilterForm = HTMLFile('dtml/zms/manage_customizefilterform', globals())
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  FilterManager.getProcessIds:
     # 
     #  Returns list of process-Ids.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getProcessIds(self, sort=1):
       obs = getRawProcesses(self)
       ids = obs.keys()
@@ -583,11 +596,11 @@ class FilterManager:
         ids = map(lambda x: x[1],mapping)
       return ids
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  FilterManager.getProcess:
     # 
     #  Returns process specified by Id.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getProcess(self, id):
       obs = getRawProcesses(self)
       ob = {}
@@ -604,11 +617,11 @@ class FilterManager:
       return ob
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  FilterManager.getFilterIds:
     # 
     #  Returns list of filter-Ids.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getFilterIds(self, sort=1):
       obs = getRawFilters(self)
       ids = obs.keys()
@@ -619,11 +632,11 @@ class FilterManager:
       return ids
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  FilterManager.getFilter:
     # 
     #  Returns filter specified by Id.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getFilter(self, id):
       obs = getRawFilters(self)
       ob = {}
@@ -639,11 +652,11 @@ class FilterManager:
       return ob
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  FilterManager.getFilterProcesses:
     # 
     #  Returns list of processes for filter specified by Id.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getFilterProcesses(self, id):
       obs = []
       for process in self.getFilter( id).get( 'processes', []):
@@ -655,12 +668,12 @@ class FilterManager:
       return obs
 
 
-    ###############################################################################################
+    ############################################################################
     #  FilterManager.manage_changeFilter:
     #
     #  Customize filter.
-    ###############################################################################################
-    def manage_changeFilter(self, lang, manage_lang, btn='', key='', REQUEST=None, RESPONSE=None):
+    ############################################################################
+    def manage_changeFilter(self, lang, btn='', key='', REQUEST=None, RESPONSE=None):
       """ FilterManager.manage_changeFilter """
       message = ''
       id = REQUEST.get('id','')
@@ -668,15 +681,15 @@ class FilterManager:
 
       # Acquire.
       # --------
-      if btn == self.getLangStr('BTN_ACQUIRE',manage_lang):
+      if btn == self.getZMILangStr('BTN_ACQUIRE'):
         newId = REQUEST.get('aq_id')
         newAcquired = 1
         id = setFilter(self, newId, newAcquired)
-        message = self.getLangStr('MSG_INSERTED',manage_lang)%id
+        message = self.getZMILangStr('MSG_INSERTED')%id
 
       # Change.
       # -------
-      elif btn == self.getLangStr('BTN_CHANGE',manage_lang):
+      elif btn == self.getZMILangStr('BTN_CHANGE'):
 	cp = self.getFilter(id)
 	# Filter.
         newId = REQUEST.get('inpId').strip()
@@ -701,25 +714,25 @@ class FilterManager:
               newProcessFile = _blobfields.createBlobField(self, _globals.DT_FILE, newProcessFile)
           setFilterProcess(self, id, newProcessId, newProcessFile)
           c += 1
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
 
       # Delete.
       # -------
-      elif btn == self.getLangStr('BTN_DELETE',manage_lang) and key == 'obj':
+      elif btn == self.getZMILangStr('BTN_DELETE') and key == 'obj':
         id = delFilter(self, id)
-        message = self.getLangStr('MSG_DELETED',manage_lang)%int(1)
+        message = self.getZMILangStr('MSG_DELETED')%int(1)
       elif btn == 'delete' and key == 'attr':
         pid = delFilterProcess(self, id, pid)
-        message = self.getLangStr('MSG_DELETED',manage_lang)%int(1)
+        message = self.getZMILangStr('MSG_DELETED')%int(1)
 
       # Export.
       # -------
-      elif btn == self.getLangStr('BTN_EXPORT',manage_lang):
+      elif btn == self.getZMILangStr('BTN_EXPORT'):
         return exportXml(self, REQUEST, RESPONSE)
 
       # Import.
       # -------
-      elif btn == self.getLangStr('BTN_IMPORT',manage_lang):
+      elif btn == self.getZMILangStr('BTN_IMPORT'):
         f = REQUEST['file']
         if f:
           filename = f.filename
@@ -728,11 +741,11 @@ class FilterManager:
           filename = REQUEST['init']
           createIfNotExists = 1
           self.importConf(filename, REQUEST, createIfNotExists)
-        message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%filename)
+        message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%filename)
 
       # Insert.
       # -------
-      elif btn == self.getLangStr('BTN_INSERT',manage_lang):
+      elif btn == self.getZMILangStr('BTN_INSERT'):
         if key == 'obj':
           newId = REQUEST.get('newId').strip()
           newAcquired = 0
@@ -740,7 +753,7 @@ class FilterManager:
           newFormat = REQUEST.get('newFormat').strip()
           newContentType = REQUEST.get('newContentType').strip()
           id = setFilter(self, newId, newAcquired, newName, newFormat, newContentType)
-          message = self.getLangStr('MSG_INSERTED',manage_lang)%id
+          message = self.getZMILangStr('MSG_INSERTED')%id
         elif key == 'attr':
           newProcessId = REQUEST.get('newFilterProcessId')
           newProcessFile = REQUEST.get('newFilterProcessFile')
@@ -750,33 +763,33 @@ class FilterManager:
             else:
               newProcessFile = _blobfields.createBlobField(self, _globals.DT_FILE, newProcessFile)
           pid = setFilterProcess(self, id, newProcessId, newProcessFile)
-          message = self.getLangStr('MSG_INSERTED',manage_lang)%newProcessId
+          message = self.getZMILangStr('MSG_INSERTED')%newProcessId
 
       # Move to.
       # --------
       elif btn == 'move_to':
         pos = REQUEST['pos']
         pid = moveFilterProcess(self, id, pid, pos)
-        message = self.getLangStr('MSG_MOVEDOBJTOPOS', manage_lang)%(("<i>%s</i>"%pid),(pos+1))
+        message = self.getZMILangStr('MSG_MOVEDOBJTOPOS')%(("<i>%s</i>"%pid),(pos+1))
 
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_customizeFilterForm?id=%s&pid:int=%i&lang=%s&manage_lang=%s&manage_tabs_message=%s'%(id,pid,lang,manage_lang,message))
+      return RESPONSE.redirect('manage_customizeFilterForm?id=%s&pid:int=%i&lang=%s&manage_tabs_message=%s'%(id,pid,lang,message))
 
 
-    ###############################################################################################
+    ############################################################################
     #  FilterManager.manage_changeProcess:
     #
     #  Customize process.
-    ###############################################################################################
-    def manage_changeProcess(self, lang, manage_lang, btn='', key='', REQUEST=None, RESPONSE=None):
+    ############################################################################
+    def manage_changeProcess(self, lang, btn='', key='', REQUEST=None, RESPONSE=None):
       """ FilterManager.manage_changeProcess """
       message = ''
       id = REQUEST.get('id','')
 
       # Change.
       # -------
-      if btn == self.getLangStr('BTN_CHANGE',manage_lang):
+      if btn == self.getZMILangStr('BTN_CHANGE'):
         newId = REQUEST.get('inpId').strip()
         newAcquired = 0
         newName = REQUEST.get('inpName').strip()
@@ -784,22 +797,22 @@ class FilterManager:
         newCommand = REQUEST.get('inpCommand').strip()
         id = delProcess(self, id)
         id = setProcess(self, newId, newAcquired, newName, newType, newCommand)
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
 
       # Delete.
       # -------
-      elif btn == self.getLangStr('BTN_DELETE',manage_lang):
+      elif btn == self.getZMILangStr('BTN_DELETE'):
         id = delProcess(self, id)
-        message = self.getLangStr('MSG_DELETED',manage_lang)%int(1)
+        message = self.getZMILangStr('MSG_DELETED')%int(1)
 
       # Export.
       # -------
-      elif btn == self.getLangStr('BTN_EXPORT',manage_lang):
+      elif btn == self.getZMILangStr('BTN_EXPORT'):
         return exportXml(self, REQUEST, RESPONSE)
 
       # Import.
       # -------
-      elif btn == self.getLangStr('BTN_IMPORT',manage_lang):
+      elif btn == self.getZMILangStr('BTN_IMPORT'):
         f = REQUEST['file']
         if f:
           filename = f.filename
@@ -808,20 +821,20 @@ class FilterManager:
           filename = REQUEST['init']
           createIfNotExists = 1
           self.importConf(filename, REQUEST, createIfNotExists)
-        message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%filename)
+        message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%filename)
 
       # Insert.
       # -------
-      elif btn == self.getLangStr('BTN_INSERT',manage_lang):
+      elif btn == self.getZMILangStr('BTN_INSERT'):
         newId = REQUEST.get('newId').strip()
         newAcquired = 0
         newName = REQUEST.get('newName').strip()
         newType = REQUEST.get('newType').strip()
         id = setProcess(self, newId, newAcquired, newName, newType)
-        message = self.getLangStr('MSG_INSERTED',manage_lang)%id
+        message = self.getZMILangStr('MSG_INSERTED')%id
 
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_customizeFilterForm?id=%s&lang=%s&manage_lang=%s&manage_tabs_message=%s'%(id,lang,manage_lang,message))
+      return RESPONSE.redirect('manage_customizeFilterForm?id=%s&lang=%s&manage_tabs_message=%s'%(id,lang,message))
 
-###################################################################################################
+################################################################################
