@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _globals.py
 #
 # $Id: _globals.py,v 1.12 2004/11/24 21:02:52 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from Acquisition import Implicit
@@ -100,9 +100,9 @@ dtMapping = [
 ]
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.datatype_key:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def datatype_key(datatype):
   for dtIndex in range(len(dtMapping)):
     if dtMapping[dtIndex][0] == datatype:
@@ -111,36 +111,36 @@ def datatype_key(datatype):
     return DT_UNKNOWN
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.format_sort_id:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def format_sort_id(i_sort_id):
   sort_id = '0000%i'%i_sort_id
   sort_id = 's' + sort_id[-4:]
   return sort_id
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.filename_quote:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def filename_quote(filename):
   for ch in ['+','%',' ','!','?','#','"']:
     filename = filename.replace(ch,'')
   return filename
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.html_quote:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def html_quote(v, name='(Unknown name)', md={}):
   return cgi.escape(str(v), 1)
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.unencode:
 #
 #  Unencodes given parameter.
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def unencode( p, enc='utf-8'):
   if type( p) is dict:
     for key in p.keys():
@@ -159,11 +159,10 @@ def unencode( p, enc='utf-8'):
   return p
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.id_quote:
-# -------------------------------------------------------------------------------------------------
-def id_quote(srctext):
-  dsttext = srctext
+# ------------------------------------------------------------------------------
+def id_quote(s):
   mapping = {
   	'\x20':'_',
   	'-':'_',
@@ -177,22 +176,19 @@ def id_quote(srctext):
   	unicode('\xdf','latin-1').encode('utf-8'):'ss',
   }
   for key in mapping.keys():
-    dsttext = dsttext.replace(key,mapping[key])
-  for ch in range(256):
-    if not (ch in [ord('_')] or \
-    	    ch in range(ord('0'),ord('9')+1) or \
-    	    ch in range(ord('A'),ord('Z')+1) or \
-    	    ch in range(ord('a'),ord('z')+1)):
-      dsttext = dsttext.replace(chr(ch),'')
-  dsttext = dsttext.lower()
-  return dsttext
+    s = s.replace(key,mapping[key])
+  valid = [ord('_')] + range(ord('0'),ord('9')+1) + range(ord('A'),ord('Z')+1) + range(ord('a'),ord('z')+1)
+  s = filter( lambda x: ord(x) in valid, s)
+  while len(s) > 0 and s[0] == '_': s = s[1:]
+  s = s.lower()
+  return s
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.strip_int:
 #
 #  Strips numeric part from string.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def strip_int(s):
   i = 0
   while i < len(s) and ord(s[i]) in range(ord('0'),ord('9')+1):
@@ -200,11 +196,11 @@ def strip_int(s):
   return i
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.id_prefix:
 #
 #  Strips non-numeric part from string.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def id_prefix(s): 
   i = 0
   while i < len(s) and ord(s[i]) not in range(ord('0'),ord('9')+1):
@@ -212,32 +208,35 @@ def id_prefix(s):
   return s[:i]
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.map_key_vals:
 #
 #  Maps list of keys and list of values to new dictionary.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def map_key_vals(keys, vals):
   d = {}
   map(operator.setitem, [d]*len(keys), keys, vals)
   return d
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.objectTree:
-# -------------------------------------------------------------------------------------------------
-def objectTree(self):
+# ------------------------------------------------------------------------------
+def objectTree(self, clients=False):
   rtn = [ self]
   for ob in self.objectValues( self.dGlobalAttrs.keys()):
     rtn.extend( objectTree( ob))
+  if clients:
+    for ob in self.getPortalClients():
+      rtn.extend( objectTree( ob, clients))
   return rtn
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.dt_html:
 #
 #  Process dtml.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def dt_html(self, value, REQUEST): 
   import DocumentTemplate.DT_HTML
   i = 0
@@ -251,21 +250,17 @@ def dt_html(self, value, REQUEST):
     if value[ j-1] == '/':
       value = value[ :j-1] + value[ j:]
     i = j
-  while True:
-    if value.find( '</dtml-var>') >= 0:
-      value = value.replace( '</dtml-var>', '')
-    else:
-      break
+  value = re.sub( '</dtml-var>', '', value)
   dtml = DocumentTemplate.DT_HTML.HTML(value)
   value = dtml( self, REQUEST)
   return value
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.dt_parse:
 #
 #  Parse and validate dtml.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def dt_parse(self, value):
   message = ''
   try:
@@ -277,11 +272,11 @@ def dt_parse(self, value):
   return message
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.form_quote
 #
 #  Remove <form>-tags for Management Interface.
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def form_quote(text, REQUEST):
   rtn = text
   if isManagementInterface(REQUEST):
@@ -291,25 +286,25 @@ def form_quote(text, REQUEST):
   return rtn
 
   
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.qs_append:
 #
 #  Append to Query-String.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def qs_append(qs, p, v):
   if len(qs) == 0:
     qs += '?'
   else:
-    qs += '&'
+    qs += '&amp;'
   qs += p + '=' + urllib.quote(v)
   return qs
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.nvl:
 #
 #  Returns its first argument if it is not None, otherwise it returns its second argument.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def nvl(a1, a2):
   if a1 is not None:
     return a1
@@ -317,40 +312,31 @@ def nvl(a1, a2):
     return a2
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.isManagementInterface
 #
 #  Returns true if current context is management-interface, false else.
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def isManagementInterface(REQUEST):
   return REQUEST is not None and \
          REQUEST.get('URL','').find('/manage') >= 0 and \
          isPreviewRequest(REQUEST)
      
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.isPreviewRequest:
 #
 #  Returns true if current context is preview-request, false else.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def isPreviewRequest(REQUEST):
   return REQUEST is not None and \
          REQUEST.get('preview','') == 'preview' and \
          REQUEST.get('live','') == ''
 
 
-# -------------------------------------------------------------------------------------------------
-#  _globals.isCacheRequest:
-#
-#  Returns true if current context is cache-request, false else.
-# -------------------------------------------------------------------------------------------------
-def isCacheRequest(REQUEST):
-  return not isPreviewRequest(REQUEST) and REQUEST.get('__cache__',0) == 1
-
-
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.getPageWithElements:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getPageWithElements(self, REQUEST):
   obs = self.getChildNodes(REQUEST)
   for ob in obs:
@@ -364,16 +350,16 @@ def getPageWithElements(self, REQUEST):
 
 
 """
-###############################################################################################
+################################################################################
 #
 #  Http
 #
-###############################################################################################
+################################################################################
 """
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.unescape:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def unescape(s):
   while 1:
     i = s.find('%')
@@ -384,11 +370,11 @@ def unescape(s):
   return s
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.authtobasic:
 #
 #  Basic Authentication
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def authtobasic(auth, h): 
  """Converts basic auth data into an HTTP header."""
  import base64
@@ -398,9 +384,9 @@ def authtobasic(auth, h):
    h.putheader('Authorization', 'Basic '+userpass)
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.http_import:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def http_import(self, url, method='GET', auth=None, parse_qs=0):
 
   # Remove HTTP-Prefix.
@@ -483,9 +469,9 @@ def http_import(self, url, method='GET', auth=None, parse_qs=0):
     return result
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.get_size:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def get_size(v):
   size = 0
   if v is not None:
@@ -497,6 +483,11 @@ def get_size(v):
       size = sum( map( lambda x: get_size(x) + get_size(v[x]), v.keys()))
     elif type(v) is int or type(v) is float:
       size = size + 4
+    elif hasattr(v,'get_real_size') and callable(getattr(v,'get_real_size')):
+      try:
+        size = size + v.get_real_size()
+      except:
+        pass
     elif hasattr(v,'get_size') and callable(getattr(v,'get_size')):
       try:
         size = size + v.get_size()
@@ -506,16 +497,16 @@ def get_size(v):
 
 
 """
-###############################################################################################
+################################################################################
 #
 #  Traces
 #
-###############################################################################################
+################################################################################
 """
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.debug:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def debug(self):
   has_zms_log = False
   try:
@@ -528,9 +519,9 @@ def debug(self):
     pass
   return has_zms_log
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.writeLog:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def writeLog(self, info):
   try:
     zms_log = getattr( self, 'zms_log', None)
@@ -541,9 +532,9 @@ def writeLog(self, info):
   except:
     pass
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.writeBlock:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def writeBlock(self, info):
   try:
     zms_log = getattr( self, 'zms_log', None)
@@ -554,9 +545,9 @@ def writeBlock(self, info):
   except:
     pass
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.writeException:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def writeException(self, etc=''):
   info = '?'
   try:
@@ -567,7 +558,6 @@ def writeException(self, etc=''):
     remove = [r"<[^<>]*>", r"&[A-Za-z]+;"]
     for pat in remove:
       v = re.sub(pat,' ', v)
-    from traceback import format_exception
     if etc: etc += '\n'
     severity = logging.ERROR
     info = etc+''.join(format_exception(t, v, tb))
@@ -581,14 +571,14 @@ def writeException(self, etc=''):
 
 
 """
-###############################################################################################
+################################################################################
 #
 #  DateTime
 #
-###############################################################################################
+################################################################################
 """
 
-# ==========================================================================
+# ==============================================================================
 # Index  Field  Values  
 # 0  year (for example, 1993) 
 # 1  month range [1,12] 
@@ -599,9 +589,9 @@ def writeException(self, etc=''):
 # 6  weekday range [0,6], Monday is 0 
 # 7  Julian day range [1,366] 
 # 8  daylight savings flag 0, 1 or -1; see below 
-# ==========================================================================
+# ==============================================================================
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.getDateTime:
 #
 #  Bei Python 2.2 ist der Typ der Objekte des Moduls "time" nicht
@@ -610,7 +600,7 @@ def writeException(self, etc=''):
 #  This is no problem for Zope since Zope uses its own, more flexible, type
 #  DateTime. Nevertheless ZMS relies on the datatype "tuple" as DateTime has 
 #  the limitation that no date prior to 1970-01-01 can be used!
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getDateTime(t):
   if t is not None:
     try:
@@ -622,11 +612,11 @@ def getDateTime(t):
       pass
   return t
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.stripDateTime:
 #
 #  Strips time portion from date-time and returns date.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def stripDateTime(t):
   d = None
   if t is not None:
@@ -634,23 +624,23 @@ def stripDateTime(t):
     d = (t[0],t[1],t[2],0,0,0,t[6],t[7],t[8])
   return d
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.daysBetween:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def daysBetween(t0, t1):
   t0 = time.mktime(stripDateTime(getDateTime(t0)))
   t1 = time.mktime(stripDateTime(getDateTime(t1)))
   d = 24.0*60.0*60.0
   return int((t1-t0)/d)
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.compareDate:
 #
 #  Compares two dates and returns result.
 #   +1: t0 < t1
 #    0: t0 == t1
 #   -1: t0 > t1
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def compareDate(t0, t1, accuracy_time=1):
   YEAR = 0
   MONTH = 1
@@ -685,9 +675,9 @@ def compareDate(t0, t1, accuracy_time=1):
   else:
     return -1
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _globals.parseLangFmtDate:
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def parseLangFmtDate(s):
   value = None
   for fmt in ['%d.%m.%Y %H:%M:%S','%Y/%m/%d %H:%M:%S','%H:%M:%S']:
@@ -727,55 +717,55 @@ def parseLangFmtDate(s):
   return value
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class MyClass:
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class MyClass:
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  MyClass.keys:
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def keys(self):
     return self.__dict__.keys()
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class MySectionizer
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class MySectionizer:
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MySectionizer.__init__:
     #
     #  Constructor.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __init__(self):
       self.sections = []
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MySectionizer.__str__:
     #
     #  Returns a string representation of the object.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __str__(self):
       s = ''
       for i in range(len(self.sections)):
         s += '%i.'%self.sections[i]
       return s
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MySectionizer.clone:
     #
     #  Creates and returns a copy of this object.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def clone(self):
       ob = MySectionizer()
       ob.sections = copy.deepcopy(self.sections)
@@ -798,28 +788,28 @@ class MySectionizer:
           self.sections[level-1] = self.sections[level-1] + 1
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class MyStack
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class MyStack:
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyStack.__init__:
     #
     #  Constructor.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __init__(self):
       self.clear()
         
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MyStack.__str__:
     #
     #  Returns a string representation of the object.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __str__(self):
       s = ''
       for el in self._stack:
@@ -856,4 +846,4 @@ class MyStack:
       else:
         return None
 
-###################################################################################################
+################################################################################
