@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _metadictmanager.py
 #
 # $Id: _metadictmanager.py,v 1.8 2004/11/24 21:02:52 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
@@ -33,16 +33,16 @@ import _globals
 
 
 """
-################################################################################################
+################################################################################
 #
 #   X M L   I M / E X P O R T
 #
-################################################################################################
+################################################################################
 """
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metadictmanager.importXml
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 def _importXml(self, item, zms_system=0, createIfNotExists=1):
   id = item['id']
@@ -56,11 +56,13 @@ def _importXml(self, item, zms_system=0, createIfNotExists=1):
     newType = item['type']
     newMandatory = item.get('mandatory',0)
     newMultilang = item.get('multilang',1)
+    newRepetitive = item.get('repetitive',0)
     newKeys = item.get('keys',[])
     newCustom = item.get('custom','')
     newDstMetaTypes = item.get('dst_meta_types',[])
-    setMetadictAttr(self, None, newId, newAcquired, newName, newType, newMandatory, newMultilang, \
-      newCustom, newKeys, newDstMetaTypes, zms_system )
+    setMetadictAttr(self, None, newId, newAcquired, newName, newType, \
+      newMandatory, newMultilang, newRepetitive, newCustom, newKeys, \
+      newDstMetaTypes, zms_system )
 
 def importXml(self, xml, REQUEST=None, zms_system=0, createIfNotExists=1):
   v = self.parseXmlString(xml)
@@ -72,9 +74,9 @@ def importXml(self, xml, REQUEST=None, zms_system=0, createIfNotExists=1):
   self.synchronizeObjAttrs()
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metadictmanager.getAttrName
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getAttrName(id):
   s_attr = id
   s_attr = s_attr.lower()
@@ -83,12 +85,12 @@ def getAttrName(id):
   return s_attr
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metadictmanager.renameMetadictAttrs
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def renameMetadictAttrs(self, old_attr, new_attr):
   if self.meta_type[:3] == 'ZMS':
     for obj_vers in self.getObjVersions():
@@ -104,9 +106,9 @@ def renameMetadictAttrs(self, old_attr, new_attr):
     for ob in self.objectValues():
       renameMetadictAttrs(ob,old_attr,new_attr)
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metadictmanager.dropMetadictAttrs
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def dropMetadictAttrs(self, attr):
   if self.meta_type[:3] == 'ZMS':
     for s_lang in self.getLangIds():
@@ -121,14 +123,14 @@ def dropMetadictAttrs(self, attr):
       dropMetadictAttrs(ob,attr)
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metadictmanager.delMetadictAttr:
 # 
 #  Delete Meta-Attribute specified by given attr.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def delMetadictAttr(self, attr):
   # Delete.
   obs = self.__get_metadicts__()
@@ -141,13 +143,14 @@ def delMetadictAttr(self, attr):
   return ''
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metadictmanager.setMetadictAttr:
 # 
 #  Set/add Meta-Attribute with specified values.
-# -------------------------------------------------------------------------------------------------
-def setMetadictAttr(self, attr, newId, newAcquired, newName='', newType='', newMandatory=0, \
-      newMultilang=1, newCustom='', newKeys=[], newDstMetaTypes=[], zms_system=0):
+# ------------------------------------------------------------------------------
+def setMetadictAttr(self, attr, newId, newAcquired, newName='', newType='', \
+      newMandatory=0, newMultilang=1, newRepetitive=0, newCustom='', \
+      newKeys=[], newDstMetaTypes=[], zms_system=0):
   obs = self.__get_metadicts__()
   # Remove exisiting entry.
   if attr is None:
@@ -168,6 +171,7 @@ def setMetadictAttr(self, attr, newId, newAcquired, newName='', newType='', newM
   newValues['type'] = newType
   newValues['mandatory'] = newMandatory
   newValues['multilang'] = newMultilang
+  newValues['repetitive'] = newRepetitive
   newValues['keys'] = newKeys
   newValues['custom'] = newCustom
   newValues['dst_meta_types'] = newDstMetaTypes
@@ -180,11 +184,11 @@ def setMetadictAttr(self, attr, newId, newAcquired, newName='', newType='', newM
   return attr
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metadictmanager.moveMetadictAttr:
 #
 #  Moves Meta-Attribute specified by given attr to specified position.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def moveMetadictAttr(self, attr, pos):
   # Move.
   obs = self.__get_metadicts__()
@@ -201,13 +205,13 @@ def moveMetadictAttr(self, attr, pos):
   return ''
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class MetadictManager
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class MetadictManager: 
 
     # Management Interface.
@@ -216,20 +220,20 @@ class MetadictManager:
     manage_BigPictureMetadictForm = HTMLFile('dtml/metadict/manage_bigpicture', globals()) 
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetadictManager.__get_metadicts__:
     # 
     #  Returns list of DC.Metadictionaries.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __get_metadicts__(self):
       return self.getConfProperty('ZMS.custom.metas',[])
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetadictManager.getMetadictAttrs:
     # 
     #  Returns list of attributes of DC.Metadictionaries.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetadictAttrs(self, meta_type=None, exclude_types=[]):
       attrs = []
       obs = self.__get_metadicts__()
@@ -250,21 +254,20 @@ class MetadictManager:
       return attrs
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetadictManager.getMetadictAttr:
     # 
     #  Get Attribute for Meta-Dictionary specified by key.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetadictAttr(self, key):
       obs = self.__get_metadicts__()
       if key in obs:
         ob = obs[obs.index(key)+1].copy()
       # ZMSLinkElement must always have attr_dc_description!
       elif key == 'attr_dc_description':
-        manage_lang = self.getManageLanguage( self.getPrimaryLanguage())
         ob = {}
         ob['id'] = 'DC.Description'
-        ob['name'] = self.getLangStr('ATTR_DC_DESCRIPTION',manage_lang)
+        ob['name'] = self.getZMILangStr('ATTR_DC_DESCRIPTION')
         ob['type'] = 'text'
         ob['dst_meta_types'] = [self.meta_type]
       # Not found!
@@ -289,12 +292,12 @@ class MetadictManager:
       return ob
 
 
-    ###############################################################################################
+    ############################################################################
     #  MetadictManager.manage_changeMetadicts:
     #
     #  Change Meta-Attributes.
-    ###############################################################################################
-    def manage_changeMetadicts(self, btn, lang, manage_lang, REQUEST, RESPONSE=None):
+    ############################################################################
+    def manage_changeMetadicts(self, btn, lang, REQUEST, RESPONSE=None):
         """ MetadictManager.manage_changeMetadicts """        
         message = ''
         attr = REQUEST.get('attr','')
@@ -304,15 +307,15 @@ class MetadictManager:
           
           # Acquire.
           # --------
-          if btn == self.getLangStr('BTN_ACQUIRE', manage_lang):
+          if btn == self.getZMILangStr('BTN_ACQUIRE'):
             newId = REQUEST['aq_id']
             newAcquired = 1
             attr = setMetadictAttr(self, None, newId, newAcquired)
-            message = self.getLangStr('MSG_INSERTED', manage_lang)%attr
+            message = self.getZMILangStr('MSG_INSERTED')%attr
           
           # Change.
           # -------
-          elif btn == self.getLangStr('BTN_CHANGE', manage_lang): 
+          elif btn == self.getZMILangStr('BTN_CHANGE'): 
             oldAttr = attr
             newId = REQUEST['id'].strip()
             newAcquired = 0
@@ -320,38 +323,39 @@ class MetadictManager:
             newType = REQUEST['metatype'].strip()
             newMandatory = REQUEST.get('mandatory', 0)
             newMultilang = REQUEST.get('multilang', 0)
+            newRepetitive = REQUEST.get('repetitive', 0)
             newKeys = self.string_list(REQUEST.get('keys',''), '\n')
             newCustom = REQUEST.get('custom', '')
             newDstMetaTypes = REQUEST.get('dst_meta_types',[])
-            attr = setMetadictAttr(self, oldAttr, newId, newAcquired, newName, newType, newMandatory, newMultilang, newCustom, newKeys, newDstMetaTypes )
+            attr = setMetadictAttr(self, oldAttr, newId, newAcquired, newName, newType, newMandatory, newMultilang, newRepetitive, newCustom, newKeys, newDstMetaTypes )
             if oldAttr != attr:
               renameMetadictAttrs(self, oldAttr, attr)
               dropMetadictAttrs(self, oldAttr)
-            message = self.getLangStr('MSG_CHANGED', manage_lang)
+            message = self.getZMILangStr('MSG_CHANGED')
           
           # Copy.
           # -----
-          elif btn == self.getLangStr('BTN_COPY',manage_lang):
+          elif btn == self.getZMILangStr('BTN_COPY'):
             metaOb = self.getMetadictAttr(attr)
             if metaOb.get('acquired',0) == 1:
               masterRoot = getattr(self,self.getConfProperty('Portal.Master'))
-              masterDocElmnt = masterRoot.objectValues(['ZMS'])[0]
+              masterDocElmnt = masterRoot.content
               REQUEST.set('attrs',[attr])
-              xml =  masterDocElmnt.manage_changeMetadicts(self.getLangStr('BTN_EXPORT',manage_lang), lang, manage_lang, REQUEST, RESPONSE)
+              xml =  masterDocElmnt.manage_changeMetadicts(self.getZMILangStr('BTN_EXPORT'), lang, REQUEST, RESPONSE)
               importXml(self,xml=xml)
-              message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%attr)
+              message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%attr)
 
           # Delete.
           # -------
-          elif btn in ['delete',self.getLangStr('BTN_DELETE', manage_lang)]:
+          elif btn in ['delete',self.getZMILangStr('BTN_DELETE')]:
             oldAttr = attr
             attr = delMetadictAttr(self, oldAttr)
             dropMetadictAttrs(self, oldAttr)
-            message = self.getLangStr('MSG_DELETED', manage_lang)%int(1)
+            message = self.getZMILangStr('MSG_DELETED')%int(1)
           
           # Export.
           # -------
-          elif btn == self.getLangStr('BTN_EXPORT', manage_lang):
+          elif btn == self.getZMILangStr('BTN_EXPORT'):
             value = []
             attrs = REQUEST.get('attrs',[])
             metadicts = self.__get_metadicts__()
@@ -373,7 +377,7 @@ class MetadictManager:
           
           # Import.
           # -------
-          elif btn == self.getLangStr('BTN_IMPORT', manage_lang):
+          elif btn == self.getZMILangStr('BTN_IMPORT'):
             f = REQUEST['file']
             if f:
               filename = f.filename
@@ -382,23 +386,24 @@ class MetadictManager:
               filename = REQUEST['init']
               createIfNotExists = 1
               self.importConf(filename, REQUEST, createIfNotExists)
-            message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%filename)
+            message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%filename)
           
           # Insert.
           # -------
-          elif btn == self.getLangStr('BTN_INSERT', manage_lang):
+          elif btn == self.getZMILangStr('BTN_INSERT'):
             newId = REQUEST['_id'].strip()
             newAcquired = 0
             newName = REQUEST['_name'].strip()
             newType = REQUEST['_type'].strip()
             newMandatory = REQUEST.get('_mandatory',0)
             newMultilang = REQUEST.get('_multilang',0)
+            newRepetitive = REQUEST.get('_repetitive',0)
             newCustom = ''
             if newType == 'method':
               newCustom += '<!--// BO %s //-->\n\n'%newId
               newCustom += '<!--// EO %s //-->\n'%newId
-            attr = setMetadictAttr(self, None, newId, newAcquired, newName, newType, newMandatory, newMultilang, newCustom)
-            message = self.getLangStr('MSG_INSERTED', manage_lang)%attr
+            attr = setMetadictAttr(self, None, newId, newAcquired, newName, newType, newMandatory, newMultilang, newRepetitive, newCustom)
+            message = self.getZMILangStr('MSG_INSERTED')%attr
           
           # Move to.
           # --------
@@ -406,7 +411,7 @@ class MetadictManager:
             pos = REQUEST['pos']
             oldAttr = attr
             attr = moveMetadictAttr(self, oldAttr, pos)
-            message = self.getLangStr('MSG_MOVEDOBJTOPOS', manage_lang)%(("<i>%s</i>"%oldAttr),(pos+1))
+            message = self.getZMILangStr('MSG_MOVEDOBJTOPOS')%(("<i>%s</i>"%oldAttr),(pos+1))
           
           ##### Page-Extension ####
           if attr == 'attr_pageext':
@@ -418,15 +423,16 @@ class MetadictManager:
         
         # Handle exception.
         except:
+          _globals.writeException(self,"[manage_changeMetadicts]")
           error = str( sys.exc_type)
           if sys.exc_value:
             error += ': ' + str( sys.exc_value)
           target = self.url_append_params( target, { 'manage_tabs_error_message':error})
         
         # Return with message.
-        target = self.url_append_params( target, { 'lang':lang, 'manage_lang':manage_lang, 'attr':attr})
+        target = self.url_append_params( target, { 'lang':lang, 'attr':attr})
         if len( message) > 0:
           target = self.url_append_params( target, { 'manage_tabs_message':message})
         return RESPONSE.redirect( target)
 
-###################################################################################################
+################################################################################
