@@ -1,4 +1,4 @@
-################################################################################################
+################################################################################
 # _metaobjmanager.py
 #
 # $Id: _metaobjmanager.py,v 1.9 2004/11/24 21:02:52 zmsdev Exp $
@@ -21,43 +21,46 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
+from App.Common import package_home
 from Globals import HTMLFile
+from Products.ExternalMethod import ExternalMethod
 from Products.PythonScripts import PythonScript
 import ZPublisher.HTTPRequest
 import copy
 import sys
 # Product Imports.
 import _blobfields
+import _fileutil
 import _globals
 import _objattrs
 
 
 """
-################################################################################################
+################################################################################
 #
 #   K E Y S
 #
-################################################################################################
+################################################################################
 """
 
 CONF_METAOBJS = "ZMS.custom.objects"
 
 
 """
-################################################################################################
+################################################################################
 #
 #   X M L   I M / E X P O R T
 #
-################################################################################################
+################################################################################
 """
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metaobjmanager.importXml
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 def _importXml(self, item, zms_system=0, createIfNotExists=1):
   id = item['key']
@@ -85,7 +88,7 @@ def _importXml(self, item, zms_system=0, createIfNotExists=1):
       newKeys = attr.get('keys')
       newCustom = attr.get('custom')
       newDefault = attr.get('default','')
-      self._setMetaObjAttr( id, None, attr_id, newName, newMandatory, newMultilang, newRepetitive, newType, newKeys, newCustom, newDefault, zms_system )
+      self._setMetaObjAttr( id, attr_id, attr_id, newName, newMandatory, newMultilang, newRepetitive, newType, newKeys, newCustom, newDefault, zms_system)
     # Set Enabled.
     self.setConfProperty( '%s.enabled'%id, newEnabled )
 
@@ -99,55 +102,81 @@ def importXml(self, xml, REQUEST=None, zms_system=0, createIfNotExists=1):
   self.synchronizeObjAttrs()
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+#  _metaobjmanager.recurse_updateVersionPatch:
+#
+#  Update version patch.
+# ------------------------------------------------------------------------------
+def recurse_updateVersionPatch(docElmnt, self, REQUEST):
+  message = ''
+  container = self.getDocumentElement()
+  Special_Objects = getattr( container, 'Special_Objects', None)
+  if Special_Objects is None:
+    container.manage_addFolder( id='Special_Objects', title='Special Objects')
+    Special_Objects = filter( lambda x: x.id == 'Special_Objects', container.objectValues(['Folder']))[0]
+    for meta_id in self.getMetaobjIds():
+      meta_obj = self.getMetaobj(meta_id)
+      if not meta_obj[ 'acquired']:
+        for key in self.getMetaobjAttrIds( meta_id):
+          attr = self.getMetaobjAttr(meta_id, key)
+          if attr['type'] == 'method':
+            Special_Objects.manage_addDTMLMethod( meta_id+'.'+key, attr['type']+': '+attr['name'], attr['custom'])
+  return message
+
+
+# ------------------------------------------------------------------------------
 #  _metaobjmanager.getRawMetaobjs:
 #
 #  Returns raw dictionary of meta-objects.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getRawMetaobjs(self):
   return self.getConfProperty(CONF_METAOBJS,{})
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metaobjmanager.setMetaobj:
 # 
 #  Sets Meta-Object with specified values.
-# ----------------------------------------------------------------------------------------------
-def setMetaobj(self, id, ob, newDtml=None, newAttrs=[]):
+# ------------------------------------------------------------------------------
+def setMetaobj(self, id, meta_obj, newDtml=None, newAttrs=[]):
   obs = getRawMetaobjs(self)
 
+  # Create template.
   if newDtml is not None:  
-    # Properties of Template.
     tmpltId = getTemplateId( id)
-    tmpltTitle = 'Template: %s'%ob['name']
-    # Remove Template (deprecated use in document-element).
-    container = self.getDocumentElement()
-    if tmpltId in container.objectIds():
-      container.manage_delObjects( ids=[ tmpltId] )
-    # Insert Template.
+    tmpltTitle = 'Template: %s'%meta_obj['name']
     container = self.getHome()
     if tmpltId in container.objectIds():
-      container.manage_delObjects( ids=[ tmpltId] )
-    container.manage_addDTMLMethod( tmpltId, tmpltTitle, '' )
-    # Change Template.
-    dtml_method = getattr( container, tmpltId )
-    dtml_method.manage_edit( newDtml, tmpltTitle )
+      container.manage_delObjects( ids=[ tmpltId])
+    container.manage_addDTMLMethod( tmpltId, tmpltTitle, '')
+    dtml_method = getattr( container, tmpltId)
+    dtml_method.manage_edit( newDtml, tmpltTitle)
     dtml_method.manage_proxy( roles=[ 'Manager'])
   
-  # Set Meta-Object.
-  ob = ob.copy()
-  ob['__obj_attrs__'] = newAttrs
-  obs[id] = ob
+  # Set Attributes to Meta-Object.
+  meta_obj = meta_obj.copy()
+  meta_obj['__obj_attrs__'] = newAttrs
+  obs[id] = meta_obj
   self.setConfProperty(CONF_METAOBJS,obs.copy())
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metaobjmanager.delMetaobj:
 # 
 #  Delete Meta-Object specified by id.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def delMetaobj(self, id):
-  docElmnt = self.getDocumentElement()
+
+  # Handle methods.
+  ids = filter( lambda x: x.startswith(id+'.'), self.Special_Objects.objectIds( ['DTML Method']))
+  if ids:
+    self.Special_Objects.manage_delObjects( ids)
+  
+  # Delete template.
+  tmpltId = getTemplateId( id)
+  container = self.getHome()
+  if tmpltId in container.objectIds():
+    container.manage_delObjects( ids=[ tmpltId] )
   
   # Delete object.
   cp = getRawMetaobjs(self)
@@ -160,26 +189,16 @@ def delMetaobj(self, id):
         delMetaObjAttr(self, id, attr_id)
     else:
       obs[key] = cp[key]
-  
-  tmpltId = getTemplateId( id)
-  # Remove Template (deprecated use in document-element).
-  container = self.getDocumentElement()
-  if tmpltId in container.objectIds():
-    container.manage_delObjects( ids=[ tmpltId] )
-  # Delete Template.
-  container = self.getHome()
-  if tmpltId in container.objectIds():
-    container.manage_delObjects( ids=[ tmpltId] )
-  
+
   # Set Attributes to Meta-Object.
   self.setConfProperty(CONF_METAOBJS,obs.copy())
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metaobjmanager.findMetaobj
 #
 #  Search tree for instance of object with given meta-ids.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def findMetaobj(self, ids):
   if self.meta_type == 'ZMSCustom' and self.meta_id in ids:
     return self
@@ -190,32 +209,32 @@ def findMetaobj(self, ids):
   return None
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metaobjmanager.delMetaObjAttr:
 # 
 #  Delete Attribute from Meta-Object specified by id.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def delMetaObjAttr(self, id, attr_id):
   ob = self.__get_metaobj__(id)
   attrs = copy.copy(ob['__obj_attrs__'])
 
   # Delete Attribute.
-  docElmnt = self.getDocumentElement()
   cp = []
   for attr in attrs:
     if attr['id'] == attr_id:
-      # Handle Zope-Objects.
-      obId = attr['id']
-      obType = attr['type']
-      if obType in [ 'DTML Method', 'DTML Document', 'Script (Python)' ]:
-        # Remove Zope-Object (deprecated use in document-element).
-        container = self.getDocumentElement()
-        if obId in container.objectIds([obType]):
-          container.manage_delObjects( ids=[ obId])
-        # Delete Zope-Object.
-        container = self.getHome()
-        if obId in container.objectIds([obType]):
-          container.manage_delObjects( ids=[ obId])
+      if attr['type'] in [ 'method']: 
+        home = self.Special_Objects
+        if id+'.'+attr['id'] in home.objectIds(['DTML Method']):
+          home.manage_delObjects(ids=[id+'.'+attr['id']])
+      elif attr['type'] in [ 'method', 'DTML Method', 'DTML Document', 'External Method', 'Script (Python)']:
+        home = self.getHome()
+        if attr['id'] in home.objectIds([attr['type']]):
+          home.manage_delObjects(ids=[attr['id']])
+        if attr['type'] == 'External Method':
+          try:
+            _fileutil.remove( INSTANCE_HOME+'/Extensions/'+attr['id']+'.py')
+          except:
+            pass
     else:
       cp.append(attr)
   ob['__obj_attrs__'] = cp
@@ -227,11 +246,11 @@ def delMetaObjAttr(self, id, attr_id):
   self.setConfProperty(CONF_METAOBJS,obs.copy())
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  MetaobjManager._moveMetaObjAttr:
 # 
 #  Moves Meta-Object Attribute in specified position.
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def moveMetaObjAttr(self, id, attr_id, pos):
   ob = self.__get_metaobj__(id)
   attrs = copy.copy(ob['__obj_attrs__'])
@@ -251,20 +270,20 @@ def moveMetaObjAttr(self, id, attr_id, pos):
   self.setConfProperty(CONF_METAOBJS,obs.copy())
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metaobjmanager.getTemplateId
 #
 #  Returns template-id for meta-object specified by given Id.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getTemplateId(id):
   return "bodyContentZMSCustom_%s"%id
 
 
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _metaobjmanager.getMetaobjZMI
 #
 #  Returns ZMI from method 'manage_main' for meta-object specified by given Id.
-# ----------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getMetaobjZMI(self, id, REQUEST):
   metaObj = self.getMetaobj(id)
   for metaObjAttr in metaObj['attrs']:
@@ -291,13 +310,13 @@ def getMetaobjZMI(self, id, REQUEST):
   return None
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class MetaobjManager
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class MetaobjManager: 
 
     # Management Interface.
@@ -316,11 +335,11 @@ class MetaobjManager:
     metaobj_input_fields = HTMLFile('dtml/metaobj/input_fields', globals())
     metaobj_input_js = HTMLFile('dtml/metaobj/input_js', globals())
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager.__get_metaobjs__:
     # 
     #  Returns all meta-objects (including acquisitions).
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __get_metaobjs__(self): 
       obs = {}
       raw = getRawMetaobjs(self)
@@ -348,11 +367,11 @@ class MetaobjManager:
           obs[ob_id] = ob
       return obs
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager.__get_metaobj__:
     # 
     #  Returns meta-object identified by Id.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __get_metaobj__(self, id):
       obs = {}
       raw = getRawMetaobjs(self)
@@ -369,11 +388,11 @@ class MetaobjManager:
         ob = obs.get( id)
       return ob
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager.getMetaobjIds:
     # 
     #  Returns list of specObj-Ids.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetaobjIds(self, sort=1):
       obs = self.__get_metaobjs__()
       ids = obs.keys()
@@ -383,11 +402,11 @@ class MetaobjManager:
         ids = map(lambda x: x[1],mapping)
       return ids
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager.getMetaobj:
     # 
     #  Returns specObj specified by Id.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetaobj(self, id):
       ob = _globals.nvl( self.__get_metaobj__(id), {})
       d = {}
@@ -399,14 +418,13 @@ class MetaobjManager:
       d[ 'attrs'] = ob.get( '__obj_attrs__', [])
       d[ 'acquired'] = ob.get( 'acquired' ,0 )
       d[ 'zms_system'] = ob.get( 'zms_system' ,0 )
-      d[ 'access'] = ob.get( 'access', None)
       return d
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager.getMetaobjId:
     # 
     #  Returns Id for specObj specified by Name.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetaobjId(self, name):
       for id in self.getMetaobjIds():
         ob = self.getMetaobj(id)
@@ -414,28 +432,28 @@ class MetaobjManager:
           return id
       return None
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager.getMetaobjZMI:
     # 
     #  Returns Meta-Object Management Interface identified by Id.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetaobjZMI(self, id, REQUEST):
       return getMetaobjZMI(self,id,REQUEST)
 
 
     """
-    ###############################################################################################
+    ############################################################################
     #
     #   A T T R I B U T E S
     #
-    ###############################################################################################
+    ############################################################################
     """
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager._initMetaObjAttrs:
     # 
     #  Init list of Attributes for Meta-Object specified by ID.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _initMetaObjAttrs(self, id):
       attrs = []
       cp = copy.copy(attrs)
@@ -448,11 +466,11 @@ class MetaobjManager:
       self.setConfProperty( CONF_METAOBJS, obs.copy() )
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager.getMetaobjAttrIdentifierId:
     # 
-    #  Returns Attribute-ID of Identifier for Datatable Meta-Object specified by ID.
-    # ------------------------------------------------------------------------------------------
+    #  Returns Attribute-ID of Datatable-Identifier for Meta-Object specified by ID.
+    # --------------------------------------------------------------------------
     def getMetaobjAttrIdentifierId(self, meta_id):
       for attr_id in self.getMetaobjAttrIds( meta_id):
         metaObjAttr = self.getMetaobjAttr( meta_id, attr_id)
@@ -461,11 +479,11 @@ class MetaobjManager:
       return None
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager.getMetaobjAttrIds:
     # 
     #  Returns list of Attribute-IDs for Meta-Object specified by ID.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetaobjAttrIds(self, meta_id):
       ob = self.__get_metaobj__(meta_id)
       attrs = ob['__obj_attrs__']
@@ -473,14 +491,20 @@ class MetaobjManager:
       return ids
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager.getMetaobjAttr:
     # 
     #  Get Attribute for Meta-Object specified by key.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetaobjAttr(self, meta_id, key):
-      ob = self.__get_metaobj__(meta_id)
-      attrs = ob['__obj_attrs__']
+      meta_objs = self.__get_metaobjs__()
+      if meta_objs.get(meta_id,{}).get('acquired',0) == 1:
+        portalMaster = self.getPortalMaster()
+        if portalMaster is not None:
+          attr = portalMaster.getMetaobjAttr( meta_id, key)
+          return attr
+      meta_obj = meta_objs.get(meta_id)
+      attrs = meta_obj['__obj_attrs__']
       for attr in attrs:
         if attr['id'] == key:
           attr = attr.copy()
@@ -489,24 +513,28 @@ class MetaobjManager:
           attr['size'] = attr.get('size',35)
           attr['errors'] = attr.get('errors','')
           try:
-            if attr['type'] in [ 'DTML Method', 'DTML Document', 'Script (Python)']:
-              docElmnt = self.getDocumentElement()
-              obElmnt = getattr( docElmnt, attr['id'] )
-              if attr['type'] in [ 'DTML Method', 'DTML Document']:
-                attr['custom'] = obElmnt.raw
-              elif attr['type'] in [ 'Script (Python)']:
-                attr['custom'] = obElmnt.body()
+            if attr['type'] in [ 'method']:
+              home = self.Special_Objects
+              ob = getattr( home, meta_id+'.'+attr['id'])
+              attr['custom'] = ob.raw
+            elif attr['type'] in [ 'DTML Method', 'DTML Document', 'Script (Python)']:
+              home = self.getHome()
+              ob = getattr( home, attr['id'])
+              if ob.meta_type in [ 'DTML Method', 'DTML Document']:
+                attr['custom'] = ob.raw
+              elif ob.meta_type in [ 'Script (Python)']:
+                attr['custom'] = ob.body()
           except:
             value = _globals.writeException(self,'[getMetaobjAttr]')
           return attr
       return None
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetaobjManager._setMetaObjAttr:
     # 
     #  Set/add Meta-Object Attribute with specified values.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _setMetaObjAttr(self, id, oldId, newId, newName, newMandatory=0, newMultilang=1, newRepetitive=0, newType='string', newKeys=[], newCustom='', newDefault='', zms_system=0 ):
       ob = self.__get_metaobj__(id)
       attrs = copy.copy(ob['__obj_attrs__'])
@@ -522,22 +550,29 @@ class MetaobjManager:
         newMultilang = 0
       
       # Defaults for Insert
+      method_types = [ 'method', 'DTML Method', 'DTML Document', 'External Method', 'Script (Python)']
       if oldId is None and \
-         newType in [ 'method', 'DTML Method', 'DTML Document', 'Script (Python)' ] and \
+         newType in method_types and \
          (newCustom == '' or type(newCustom) is not type('')):
-        if newType in [ 'method', 'DTML Method', 'DTML Document' ]:
+        if newType in [ 'method', 'DTML Method', 'DTML Document']:
           newCustom = ''
           newCustom += '<!--// BO '+ newId + ' //-->\n'
           newCustom += '\n'
           newCustom += '<!--// EO '+ newId + ' //-->\n'
-	if newType in [ 'Script (Python)' ]:
+        elif newType in [ 'External Method']:
+          newCustom = ''
+          newCustom += '# Example code:\n'
+          newCustom += '\n'
+          newCustom += 'def ' + newId + '():\n'
+          newCustom += '  return "This is the external method ' + newId + '"\n'
+        elif newType in [ 'Script (Python)']:
           newCustom += ''
           newCustom += '# --// BO '+ newId + ' //--\n'
           newCustom += '# Example code:\n'
           newCustom += '\n'
-	  newCustom += '# Import a standard function, and get the HTML request and response objects.\n'
-	  newCustom += 'from Products.PythonScripts.standard import html_quote\n'
-	  newCustom += 'request = container.REQUEST\n'
+          newCustom += '# Import a standard function, and get the HTML request and response objects.\n'
+          newCustom += 'from Products.PythonScripts.standard import html_quote\n'
+          newCustom += 'request = container.REQUEST\n'
           newCustom += 'RESPONSE =  request.RESPONSE\n'
           newCustom += '\n'
           newCustom += '# Return a string identifying this script.\n'
@@ -560,6 +595,10 @@ class MetaobjManager:
       attr['custom'] = newCustom
       attr['default'] = newDefault
 
+      # Handle methods (i).
+      if oldId is not None and id+'.'+oldId in self.Special_Objects.objectIds(['DTML Method']):
+        self.Special_Objects.manage_delObjects(ids=[id+'.'+oldId])
+
       # Parse Dtml for Errors.
       message = ''
       if newType in [ 'method', 'DTML Method', 'DTML Document']:
@@ -567,6 +606,10 @@ class MetaobjManager:
         if len( message) > 0:
           attr['errors'] = message
           message = '<div class="form-label">' + newId + '</div><div style="color:red; background-color:yellow; ">%s</div>'%message
+        else:
+          # Handle methods (ii).
+          if newType in [ 'method']:
+            self.Special_Objects.manage_addDTMLMethod( id+'.'+newId, newType+': '+newName, newCustom)
       
       # Replace
       ids = self.getMetaobjAttrIds(id)
@@ -574,10 +617,8 @@ class MetaobjManager:
         i = ids.index(oldId)
         attrs[i] = attr
       else:
-        i = len(attrs)
-        method_types = [ 'method', 'DTML Method', 'DTML Document', 'Script (Python)' ]
         # Always append new methods at the end.
-        if newType in method_types:
+        if oldId == newId or newType in method_types:
           attrs.append( attr)
         # Insert new attributes before methods
         else:
@@ -589,24 +630,33 @@ class MetaobjManager:
           else:
             attrs.append( attr)
       ob['__obj_attrs__'] = attrs
-      
+
       # Handle Zope-Objects.
-      if newType in [ 'DTML Method', 'DTML Document', 'Script (Python)']:
+      if newType in [ 'DTML Method', 'DTML Document', 'External Method', 'Script (Python)']:
         # Remove Zope-Object (deprecated use in document-element).
         container = self.getDocumentElement()
         if oldId in container.objectIds():
           container.manage_delObjects( ids=[ oldId])
           oldId = None
+        # External Method.
+        if newType == 'External Method':
+          try:
+            _fileutil.remove( INSTANCE_HOME+'/Extensions/'+oldId+'.py')
+          except:
+            pass
+          newExternalMethod = INSTANCE_HOME+'/Extensions/'+newId+'.py'
+          _fileutil.exportObj( newCustom, newExternalMethod)
         # Insert Zope-Object.
         container = self.getHome()
-        newTitle = '*** DO NOT DELETE OR MODIFY ***'
-        if oldId is None:
+        if oldId is None or oldId == newId:
           if newId in container.objectIds():
             container.manage_delObjects( ids=[ newId])
           if newType == 'DTML Method':
-            container.manage_addDTMLMethod( newId, newTitle, newCustom)
+            container.manage_addDTMLMethod( newId, newName, newCustom)
           elif newType == 'DTML Document':
-            container.manage_addDTMLDocument( newId, newTitle, newCustom)
+            container.manage_addDTMLDocument( newId, newName, newCustom)
+          elif newType == 'External Method':
+            ExternalMethod.manage_addExternalMethod( container, newId, newName, newId, newId)
           elif newType == 'Script (Python)':
             PythonScript.manage_addPythonScript( container, newId)
         # Rename Zope-Object.
@@ -615,7 +665,7 @@ class MetaobjManager:
         # Change Zope-Object.
         obElmnt = getattr( container, newId)
         if newType in [ 'DTML Method', 'DTML Document' ]:
-          obElmnt.manage_edit( title=newTitle, data=newCustom)
+          obElmnt.manage_edit( title=newName, data=newCustom)
           obElmnt.manage_proxy( roles=[ 'Manager'])
           if newId.find( 'manage_') == 0:
             obElmnt.manage_role(role_to_manage='Authenticated',permissions=['View'])
@@ -633,7 +683,7 @@ class MetaobjManager:
               s = s[:-1]
             body += s + '\n'
             count += 1
-          obElmnt.ZPythonScript_setTitle( newTitle)
+          obElmnt.ZPythonScript_setTitle( newName)
           obElmnt.ZPythonScript_edit( params=params, body=body)
       
       # Assign Attributes to Meta-Object.
@@ -646,12 +696,12 @@ class MetaobjManager:
       return message
 
 
-    ###############################################################################################
+    ############################################################################
     #  MetaobjManager.manage_changeMetaobjs:
     #
     #  Change Meta-Object definitions.
-    ###############################################################################################
-    def manage_changeMetaobjs(self, lang, manage_lang, btn='', key='all', REQUEST=None, RESPONSE=None):
+    ############################################################################
+    def manage_changeMetaobjs(self, lang, btn='', key='all', REQUEST=None, RESPONSE=None):
         """ MetaobjManager.manage_changeMetaobjs """
         message = ''
         id = REQUEST.get('id','')
@@ -662,7 +712,7 @@ class MetaobjManager:
           # Delete.
           # -------
           # Delete Object.
-          if key == 'obj' and btn == self.getLangStr('BTN_DELETE',manage_lang):
+          if key == 'obj' and btn == self.getZMILangStr('BTN_DELETE'):
             ids = [id]
             metaObj = self.getMetaobj( id)
             if metaObj['type'] == 'ZMSPackage':
@@ -675,7 +725,7 @@ class MetaobjManager:
               for id in ids:
                 delMetaobj( self, id )
               id = ''
-              message = self.getLangStr('MSG_CHANGED',manage_lang)
+              message = self.getZMILangStr('MSG_CHANGED')
             else:
               raise 'All instances of "%s" must be deleted before definition can be deleted: <a href="%s/manage_main#_%s">%s</a>!'%(id,metaobj.getParentNode().absolute_url(),metaobj.id,metaobj.absolute_url())
           # Delete Attribute.
@@ -685,7 +735,7 @@ class MetaobjManager:
           
           # Change.
           # -------
-          elif key == 'all' and btn == self.getLangStr('BTN_CHANGE',manage_lang):
+          elif key == 'all' and btn == self.getZMILangStr('BTN_CHANGE'):
             savedAttrs = copy.copy(self.getMetaobj(id)['attrs'])
             # Change Object.
             id = REQUEST['id'].strip()
@@ -696,11 +746,6 @@ class MetaobjManager:
             newValue['package'] = REQUEST.get('obj_package').strip()
             newValue['__obj_attrs__'] = []
             newDtml = REQUEST.get('obj_dtml','')
-            newValue['access'] = { 
-             'insert': REQUEST.get( 'access_insert', []), 
-             'edit': REQUEST.get( 'access_edit', []), 
-             'delete': REQUEST.get( 'access_delete', []), 
-            }
             setMetaobj(self, id, newValue, newDtml, savedAttrs)
             # Change Attributes.
             for old_id in REQUEST.get('old_ids',[]):
@@ -721,23 +766,23 @@ class MetaobjManager:
                     newCustom = _blobfields.createBlobField( self,_globals.DT_FILE, newCustom, mediadbStorable=False)
               message += self._setMetaObjAttr( id, old_id, attr_id, newName, newMandatory, newMultilang, newRepetitive, newType, newKeys, newCustom, newDefault )
             # Return with message.
-            message += self.getLangStr('MSG_CHANGED',manage_lang)
+            message += self.getZMILangStr('MSG_CHANGED')
           
           # Copy.
           # -----
-          elif btn == self.getLangStr('BTN_COPY',manage_lang):
+          elif btn == self.getZMILangStr('BTN_COPY'):
             metaOb = self.getMetaobj(id)
             if metaOb.get('acquired',0) == 1:
               masterRoot = getattr(self,self.getConfProperty('Portal.Master'))
-              masterDocElmnt = masterRoot.objectValues(['ZMS'])[0]
+              masterDocElmnt = masterRoot.content
               REQUEST.set('ids',[id])
-              xml =  masterDocElmnt.manage_changeMetaobjs(lang, manage_lang, self.getLangStr('BTN_EXPORT',manage_lang), key, REQUEST, RESPONSE)
+              xml =  masterDocElmnt.manage_changeMetaobjs(lang, self.getZMILangStr('BTN_EXPORT'), key, REQUEST, RESPONSE)
               importXml(self,xml=xml)
-              message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%id)
+              message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%id)
           
           # Export.
           # -------
-          elif btn == self.getLangStr('BTN_EXPORT',manage_lang):
+          elif btn == self.getZMILangStr('BTN_EXPORT'):
             value = []
             ids = REQUEST.get('ids',[])
             for id in ids:
@@ -776,7 +821,7 @@ class MetaobjManager:
             
           # Insert.
           # -------
-          elif btn == self.getLangStr('BTN_INSERT',manage_lang):
+          elif btn == self.getZMILangStr('BTN_INSERT'):
             # Insert Object.
             if key == 'obj':
               id = REQUEST['_meta_id'].strip()
@@ -797,17 +842,17 @@ class MetaobjManager:
               setMetaobj(self, id, newValue, newDtml)
               # Insert Attributes.
               if newValue['type'] == 'ZMSDocument':
-                message += self._setMetaObjAttr(id,None,'titlealt',self.getLangStr('ATTR_TITLESHORT',manage_lang),1,1,0,'string')
-                message += self._setMetaObjAttr(id,None,'title',self.getLangStr('ATTR_TITLE',manage_lang),1,1,0,'string')
+                message += self._setMetaObjAttr(id,None,'titlealt',self.getZMILangStr('ATTR_TITLESHORT'),1,1,0,'string')
+                message += self._setMetaObjAttr(id,None,'title',self.getZMILangStr('ATTR_TITLE'),1,1,0,'string')
               elif newValue['type'] == 'ZMSTeaserElement':
-                message += self._setMetaObjAttr(id,None,'titlealt',self.getLangStr('ATTR_TITLESHORT',manage_lang),1,1,0,'string')
-                message += self._setMetaObjAttr(id,None,'attr_penetrance',self.getLangStr('ATTR_PENETRANCE',manage_lang),1,1,0,'select',['this','sub_nav','sub_all'])
+                message += self._setMetaObjAttr(id,None,'titlealt',self.getZMILangStr('ATTR_TITLESHORT'),1,1,0,'string')
+                message += self._setMetaObjAttr(id,None,'attr_penetrance',self.getZMILangStr('ATTR_PENETRANCE'),1,1,0,'select',['this','sub_nav','sub_all'])
               elif newValue['type'] == 'ZMSRecordSet':
-                message += self._setMetaObjAttr(id,None,'records',self.getLangStr('ATTR_RECORDS',manage_lang),1,1,0,'list')
+                message += self._setMetaObjAttr(id,None,'records',self.getZMILangStr('ATTR_RECORDS'),1,1,0,'list')
                 message += self._setMetaObjAttr(id,None,'col_id','COL_ID',1,0,0,'identifier',[],0)
                 message += self._setMetaObjAttr(id,None,'col_1','COL_1',0,0,0,'string',[],1)
                 message += self._setMetaObjAttr(id,None,'col_2','COL_2',0,0,0,'string',[],1)
-              message += self.getLangStr('MSG_INSERTED',manage_lang)%id
+              message += self.getZMILangStr('MSG_INSERTED')%id
             # Insert Attribute.
             if key == 'attr':
               attr_id = REQUEST['attr_id'].strip()
@@ -820,11 +865,11 @@ class MetaobjManager:
               newCustom = REQUEST.get('_custom','')
               newDefault = REQUEST.get('_default','')
               message += self._setMetaObjAttr( id, None, attr_id, newName, newMandatory, newMultilang, newRepetitive, newType, newKeys, newCustom, newDefault)
-              message += self.getLangStr('MSG_INSERTED',manage_lang)%attr_id
+              message += self.getZMILangStr('MSG_INSERTED')%attr_id
           
           # Acquire.
           # --------
-          elif btn == self.getLangStr('BTN_ACQUIRE',manage_lang):
+          elif btn == self.getZMILangStr('BTN_ACQUIRE'):
             id = REQUEST['aq_id']
             newValue = {}
             newValue['acquired'] = 1
@@ -833,11 +878,11 @@ class MetaobjManager:
             newValue['__obj_attrs__'] = []
             setMetaobj(self, id, newValue)
             # Return with message.
-            message = self.getLangStr('MSG_INSERTED',manage_lang)%id
+            message = self.getZMILangStr('MSG_INSERTED')%id
           
           # Import.
           # -------
-          elif btn == self.getLangStr('BTN_IMPORT',manage_lang):
+          elif btn == self.getZMILangStr('BTN_IMPORT'):
             f = REQUEST['file']
             if f:
               filename = f.filename
@@ -846,7 +891,7 @@ class MetaobjManager:
               filename = REQUEST['init']
               createIfNotExists = 1
               self.importConf(filename, REQUEST, createIfNotExists)
-            message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%filename)
+            message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%filename)
           
           # Move to.
           # --------
@@ -854,20 +899,21 @@ class MetaobjManager:
             pos = REQUEST['pos']
             attr_id = REQUEST['attr_id']
             moveMetaObjAttr( self, id, attr_id, pos)
-            message = self.getLangStr('MSG_MOVEDOBJTOPOS', manage_lang)%(("<i>%s</i>"%attr_id),(pos+1))
+            message = self.getZMILangStr('MSG_MOVEDOBJTOPOS')%(("<i>%s</i>"%attr_id),(pos+1))
           
           ##### SYNCHRONIZE ####
           self.synchronizeObjAttrs()
           
         # Handle exception.
         except:
+          _globals.writeException(self,"[manage_changeMetaobjs]")
           error = str( sys.exc_type)
           if sys.exc_value:
             error += ': ' + str( sys.exc_value)
           target = self.url_append_params( target, { 'manage_tabs_error_message':error})
         
         # Return with message.
-        target = self.url_append_params( target, { 'lang':lang, 'manage_lang':manage_lang, 'id':id, 'attr_id':REQUEST.get('attr_id','')})
+        target = self.url_append_params( target, { 'lang':lang, 'id':id, 'attr_id':REQUEST.get('attr_id','')})
         if len( message) > 0:
           target = self.url_append_params( target, { 'manage_tabs_message':message})
         if REQUEST.has_key('inp_id_name'):
@@ -877,4 +923,4 @@ class MetaobjManager:
           target += '#Edit'
         return RESPONSE.redirect( target)
 
-################################################################################################
+################################################################################
