@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _metapatternmanager.py
 #
 # $Id: _metapatternmanager.py,v 1.5 2004/11/24 21:02:52 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from App.Common import package_home
@@ -36,18 +36,18 @@ import _globals
 import _fileutil
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class MetapatternObject
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class MetapatternObject: 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetapatternObject._normalize_ids_after_instantiate:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _normalize_ids_after_instantiate(self, REQUEST):
       #++ _globals.writeLog("[%s._normalize_ids_after_instantiate]"%(self.meta_type))
       for obj_ver in self.getObjVersions():
@@ -76,12 +76,12 @@ class MetapatternObject:
     manage_addMetapatternForm = HTMLFile('dtml/metapattern/manage_addform', globals()) 
         
         
-    ###############################################################################################
+    ############################################################################
     #  MetapatternObject.manage_addMetapattern:
     #
     #  Add Meta-Pattern.
-    ###############################################################################################
-    def manage_addMetapattern(self, btn, lang, manage_lang, REQUEST, RESPONSE):
+    ############################################################################
+    def manage_addMetapattern(self, btn, lang, REQUEST, RESPONSE):
         """ MetapatternObject.manage_addMetapattern """
         message = ""
         id = ""
@@ -91,13 +91,13 @@ class MetapatternObject:
           
         # Overwrite.
         # ----------
-        if btn == self.getLangStr('BTN_OVERWRITE',manage_lang):
+        if btn == self.getZMILangStr('BTN_OVERWRITE'):
           id = REQUEST['overwrite_id']
           folder.manage_delObjects([id])
         
         # Insert.
         # -------
-        if btn == self.getLangStr('BTN_INSERT',manage_lang):
+        if btn == self.getZMILangStr('BTN_INSERT'):
           id = REQUEST['id']
           
         ##### Register Meta-Pattern ####
@@ -110,19 +110,19 @@ class MetapatternObject:
           obj.manage_addProperty('path',self.relative_obj_path(),'string')
           
           # Return with message.
-          message = urllib.quote(self.getLangStr('MSG_INSERTED',manage_lang)%title)
-          return RESPONSE.redirect('%s/manage_customizeMetapatternForm?lang=%s&manage_lang=%s&manage_tabs_message=%s&id=%s'%(self.getDocumentElement().absolute_url(),lang,manage_lang,message,id))
+          message = urllib.quote(self.getZMILangStr('MSG_INSERTED')%title)
+          return RESPONSE.redirect('%s/manage_customizeMetapatternForm?lang=%s&manage_tabs_message=%s&id=%s'%(self.getDocumentElement().absolute_url(),lang,message,id))
         
         # Return with message.
-        return RESPONSE.redirect('../manage_main?lang=%s&manage_lang=%s#_%s'%(lang,manage_lang,self.id))
+        return RESPONSE.redirect('../manage_main?lang=%s#_%s'%(lang,self.id))
 
 
-    ###############################################################################################
+    ############################################################################
     #  MetapatternObject.manage_instantiateMetapattern:
     #
     #  Instantiate new Meta-Pattern.
-    ###############################################################################################
-    def manage_instantiateMetapattern(self, lang, manage_lang, _sort_id, custom, REQUEST, RESPONSE=None):
+    ############################################################################
+    def manage_instantiateMetapattern(self, lang, _sort_id, custom, REQUEST, RESPONSE=None):
       """ MetapatternObject.manage_instantiateMetapattern """
       
       ob = None
@@ -176,76 +176,82 @@ class MetapatternObject:
       
       # Return with message.
       if RESPONSE:
-        message = urllib.quote(self.getLangStr('MSG_INSERTED',manage_lang)%ob['title'])
+        message = urllib.quote(self.getZMILangStr('MSG_INSERTED')%ob['title'])
         if obj.meta_type in ['ZMS','ZMSFolder','ZMSDocument','ZMSSysFolder']:
-          return RESPONSE.redirect('%s/manage_properties?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(obj.id,lang,manage_lang,message))
+          return RESPONSE.redirect('%s/manage_properties?lang=%s&manage_tabs_message=%s'%(obj.id,lang,message))
         else:
-          return RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(obj.id,lang,manage_lang,message))
+          return RESPONSE.redirect('%s/manage_main?lang=%s&manage_tabs_message=%s'%(obj.id,lang,message))
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class MetapatternManager
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class MetapatternManager(MetapatternObject): 
 
     # Management Interface.
     # ---------------------
     manage_customizeMetapatternForm = HTMLFile('dtml/metapattern/manage_customizeform', globals()) 
 
-
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetapatternManager.getMetapatternHome
-    # -------------------------------------------------------------------------------------------------
-    def getMetapatternHome(self):
+    # --------------------------------------------------------------------------
+    def getMetapatternHome(self, createIfNotExists=0):
       id = 'acl_metapatterns'
       docElmnt = self.getDocumentElement()
-      if not id in docElmnt.objectIds(['Folder']):
-        docElmnt.manage_addFolder(id=id,title='*** DO NOT DELETE OR MODIFY ***')
-      return getattr(docElmnt,id)
+      folder = getattr( docElmnt, id, None)
+      if folder is None:
+        if createIfNotExists:
+          docElmnt.manage_addFolder(id=id,title='*** DO NOT DELETE OR MODIFY ***')
+      else:
+        if not createIfNotExists:
+          if len( folder.objectIds()) == 0:
+            docElmnt.manage_delObjects(ids=[id])
+      return getattr( docElmnt, id, None)
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MetapatternManager.initMetapattern
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def initMetapattern(self, id):
-      folder = self.getMetapatternHome()
+      folder = self.getMetapatternHome(createIfNotExists=1)
       if not id in folder.objectIds(['File']):
         _fileutil.importZexp(folder,package_home(globals())+'/import/',id+'.zpat')
         #-- Reset path.
         ob = getattr(folder,id)
         ob.manage_changeProperties({'path':''})
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # MetapatternManager.getMetapatternIds:
     # 
     # Returns list of IDs of Meta-Patterns.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetapatternIds(self, REQUEST, meta_type=None):
-      folder = self.getMetapatternHome()
       ids = []
-      for id in folder.objectIds(['File']):
-        if meta_type is None or self.getMetapattern(id,REQUEST)['type']==meta_type:
-          ids.append(id)
+      folder = self.getMetapatternHome()
+      if folder is not None:
+        for id in folder.objectIds(['File']):
+          if meta_type is None or self.getMetapattern(id,REQUEST)['type']==meta_type:
+            ids.append(id)
       return ids
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # MetapatternManager.getMetapatternTitle:
     # 
     # Returns title of Meta-Pattern identified by ID.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetapatternTitle(self, id, REQUEST):
       folder = self.getMetapatternHome()
       ob = getattr(folder,id)
       return ob.title
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # MetapatternManager.getMetapattern:
     # 
     # Returns Meta-Pattern identified by ID.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetapattern(self, id, REQUEST):
       folder = self.getMetapatternHome()
       ob = getattr(folder,id)
@@ -257,86 +263,85 @@ class MetapatternManager(MetapatternObject):
         ob_src = ob.getLinkObj('{$' + ob_path + '}',REQUEST)
       return {'id':id,'title':ob_title,'type':ob_type,'path':ob_path,'src':ob_src,'ob':ob}
 
-
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # MetapatternManager.delMetapattern:
     # 
     # Delete Meta-Pattern specified by ID.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def delMetapattern(self, id):
       folder = self.getMetapatternHome()
       folder.manage_delObjects(ids=[id])
 
 
-    ###############################################################################################
+    ############################################################################
     # MetapatternManager.manage_changeMetapattern:
     #
     # Change Meta-Patterns.
-    ###############################################################################################
-    def manage_changeMetapattern(self, btn, lang, manage_lang, REQUEST, RESPONSE):
-        """ MetapatternManager.manage_changeMetapattern """
-        message = ''
+    ############################################################################
+    def manage_changeMetapattern(self, btn, lang, REQUEST, RESPONSE):
+      """ MetapatternManager.manage_changeMetapattern """
+      message = ''
+      id = ''
+      
+      # Delete.
+      # -------
+      if btn == self.getZMILangStr('BTN_DELETE'):
+        id = REQUEST['id']
+        self.delMetapattern(id)
         id = ''
-        
-        # Delete.
-        # -------
-        if btn == self.getLangStr('BTN_DELETE',manage_lang):
-          id = REQUEST['id']
-          self.delMetapattern(id)
-          id = ''
-          message = urllib.quote(self.getLangStr('MSG_CHANGED',manage_lang))
-        
-        # Change.
-        # -------
-        elif btn == self.getLangStr('BTN_CHANGE',manage_lang):
-          id = REQUEST['id']
-          new_id = REQUEST['new_id'].strip()
-          new_title = REQUEST['new_title'].strip()
-          folder = self.getMetapatternHome()
-          if id != new_id:
-            folder.manage_renameObject(id=id,new_id=new_id)
-          obj = getattr(folder,new_id)
-          obj.title = new_title
-          id = new_id
-          message = urllib.quote(self.getLangStr('MSG_CHANGED',manage_lang))        
-        
-        # Export.
-        # -------
-        elif btn == self.getLangStr('BTN_EXPORT',manage_lang):
-          id = REQUEST['id']
-          folder = self.getMetapatternHome()
-          content_type = 'application/zip'
-          export = folder.manage_exportObject(id=id,download=1)
-          filename = id + '.zpat'
-          RESPONSE.setHeader('Content-Type',content_type)
-          RESPONSE.setHeader('Content-Disposition','inline;filename=%s'%filename)
-          return export
-        
-        # Import.
-        # -------
-        elif btn == self.getLangStr('BTN_IMPORT',manage_lang):
-          folder = self.getMetapatternHome()
-          idsBefore = self.getMetapatternIds(REQUEST)
-          #-- Create temporary folder.
-          path = tempfile.mktemp() + os.sep
-          filename = 'metapattern.zexp'
-          #-- Save file to temporary folder.
-          _fileutil.exportObj(REQUEST['file'],'%s/%s'%(path,filename))
-          #-- Import zexp
-          _fileutil.importZexp(folder,path,filename)
-          #-- Remove temporary folder.
-          _fileutil.remove(path,deep=1)
-          #-- Retrieve id.
-          idsAfter = self.getMetapatternIds(REQUEST)
-          for id in idsAfter:
-            if id not in idsBefore:
-              new_id = id
-          id = new_id
-          #-- Reset path.
-          ob = getattr(folder,id)
-          ob.manage_changeProperties({'path':''})
-        
-        # Return with message.
-        return RESPONSE.redirect('manage_customizeMetapatternForm?lang=%s&manage_lang=%s&manage_tabs_message=%s&id=%s'%(lang,manage_lang,message,id))
+        message = urllib.quote(self.getZMILangStr('MSG_CHANGED'))
+      
+      # Change.
+      # -------
+      elif btn == self.getZMILangStr('BTN_CHANGE'):
+        id = REQUEST['id']
+        new_id = REQUEST['new_id'].strip()
+        new_title = REQUEST['new_title'].strip()
+        folder = self.getMetapatternHome()
+        if id != new_id:
+          folder.manage_renameObject(id=id,new_id=new_id)
+        obj = getattr(folder,new_id)
+        obj.title = new_title
+        id = new_id
+        message = urllib.quote(self.getZMILangStr('MSG_CHANGED'))        
+      
+      # Export.
+      # -------
+      elif btn == self.getZMILangStr('BTN_EXPORT'):
+        id = REQUEST['id']
+        folder = self.getMetapatternHome()
+        content_type = 'application/zip'
+        export = folder.manage_exportObject(id=id,download=1)
+        filename = id + '.zpat'
+        RESPONSE.setHeader('Content-Type',content_type)
+        RESPONSE.setHeader('Content-Disposition','inline;filename=%s'%filename)
+        return export
+      
+      # Import.
+      # -------
+      elif btn == self.getZMILangStr('BTN_IMPORT'):
+        folder = self.getMetapatternHome()
+        idsBefore = self.getMetapatternIds(REQUEST)
+        #-- Create temporary folder.
+        path = tempfile.mktemp() + os.sep
+        filename = 'metapattern.zexp'
+        #-- Save file to temporary folder.
+        _fileutil.exportObj(REQUEST['file'],'%s/%s'%(path,filename))
+        #-- Import zexp
+        _fileutil.importZexp(folder,path,filename)
+        #-- Remove temporary folder.
+        _fileutil.remove(path,deep=1)
+        #-- Retrieve id.
+        idsAfter = self.getMetapatternIds(REQUEST)
+        for id in idsAfter:
+          if id not in idsBefore:
+            new_id = id
+        id = new_id
+        #-- Reset path.
+        ob = getattr(folder,id)
+        ob.manage_changeProperties({'path':''})
+      
+      # Return with message.
+      return RESPONSE.redirect('manage_customizeMetapatternForm?lang=%s&manage_tabs_message=%s&id=%s'%(lang,message,id))
 
-###################################################################################################
+################################################################################
