@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _multilangmanager.py
 #
 # $Id: _multilangmanager.py,v 1.9 2004/11/30 20:03:17 zmsdev Exp $
@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
@@ -29,19 +29,9 @@ import urllib
 # Product Imports.
 import _globals
 
-# -------------------------------------------------------------------------------------------------
-#  Constants
-# -------------------------------------------------------------------------------------------------
-STYLESHEET_CSS = \
-	'<dtml-call "REQUEST.RESPONSE.setHeader(\'Cache-Control\',\'public, max-age=3600\')">' + \
-	'<dtml-var f_standard_html_request>' + \
-	'<dtml-var f_css_defaults>' + \
-	'<dtml-var "_[\'stylesheet.css\']">'
-
-
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  importXml
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def _importXml(self, item, zms_system=0, createIfNotExists=1):
   if createIfNotExists:
     key = item['key']
@@ -60,9 +50,9 @@ def importXml(self, xml, REQUEST=None, zms_system=0, createIfNotExists=1):
     _importXml( self, value, zms_system, createIfNotExists)
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _multilangmanager.getDescLangs
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getDescLangs(self, id, langs):
   obs = []
   # Primary language is always the first item in the sorted list.
@@ -80,11 +70,11 @@ def getDescLangs(self, id, langs):
   return obs
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _multilangmanager.setMethod:
 # 
 #  Set/add DTML-Method (e.g. index_lang.html) for specified language.
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def setMethod(self, id, raw):
   # delete method (if already exists)
   delMethod(self, id)
@@ -93,11 +83,11 @@ def setMethod(self, id, raw):
   self.manage_addDTMLMethod(id,title,raw)
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _multilangmanager.delMethod:
 # 
 #  Delete DTML-Method (e.g. index_lang.html) for specified language.
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def delMethod(self, id):
   try: 
     self.manage_delObjects(ids=[id])
@@ -105,20 +95,20 @@ def delMethod(self, id):
     pass
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   C l a s s   M u l t i L a n g u a g e O b j e c t
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class MultiLanguageObject:
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageObject.getLanguages: 
     #
     #  Returns list of Ids of languages (primary language 1st).
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLanguages(self, REQUEST=None):
     
       #-- [ReqBuff]: Fetch buffered value from Http-Request.
@@ -138,11 +128,11 @@ class MultiLanguageObject:
         return self.storeReqBuff( reqBuffId, value, REQUEST)
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageObject.getDescendantLanguages: 
     #
     #  Returns IDs of descendant languages.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getDescendantLanguages(self, id, REQUEST=None):
       obs = []
       user_langs = ['*']
@@ -156,13 +146,13 @@ class MultiLanguageObject:
       return map(lambda ob: ob[1],obs)
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   C l a s s   M u l t i L a n g u a g e M a n a g e r
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class MultiLanguageManager:
 
     # Management Interface.
@@ -170,34 +160,34 @@ class MultiLanguageManager:
     manage_customizeLanguagesForm = HTMLFile('dtml/zms/manage_customizelanguagesform', globals()) 
 
     """
-    ###############################################################################################
+    ############################################################################
     #	P R I M A R Y   L A N G U A G E
-    ###############################################################################################
+    ############################################################################
     """
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.setPrimaryLanguage: 
     #
     #  Sets ID of the primary language.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def setPrimaryLanguage(self, lang):
       self.language_primary = lang
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getPrimaryLanguage: 
     #
     #  Returns ID of the primary language.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getPrimaryLanguage(self):
       return self.language_primary
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getParentLanguage: 
     #
     #  Returns ID of parent language.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getParentLanguage(self, id):
       parent = None
       langs = self.getLangs()
@@ -207,11 +197,11 @@ class MultiLanguageManager:
       return parent
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getParentLanguages: 
     #
     #  Returns IDs of parent languages.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getParentLanguages(self, id):
       obs = []
       langs = self.getLangs()
@@ -227,11 +217,11 @@ class MultiLanguageManager:
       return obs
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getManageLanguage: 
     #
     #  Returns ID of the preferred language for the management interface.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getManageLanguage(self, id):
       languages = self.getLangs().get(id)
       if type(languages) is dict and languages.has_key('manage'):
@@ -247,11 +237,11 @@ class MultiLanguageManager:
       return rtn
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getLanguageLabel: 
     #
     #  Returns language-label of specified ID.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLanguageLabel(self, id):
       label = id
       langs = self.getLangs()
@@ -260,27 +250,27 @@ class MultiLanguageManager:
       return label
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getLangs:
     # 
     #  Returns dictionary of languages.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLangs(self):
       return getattr(self,'attr_languages',{})
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getLang: 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLang(self, id):
       return self.getLangs()[id]
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getLangIds: 
     #
     #  Returns list of Ids of languages (primary language 1st).
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLangIds(self, sort=1):
       obs = []
       langs = self.getLangs()
@@ -294,9 +284,9 @@ class MultiLanguageManager:
       return map(lambda ob: ob[1],obs)
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getLanguageFromName: 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLanguageFromName(self, name): 
       lang = None
       i = name.rfind('.')
@@ -311,11 +301,11 @@ class MultiLanguageManager:
       return lang
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getLanguage: 
     #
     #  Get requested language of specified URL (used by index_html).
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLanguage(self, REQUEST): 
       lang = REQUEST.get('lang',None)
       langs = self.getLangIds()
@@ -337,9 +327,9 @@ class MultiLanguageManager:
       return lang
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getHttpAcceptLanguage: 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getHttpAcceptLanguage(self, REQUEST): 
       lang = None
       langs = self.getLangIds()
@@ -347,7 +337,7 @@ class MultiLanguageManager:
         accept = REQUEST.get('HTTP_ACCEPT_LANGUAGE','')
         if accept.find( ';') >= 0:
           accept = accept[ : accept.find( ';')]
-        m = { 'de' : 'ger', 'en' : 'eng', 'fr' : 'fra', 'ru' : 'rus'}
+        m = { 'de' : 'ger', 'en' : 'eng', 'fr' : 'fra', 'ru' : 'rus', 'es' : 'esp', 'it' : 'ita', 'nl' : 'nld', 'sv' : 'swe'}
         for l in accept.split( ','):
           if l.find( '-') > 0:
             l = l[ : l.find( '-')]
@@ -360,11 +350,11 @@ class MultiLanguageManager:
       return lang
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.setLanguage: 
     # 
     #  Set/add language with specified values.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def setLanguage(self, lang, label, parent, newManage=None):
       
       if len(parent) == 0:
@@ -391,13 +381,12 @@ class MultiLanguageManager:
       self.recreateCatalog()
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.setLangMethods: 
     # 
     #  Set/Add Standard DTML-Methods.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def setLangMethods(self, lang):
-      setMethod(self,'stylesheet_%s.css'%lang,STYLESHEET_CSS)
       pageexts = ['.html']
       if 'attr_pageext' in self.getMetadictAttrs():
         metadictAttr = self.getMetadictAttr('attr_pageext')
@@ -410,11 +399,11 @@ class MultiLanguageManager:
         setMethod(self,'search_%s%s'%(lang,pageext),'<dtml-call "REQUEST.set(\'op\',\'search\')"><dtml-var index_html>')
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.delLanguage: 
     # 
     #  Delete language.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def delLanguage(self, lang):
       
       #-- Delete language.
@@ -426,7 +415,6 @@ class MultiLanguageManager:
       self.attr_languages = self.attr_languages.copy()
       
       #-- Delete Standard DTML-Methods.
-      delMethod(self,'stylesheet_%s.css'%lang)
       pageexts = ['.html']
       if 'attr_pageext' in self.getMetadictAttrs():
         metadictAttr = self.getMetadictAttr('attr_pageext')
@@ -441,24 +429,24 @@ class MultiLanguageManager:
       self.recreateCatalog()
 
 
-    ###############################################################################################
+    ############################################################################
     #  MultiLanguageManager.manage_changeLanguages:
     #
     #  Change languages.
-    ###############################################################################################
-    def manage_changeLanguages(self, lang, manage_lang, REQUEST, RESPONSE):
+    ############################################################################
+    def manage_changeLanguages(self, lang, REQUEST, RESPONSE):
         """ MultiLanguageManager.manage_changeLanguages """
         
         # Delete.
         # -------
-        if REQUEST['btn'] == self.getLangStr('BTN_DELETE',manage_lang):
+        if REQUEST['btn'] == self.getZMILangStr('BTN_DELETE'):
           ids = REQUEST.get('ids',[])
           for id in ids:
             self.delLanguage(id) 
         
         # Change.
         # -------
-        elif REQUEST['btn'] == self.getLangStr('BTN_CHANGE',manage_lang):
+        elif REQUEST['btn'] == self.getZMILangStr('BTN_CHANGE'):
           for id in self.getLangIds():
             newLabel = REQUEST.get('%s_label'%id).strip()
             newParent = REQUEST.get('%s_parent'%id).strip()
@@ -467,7 +455,7 @@ class MultiLanguageManager:
         
         # Insert.
         # -------
-        elif REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
+        elif REQUEST['btn'] == self.getZMILangStr('BTN_INSERT'):
           id = REQUEST['language_id']
           newLabel = REQUEST.get('language_label').strip()
           if len(self.getLangIds()) == 0:
@@ -478,15 +466,15 @@ class MultiLanguageManager:
           self.setLanguage(id, newLabel, newParent, newManage)
         
         # Return with message.
-        message = urllib.quote(self.getLangStr('MSG_CHANGED',manage_lang))
-        return RESPONSE.redirect('manage_customizeLanguagesForm?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(lang,manage_lang,message))
+        message = urllib.quote(self.getZMILangStr('MSG_CHANGED'))
+        return RESPONSE.redirect('manage_customizeLanguagesForm?lang=%s&manage_tabs_message=%s'%(lang,message))
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.get_lang_dict:
     #
     #  Returns language-dictionary.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def get_lang_dict(self):
       d = {}
       portalMaster = self.getPortalMaster()
@@ -505,11 +493,11 @@ class MultiLanguageManager:
       return d
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  MultiLanguageManager.getLangDict:
     #
     #  Returns list of entries from language-dictionary (ordered by key).
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLangDict(self):
       lang_dict = self.get_lang_dict()
       lang_list = []
@@ -522,17 +510,17 @@ class MultiLanguageManager:
       return lang_list
 
 
-    ###############################################################################################
+    ############################################################################
     #  MultiLanguageManager.manage_changeLangDictProperties:
     #
     #  Change property of language-dictionary.
-    ###############################################################################################
-    def manage_changeLangDictProperties(self, lang, manage_lang, REQUEST, RESPONSE):
+    ############################################################################
+    def manage_changeLangDictProperties(self, lang, REQUEST, RESPONSE):
         """ MultiLanguageManager.manage_changeLangDictProperties """
         
         # Delete.
         # -------
-        if REQUEST['btn'] == self.getLangStr('BTN_DELETE',manage_lang):
+        if REQUEST['btn'] == self.getZMILangStr('BTN_DELETE'):
           ids = REQUEST.get('ids',[])
           dict = self.get_lang_dict()
           lang_dict = {}
@@ -543,7 +531,7 @@ class MultiLanguageManager:
         
         # Change.
         # -------
-        elif REQUEST['btn'] == self.getLangStr('BTN_CHANGE',manage_lang):
+        elif REQUEST['btn'] == self.getZMILangStr('BTN_CHANGE'):
           d = self.get_lang_dict()
           lang_dict = {}
           for key in d.keys():
@@ -556,7 +544,7 @@ class MultiLanguageManager:
         
         # Insert.
         # -------
-        elif REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
+        elif REQUEST['btn'] == self.getZMILangStr('BTN_INSERT'):
           id = ''
           key = REQUEST['%s_key'%(id)].strip()
           lang_dict = self.get_lang_dict()
@@ -567,7 +555,7 @@ class MultiLanguageManager:
         
         # Export.
         # -------
-        elif REQUEST['btn'] == self.getLangStr('BTN_EXPORT',manage_lang):
+        elif REQUEST['btn'] == self.getZMILangStr('BTN_EXPORT'):
           value = []
           ids = REQUEST.get('ids',[])
           dict = self.get_lang_dict()
@@ -587,7 +575,7 @@ class MultiLanguageManager:
         
         # Import.
         # -------
-        elif REQUEST['btn'] == self.getLangStr('BTN_IMPORT',manage_lang):
+        elif REQUEST['btn'] == self.getZMILangStr('BTN_IMPORT'):
           f = REQUEST['file']
 	  if f:
 	    filename = f.filename
@@ -596,10 +584,10 @@ class MultiLanguageManager:
             filename = REQUEST['init']
 	    createIfNotExists = 1
 	    self.importConf(filename, REQUEST, createIfNotExists)
-          message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%filename)
+          message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%filename)
         
         # Return with message.
-        message = urllib.quote(self.getLangStr('MSG_CHANGED',manage_lang))
-        return RESPONSE.redirect('manage_customizeLanguagesForm?lang=%s&manage_lang=%s&manage_tabs_message=%s#langdict'%(lang,manage_lang,message))
+        message = urllib.quote(self.getZMILangStr('MSG_CHANGED'))
+        return RESPONSE.redirect('manage_customizeLanguagesForm?lang=%s&manage_tabs_message=%s#langdict'%(lang,message))
 
-###################################################################################################
+################################################################################
