@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _textformatmanager.py
 #
 # $Id: _textformatmanager.py,v 1.11 2004/11/30 20:03:17 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
@@ -33,42 +33,44 @@ import _globals
 import _objattrs
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _textformatmanager.importXml
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
-def _importXml(self, item):
-  textFmts = getTextFormats(self)
+def _importXml(self, item, zms_system=0, createIfNotExists=1):
+  fmts = getTextFormats(self)
   id = item['key']
   dict = item['value']
-  if id in textFmts:
-    i = textFmts.index(id)
-    textFmts[i+1] = dict
+  if id in fmts:
+    i = fmts.index(id)
+    fmts[i+1] = dict
   else:
-    textFmts.append(id)
-    textFmts.append(dict)
-  self.setConfProperty('ZMS.custom.textformats',copy.deepcopy(textFmts))
+    fmts.append(id)
+    fmts.append(dict)
+  self.setConfProperty('ZMS.custom.textformats',copy.deepcopy(fmts))
 
-def importXml(self, xml):
-  value = self.parseXmlString(xml)
-  if type(value) is list:
-    for item in value:
-      _importXml(self,item)
+def importXml(self, xml, REQUEST=None, zms_system=0, createIfNotExists=1):
+  v = self.parseXmlString(xml)
+  if type(v) is list:
+    for item in v:
+      _importXml(self,item,zms_system,createIfNotExists)
   else:
-    _importXml(self,value)
+    _importXml(self,v,zms_system,createIfNotExists)
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _textformatmanager.br_quote
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def br_quote(text, subtag, REQUEST):
   if type(text) is not type(''):
     text = str(text)
   rtn = ''
-  q = ''
+  qcr = ''
+  qtab = '&nbsp;' * 6
   if _globals.isManagementInterface(REQUEST):
     if not REQUEST.has_key('format'):
-      q = '&para;'
+      qcr = '<span class="unicode">&crarr;</span>'
+      qtab = '<span class="unicode">&rarr;</span>' + '&nbsp;' * 5
   if subtag == 'br':
     tmp = []
     for s in text.split('<%s>'%subtag):
@@ -79,82 +81,89 @@ def br_quote(text, subtag, REQUEST):
     text = ''.join(tmp)
   ts = text.split('\n')
   c = 1
-  for s in ts:
-    subtext = s.strip()
+  for line in ts:
     rtn += '\n'
+    i = 0
+    while i < len( line) and line[ i] in [ ' ', '\t']:
+      if line[ i] == ' ':
+        rtn += '&nbsp;'
+      elif line[ i] == '\t':
+        rtn += qtab
+      i+=1
+    line = line[ i:].strip()
     if subtag == 'br':
-      rtn += subtext+q
+      rtn += line+qcr
       if c < len( ts):
         rtn += '<%s />'%subtag
-    elif len(subtext) > 0:
+    elif len(line) > 0:
       rtn += '<%s'%subtag
       rtn += '>'
-      rtn += subtext+q
+      rtn += line+qcr
       rtn += '</%s>'%subtag
     c += 1
   return rtn
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _textformatmanager.delTextFormat:
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def delTextFormat(self, id):
-  textFmts = getTextFormats(self)
-  i = textFmts.index(id)
-  del textFmts[i]
-  del textFmts[i]
-  self.setConfProperty('ZMS.custom.textformats',copy.deepcopy(textFmts))
+  fmts = getTextFormats(self)
+  i = fmts.index(id)
+  del fmts[i]
+  del fmts[i]
+  self.setConfProperty('ZMS.custom.textformats',copy.deepcopy(fmts))
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _textformatmanager.setTextFormat:
-# ------------------------------------------------------------------------------------------
-def setTextFormat(self, id, newId, newDisplay, manage_lang, newTag='', newSubtag='', newAttrs='', newRichedit=0):
-  textFmts = getTextFormats(self)
-  if id in textFmts:
-    i = textFmts.index(id)
+# ------------------------------------------------------------------------------
+def setTextFormat(self, id, newId, newDisplay, newZMILang, newTag='', newSubtag='', newAttrs='', newRichedit=0):
+  fmts = getTextFormats(self)
+  if id in fmts:
+    i = fmts.index(id)
   else:
-    i = len(textFmts)
-    textFmts.append(newId)
-    textFmts.append({'display':{}})
-  dict = textFmts[i+1]
-  dict['display'][manage_lang] = newDisplay
+    i = len(fmts)
+    fmts.append(newId)
+    fmts.append({'display':{}})
+  dict = fmts[i+1]
+  dict['display'][newZMILang] = newDisplay
   dict['tag'] = newTag
   dict['subtag'] = newSubtag
   dict['attrs'] = newAttrs
   dict['richedit'] = newRichedit
-  textFmts[i] = newId
-  textFmts[i+1] = dict.copy()
-  self.setConfProperty('ZMS.custom.textformats',copy.deepcopy(textFmts))
+  fmts[i] = newId
+  fmts[i+1] = dict.copy()
+  self.setConfProperty('ZMS.custom.textformats',copy.deepcopy(fmts))
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _textformatmanager.setDefaultTextFormat:
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def setDefaultTextFormat(self, id):
   if len(id) > 0:
     self.setConfProperty('ZMS.custom.textformats.default',id)
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _textformatmanager.getTextFormats:
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getTextFormats(self):
   return self.getConfProperty('ZMS.custom.textformats',[])
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class TextFormatObject:
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class TextFormatObject:
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  TextFormatObject.renderText:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def renderText(self, format, text, REQUEST, id=None):
       # Process format.
       textformat = self.getTextFormat( format, REQUEST)
@@ -166,9 +175,9 @@ class TextFormatObject:
       return text
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  TextFormatObject.renderContentEditable:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def renderContentEditable(self, key, text, REQUEST):
       contentEditable = \
         self.getConfProperty('ZMS.contenteditable',0) \
@@ -180,7 +189,6 @@ class TextFormatObject:
       html = ''
       if contentEditable:
         lang = REQUEST['lang']
-        manage_lang = REQUEST['manage_lang']
         id = self.id
         fmName = 'form0_%s'%id
         elName = '%s_%s'%(key,lang)
@@ -191,7 +199,7 @@ class TextFormatObject:
         html += ' id="charformat_%s"'%divId
         html += ' style="display:none;width:100'+'%;white-space:nowrap;"'
         html += '>'
-        html += self.f_selectCharformat(self, fmName=fmName, elName=elName, divId=divId, lang=lang, manage_lang=manage_lang, REQUEST=REQUEST)
+        html += self.f_selectCharformat(self, fmName=fmName, elName=elName, divId=divId, lang=lang, REQUEST=REQUEST)
         html += '</div>'
         if _globals.isManagementInterface(REQUEST):
           html += '<div'
@@ -203,7 +211,7 @@ class TextFormatObject:
           html += text
           html += '</div>'
           html += '<div class="saveclick" id="saveclick_%s" style="display:none;">'%divId
-          html += '[<a href="javascript:contenteditableChangeClick(\'%s\',\'%s\',\'%s\')" style="color: black; font-size:9px; text-decoration: none;">%s</a>]'%(self.absolute_url(),id,key,self.getLangStr('BTN_CHANGE',REQUEST['manage_lang']))
+          html += '[<a href="javascript:contenteditableChangeClick(\'%s\',\'%s\',\'%s\')" style="color: black; font-size:9px; text-decoration: none;">%s</a>]'%(self.absolute_url(),id,key,self.getZMILangStr('BTN_CHANGE'))
           html += '</div>'
         else:
           html += '<div'
@@ -214,50 +222,17 @@ class TextFormatObject:
           html += '>'
           html += text
           html += '</div>'
-
-        """
-        lang = REQUEST['lang']
-        manage_lang = REQUEST['manage_lang']
-        fmName = 'form0'
-        elName = '%s_%s'%(key,self.id)
-        # Content-Editable.
-        html += '<div class="charformat" id="charformat_%s" style="display:none; white-space:nowrap;">'%elName
-        html += self.f_selectCharformat(self, fmName=fmName, elName=elName, lang=lang, manage_lang=manage_lang, REQUEST=REQUEST)
-        html += '</div>'
-        if _globals.isManagementInterface(REQUEST):
-          html += '<div'
-          html += ' id="%s"'%elName
-          html += ' contentEditable="true"'
-          html += ' onClick="javascript: style.border=\'1px dotted blue\'; saveclick_%s.style.display=\'inline\';" '%elName
-          html += ' onBlur="javascript: style.border=\'none\';"'
-          html += '>'
-          html += text
-          html += '</div>'
-          html += '<div class="saveclick" id="saveclick_%s" style="display:none;">'%elName
-          html += '[<a href="javascript:contenteditableChangeClick(\'%s\',\'%s\',\'%s\')" style="color: black; font-size:9px; text-decoration: none;">%s</a>]'%(self.absolute_url(),self.id,key,self.getLangStr('BTN_CHANGE',REQUEST['manage_lang']))
-          html += '</div>'
-        else:
-          html += '<div'
-          html += ' id="%s"'%elName
-          html += ' contentEditable="true"'
-          html += ' onClick="javascript: style.border=\'1px dotted blue\'; charformat_%s.style.display=\'inline\';"'%elName
-          html += ' onBlur="javascript: style.border=\'none\'; contentEditableBlur( this, \'%s\', \'%s\');"'%(self.id,self.getObjAttrName( self.getObjAttr( key), lang))
-          html += '>'
-          html += text
-          html += '</div>'
-        """
-
       else:
         html += text
       return html
 
 
-    ############################################################################################
+    ############################################################################
     #  TextFormatObject.manage_changeTextProperties:
     #
     #  Change text property from CONTENTEDITABLE paragraph.
-    ############################################################################################
-    def manage_changeTextProperties(self, key, lang, manage_lang, REQUEST, RESPONSE): 
+    ############################################################################
+    def manage_changeTextProperties(self, key, lang, REQUEST, RESPONSE): 
       """ TextFormatManager.manage_changeTextProperties """
       message = ''
 
@@ -317,7 +292,7 @@ class TextFormatObject:
         self.setObjProperty(key, text, lang)
       self.onChangeObj(REQUEST)
       #-- Message.
-      message += self.getLangStr('MSG_CHANGED',manage_lang)
+      message += self.getZMILangStr('MSG_CHANGED')
 
       # Return with message.
       self.checkIn(REQUEST)
@@ -325,7 +300,7 @@ class TextFormatObject:
       i = url.find('?')
       if i >= 0:
         url = url[:i]
-      url = self.url_append_params(url,{'lang':lang,'manage_lang':manage_lang,'preview':'preview','manage_tabs_message':message,})
+      url = self.url_append_params(url,{'lang':lang,'preview':'preview','manage_tabs_message':message,})
       if url.find('/manage') >= 0:
         url += '#_'+self.id
       else:
@@ -333,13 +308,13 @@ class TextFormatObject:
       return RESPONSE.redirect(url)
      
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class TextFormatManager:
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class TextFormatManager: 
 
 
@@ -348,24 +323,24 @@ class TextFormatManager:
     manage_customizeTextFormatForm = HTMLFile('dtml/zms/manage_customizetextformatform', globals()) 
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  TextFormatManager.getTextFormatIds:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTextFormatIds(self, REQUEST):
       return map(lambda ob: ob.getId(),self.getTextFormats(REQUEST))
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  TextFormatManager.getTextFormat:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTextFormat(self, format, REQUEST):
       obs = getTextFormats(self)
       if format in obs:
         return TextFormat(self,format,obs[obs.index(format)+1],REQUEST)
       return None
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  TextFormatManager.getTextFormats:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTextFormats(self, REQUEST):
       l_sort = []
       obs = getTextFormats(self.getDocumentElement())
@@ -377,26 +352,26 @@ class TextFormatManager:
       l_sort.sort()
       return map(lambda ob: ob[1],l_sort)
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  TextFormatManager.getTextFormatDefault:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTextFormatDefault(self, REQUEST={}):
       return self.getConfProperty('ZMS.custom.textformats.default','body')
 
 
-    ############################################################################################
+    ############################################################################
     #  TextFormatManager.manage_customizeTextFormat:
     #
-    #  Change Text-Formats.
-    ############################################################################################
-    def manage_customizeTextFormat(self, lang, manage_lang, REQUEST, RESPONSE): 
+    #  Change text-formats.
+    ############################################################################
+    def manage_customizeTextFormat(self, lang, REQUEST, RESPONSE): 
       """ TextFormatManager.manage_customizeTextFormat """
       message = ''
       id = REQUEST.get('id','')
       
       # Change.
       # -------
-      if REQUEST['btn'] == self.getLangStr('BTN_CHANGE',manage_lang):
+      if REQUEST['btn'] == self.getZMILangStr('BTN_CHANGE'):
         old_id = REQUEST['id']
         id = REQUEST['new_id'].strip()
         display = REQUEST['new_display'].strip()
@@ -404,37 +379,37 @@ class TextFormatManager:
         subtag = REQUEST['new_subtag'].strip()
         attrs = REQUEST['new_attrs'].strip()
         richedit = REQUEST.get('new_richedit',0)
-        setTextFormat(self,old_id,id,display,manage_lang,tag,subtag,attrs,richedit)
+        setTextFormat(self,old_id,id,display,self.get_manage_lang(),tag,subtag,attrs,richedit)
         if REQUEST.has_key('new_default'): 
           setDefaultTextFormat(self,REQUEST['new_default'])
         id = ""
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       # Delete.
       # -------
-      elif REQUEST['btn'] == self.getLangStr('BTN_DELETE',manage_lang):
+      elif REQUEST['btn'] == self.getZMILangStr('BTN_DELETE'):
         id = REQUEST['id']
         delTextFormat(self,id) 
         id = ""
-        message = self.getLangStr('MSG_DELETED',manage_lang)%int(1)
+        message = self.getZMILangStr('MSG_DELETED')%int(1)
       
       # Insert.
       # -------
-      elif REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
+      elif REQUEST['btn'] == self.getZMILangStr('BTN_INSERT'):
         id = REQUEST['_id'].strip()
         display = REQUEST['_display'].strip()
-        setTextFormat(self,'',id,display,manage_lang)
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        setTextFormat(self,'',id,display,self.get_manage_lang())
+        message = self.getZMILangStr('MSG_CHANGED')
       
       # Export.
       # -------
-      elif REQUEST['btn'] == self.getLangStr('BTN_EXPORT',manage_lang):
+      elif REQUEST['btn'] == self.getZMILangStr('BTN_EXPORT'):
         value = []
         ids = REQUEST.get('ids',[])
-        textFmts = getTextFormats(self)
-        for i in range(len(textFmts)/2):
-          id = textFmts[i*2]
-          ob = textFmts[i*2+1]
+        fmts = getTextFormats(self)
+        for i in range(len(fmts)/2):
+          id = fmts[i*2]
+          ob = fmts[i*2+1]
           if id in ids or len(ids) == 0:
             value.append({'key':id,'value':ob})
         if len(value)==1:
@@ -448,29 +423,36 @@ class TextFormatManager:
 
       # Import.
       # -------
-      elif REQUEST['btn'] == self.getLangStr('BTN_IMPORT',manage_lang):
-        importXml(self,xml=REQUEST['file'])
-        message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%REQUEST['file'].filename)
+      elif REQUEST['btn'] == self.getZMILangStr('BTN_IMPORT'):
+        f = REQUEST['file']
+        if f:
+          filename = f.filename
+          importXml(self,xml=f)
+        else:
+          filename = REQUEST['init']
+          createIfNotExists = 1
+          self.importConf(filename, REQUEST, createIfNotExists)
+        message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%filename)
 
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_customizeTextFormatForm?lang=%s&manage_lang=%s&manage_tabs_message=%s&id=%s'%(lang,manage_lang,message,id))
+      return RESPONSE.redirect('manage_customizeTextFormatForm?lang=%s&manage_tabs_message=%s&id=%s#form0'%(lang,message,id))
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class TextFormat:
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class TextFormat:
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  TextFormat.__init__:
   #
   #  Constructor.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def __init__(self, owner, id, ob, REQUEST):
     self.setOwner(owner)
     self.setId(id)
@@ -489,33 +471,33 @@ class TextFormat:
     self.setRichedit(richedit)
     
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Get/Set Owner.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getOwner(self): return self.owner
   def setOwner(self, owner): self.owner = owner
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Get/Set Id.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getId(self): return self.id
   def setId(self, id): self.id = id
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Get/Set Display.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getDisplay(self): return self.display
   def setDisplay(self, display): self.display = display
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Get/Set <Tag>.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getTag(self): return self.tag
   def setTag(self, tag): self.tag = tag
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Assemble <Start-Tag>.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getStartTag(self, id=None): 
     html = ''
     tag = self.getTag()
@@ -529,9 +511,9 @@ class TextFormat:
       html += '>'
     return html
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Assemble <End-Tag>.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getEndTag(self): 
     html = ''
     tag = self.getTag()
@@ -540,27 +522,27 @@ class TextFormat:
       html += '>'
     return html
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Get/Set <Sub-Tag>.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getSubTag(self): return self.subtag
   def setSubTag(self, subtag): self.subtag = subtag
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Get/Set <Tag>-Attributes.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getAttrs(self): return self.attrs
   def setAttrs(self, attrs): self.attrs = attrs
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Get/Set Richedit.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getRichedit(self): return self.richedit
   def setRichedit(self, richedit): self.richedit = richedit
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  HTML.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getHtml(self): 
     html = ''
     # Open tag.
@@ -592,9 +574,9 @@ class TextFormat:
       html += '&nbsp;'
     return html
 
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  Render text.
-  # -----------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def renderText(self, text, REQUEST, id=None):
     html = ''
     tag = self.getTag()
@@ -609,8 +591,8 @@ class TextFormat:
     html += self.getEndTag()
     # Default.
     if len(html)==0:
-      html = '%s&nbsp;'%(html)
+      html = '&nbsp;'
     # Return.
     return html
 
-###################################################################################################
+################################################################################
