@@ -90,11 +90,10 @@ def importXml(self, xml, REQUEST):
     wfRoles = self.concat_list(wfRoles,wfTransition.get('performer',[]))
   for newRole in self.difference_list(wfRoles, self.userdefined_roles()):
     REQUEST.set('newId', newRole)
-    manage_lang = REQUEST.get('manage_lang')
     lang = REQUEST.get('lang')
     key = 'obj'
-    btn = self.getLangStr('BTN_INSERT', manage_lang)
-    self.manage_roleProperties(btn, key, lang, manage_lang, REQUEST)
+    btn = self.getZMILangStr('BTN_INSERT')
+    self.manage_roleProperties(btn, key, lang, REQUEST)
 
 # -------------------------------------------------------------------------------------------------
 #   _workflowmanager.exportXml
@@ -298,7 +297,6 @@ class WorkflowItem:
     def filtered_workflow_actions(self, path, REQUEST):
       actions = []
       lang = REQUEST['lang']
-      manage_lang = REQUEST['manage_lang']
       auth_user = REQUEST['AUTHENTICATED_USER']
       
       #-- Workflow.
@@ -318,7 +316,7 @@ class WorkflowItem:
 
       #-- Headline,
       if len( actions) > 0:
-        actions.insert(0,('----- %s -----'%self.getLangStr('TAB_WORKFLOW',manage_lang),''))
+        actions.insert(0,('----- %s -----'%self.getZMILangStr('TAB_WORKFLOW'),''))
 
       # Return action list.
       return actions
@@ -342,7 +340,7 @@ class WorkflowManager:
     #
     #  Auto-Commit ZMS-tree.
     # ---------------------------------------------------------------------------------------------
-    def doAutocommit(self, lang, manage_lang, REQUEST):
+    def doAutocommit(self, lang, REQUEST):
       _versionmanager.doAutocommit(self,REQUEST)
 
     # ---------------------------------------------------------------------------------------------
@@ -441,25 +439,25 @@ class WorkflowManager:
     #
     #  Customize workflow.
     ###############################################################################################
-    def manage_changeWorkflow(self, lang, manage_lang, key='', btn='', REQUEST=None, RESPONSE=None):
+    def manage_changeWorkflow(self, lang, key='', btn='', REQUEST=None, RESPONSE=None):
       """ WorkflowManager.manage_changeWorkflow """
       message = ''
       
       # Active.
       # -------
-      if key == 'custom' and btn == self.getLangStr('BTN_CHANGE',manage_lang):
+      if key == 'custom' and btn == self.getZMILangStr('BTN_CHANGE'):
         # Autocommit & Nodes.
         old_autocommit = self.getConfProperty('ZMS.autocommit',1)
         new_autocommit = REQUEST.get('workflow',0) == 0
         self.setConfProperty('ZMS.autocommit',new_autocommit)
         self.setConfProperty('ZMS.workflow.nodes',self.string_list(REQUEST.get('nodes','')))
         if old_autocommit == 0 and new_autocommit == 1:
-          self.doAutocommit(lang,manage_lang,REQUEST)
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+          self.doAutocommit(lang,REQUEST)
+        message = self.getZMILangStr('MSG_CHANGED')
         # Acquire.
         newAcquire = REQUEST.get('acquire',0) == 1
         self.setConfProperty(CONF_ACQUIRE,newAcquire)
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
 	# Init.
         filename = REQUEST.get('filename','')
         self.setConfProperty(CONF_INIT,filename)
@@ -468,14 +466,14 @@ class WorkflowManager:
       # ---------
       elif key == 'protocol':
         # Change.
-        if btn == self.getLangStr('BTN_CHANGE',manage_lang):
+        if btn == self.getZMILangStr('BTN_CHANGE'):
           keep_entries = REQUEST.get('keep_entries',0)
           self.setConfProperty(CONF_PROTOCOL_KEEP,keep_entries)
           if keep_entries == 0:
             self.setConfProperty(CONF_PROTOCOL,[])
-          message = self.getLangStr('MSG_CHANGED',manage_lang)
+          message = self.getZMILangStr('MSG_CHANGED')
         # Export.
-        elif btn == self.getLangStr('BTN_EXPORT',manage_lang):
+        elif btn == self.getZMILangStr('BTN_EXPORT'):
           export = readProtocol(self)
           content_type = 'text/plain'
           filename = 'workFlow.protocol.log'
@@ -485,12 +483,12 @@ class WorkflowManager:
       
       # Export.
       # -------
-      elif key == 'export' and btn == self.getLangStr('BTN_EXPORT',manage_lang):
+      elif key == 'export' and btn == self.getZMILangStr('BTN_EXPORT'):
         return exportXml(self, REQUEST, RESPONSE)
       
       # Import.
       # -------
-      elif key == 'import' and btn == self.getLangStr('BTN_IMPORT',manage_lang):
+      elif key == 'import' and btn == self.getZMILangStr('BTN_IMPORT'):
         f = REQUEST['file']
 	if f:
 	  filename = f.filename
@@ -499,11 +497,11 @@ class WorkflowManager:
           filename = REQUEST.get('init')
           self.setConfProperty(CONF_INIT,filename)
           filename = initConf(self, filename, REQUEST)
-        message = self.getLangStr('MSG_IMPORTED',manage_lang)%('<i>%s</i>'%f.filename)
+        message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%f.filename)
       
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_customizeWorkflowForm?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(lang,manage_lang,message,key))
+      return RESPONSE.redirect('manage_customizeWorkflowForm?lang=%s&manage_tabs_message=%s#_%s'%(lang,message,key))
 
 
     ###############################################################################################
@@ -511,7 +509,7 @@ class WorkflowManager:
     #
     #  Customize workflow-activities.
     ###############################################################################################
-    def manage_changeWfActivities(self, lang, manage_lang, btn='', REQUEST=None, RESPONSE=None):
+    def manage_changeWfActivities(self, lang, btn='', REQUEST=None, RESPONSE=None):
       """ WorkflowManager.manage_changeWfActivities """
       message = ''
       id = REQUEST.get('id','')
@@ -520,7 +518,7 @@ class WorkflowManager:
       
       # Change.
       # -------
-      if btn == self.getLangStr('BTN_CHANGE',manage_lang):
+      if btn == self.getZMILangStr('BTN_CHANGE'):
         item = self.getWfActivity(id)
         newId = REQUEST.get('inpId').strip()
         newName = REQUEST.get('inpName').strip()
@@ -532,17 +530,17 @@ class WorkflowManager:
             newIcon = _blobfields.createBlobField(self,_globals.DT_IMAGE,newIcon)
         newEditable = REQUEST.get('inpEditable',0)
         id = setWfActivity(self, item.get('id',None), newId, newName, newIcon, newEditable)
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       # Delete.
       # -------
-      elif btn in ['delete',self.getLangStr('BTN_DELETE',manage_lang)]:
+      elif btn in ['delete',self.getZMILangStr('BTN_DELETE')]:
         id = delWfItem(self, id, CONF_ACTIVITIES)
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       # Insert.
       # -------
-      elif btn == self.getLangStr('BTN_INSERT',manage_lang):
+      elif btn == self.getZMILangStr('BTN_INSERT'):
         item = {}
         newId = REQUEST.get('newId').strip()
         newName = REQUEST.get('newName').strip()
@@ -554,19 +552,19 @@ class WorkflowManager:
             newIcon = _blobfields.createBlobField(self,_globals.DT_IMAGE,newIcon)
         newEditable = REQUEST.get('newEditable',0)
         id = setWfActivity(self, item.get('id',None), newId, newName, newIcon, newEditable)
-        message = self.getLangStr('MSG_INSERTED',manage_lang)%id
+        message = self.getZMILangStr('MSG_INSERTED')%id
       
       # Move to.
       # --------
       elif btn == 'move_to':
         pos = REQUEST['pos']
         moveWfItem(self, id, pos, CONF_ACTIVITIES)
-        message = self.getLangStr('MSG_MOVEDOBJTOPOS', manage_lang)%(("<i>%s</i>"%id),(pos+1))
+        message = self.getZMILangStr('MSG_MOVEDOBJTOPOS')%(("<i>%s</i>"%id),(pos+1))
         id = ''
       
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_customizeWorkflowForm?lang=%s&manage_lang=%s&manage_tabs_message=%s#_Activities'%(lang,manage_lang,message))
+      return RESPONSE.redirect('manage_customizeWorkflowForm?lang=%s&manage_tabs_message=%s#_Activities'%(lang,message))
 
 
     ###############################################################################################
@@ -574,7 +572,7 @@ class WorkflowManager:
     #
     #  Customize workflow-transitions.
     ###############################################################################################
-    def manage_changeWfTransitions(self, lang, manage_lang, btn='', REQUEST=None, RESPONSE=None):
+    def manage_changeWfTransitions(self, lang, btn='', REQUEST=None, RESPONSE=None):
       """ WorkflowManager.manage_changeWfTransitions """
       message = ''
       id = REQUEST.get('id','')
@@ -583,7 +581,7 @@ class WorkflowManager:
       
       # Change.
       # -------
-      if btn == self.getLangStr('BTN_CHANGE', manage_lang):
+      if btn == self.getZMILangStr('BTN_CHANGE'):
         item = self.getWfTransition(id)
         newId = REQUEST.get('inpId').strip()
         newName = REQUEST.get('inpName').strip()
@@ -592,18 +590,18 @@ class WorkflowManager:
         newPerformer = REQUEST.get('inpPerformer',[])
         newDtml = REQUEST.get('inpDtml','').strip()
         message += setWfTransition(self, item.get('id',None), newId, newName, newFrom, newTo, newPerformer, newDtml)
-        message += self.getLangStr('MSG_CHANGED',manage_lang)
+        message += self.getZMILangStr('MSG_CHANGED')
         id = newId
       
       # Delete.
       # -------
-      elif btn in ['delete',self.getLangStr('BTN_DELETE',manage_lang)]:
+      elif btn in ['delete',self.getZMILangStr('BTN_DELETE')]:
         id = delWfItem(self, id, CONF_TRANSITIONS)
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       # Insert.
       # -------
-      elif btn == self.getLangStr('BTN_INSERT', manage_lang):
+      elif btn == self.getZMILangStr('BTN_INSERT'):
         item = {}
         newId = REQUEST.get('newId').strip()
         newName = REQUEST.get('newName').strip()
@@ -612,7 +610,7 @@ class WorkflowManager:
         newPerformer = REQUEST.get('newPerformer',[])
         newDtml = REQUEST.get('newDtml','').strip()
         message += setWfTransition(self, item.get('id',None), newId, newName, newFrom, newTo, newPerformer, newDtml)
-        message += self.getLangStr('MSG_INSERTED',manage_lang)%id
+        message += self.getZMILangStr('MSG_INSERTED')%id
         id = newId
       
       # Move to.
@@ -620,11 +618,11 @@ class WorkflowManager:
       elif btn == 'move_to':
         pos = REQUEST['pos']
         moveWfItem(self, id, pos, CONF_TRANSITIONS)
-        message = self.getLangStr('MSG_MOVEDOBJTOPOS', manage_lang)%(("<i>%s</i>"%id),(pos+1))
+        message = self.getZMILangStr('MSG_MOVEDOBJTOPOS')%(("<i>%s</i>"%id),(pos+1))
         id = ''
       
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_customizeWorkflowForm?id=%s&lang=%s&manage_lang=%s&manage_tabs_message=%s#_Transitions'%(id,lang,manage_lang,message))
+      return RESPONSE.redirect('manage_customizeWorkflowForm?id=%s&lang=%s&manage_tabs_message=%s#_Transitions'%(id,lang,message))
 
 ###################################################################################################
