@@ -509,7 +509,7 @@ def toXml(self, value, xhtml=0, encoding='utf-8'):
 # ---------------------------------------------------------------------------------------------
 #  _xmllib.getAttrToXml:
 # ---------------------------------------------------------------------------------------------
-def getAttrToXml(self, base, base_path, obj_attr, REQUEST):
+def getAttrToXml(self, base_path, data2hex, obj_attr, REQUEST):
   xml = ''
   
   #-- DATATYPE
@@ -536,7 +536,7 @@ def getAttrToXml(self, base, base_path, obj_attr, REQUEST):
     
     # Objects.
     if datatype in _globals.DT_BLOBS:
-      xml += value.toXml( self, base, base_path)
+      xml += value.toXml( self, base_path, data2hex)
     
     # XML.
     elif datatype == _globals.DT_XML or \
@@ -556,7 +556,7 @@ def getAttrToXml(self, base, base_path, obj_attr, REQUEST):
 # ---------------------------------------------------------------------------------------------
 #  _xmllib.getObjPropertyToXml:
 # ---------------------------------------------------------------------------------------------
-def getObjPropertyToXml(self, base, base_path, obj_attr, REQUEST):
+def getObjPropertyToXml(self, base_path, data2hex, obj_attr, REQUEST):
   xml = ''
   # Multi-Language Attributes.
   if obj_attr['multilang']:
@@ -564,14 +564,14 @@ def getObjPropertyToXml(self, base, base_path, obj_attr, REQUEST):
     langIds = self.getLangIds()
     for langId in langIds:
       REQUEST.set('lang',langId)
-      s_attr_xml = getAttrToXml( self, base, base_path, obj_attr, REQUEST)
+      s_attr_xml = getAttrToXml( self, base_path, data2hex, obj_attr, REQUEST)
       if len(s_attr_xml) > 0:
         xml += '\n<lang id="%s"'%langId
         xml += '>%s</lang>'%s_attr_xml
     REQUEST.set('lang',lang)
   # Simple Attributes.
   else:
-    xml += getAttrToXml( self, base, base_path, obj_attr, REQUEST)
+    xml += getAttrToXml( self, base_path, data2hex, obj_attr, REQUEST)
   # Return xml.
   return xml
 
@@ -579,38 +579,47 @@ def getObjPropertyToXml(self, base, base_path, obj_attr, REQUEST):
 # ---------------------------------------------------------------------------------------------
 #  _xmllib.getObjToXml:
 # ---------------------------------------------------------------------------------------------
-def getObjToXml(self, base, REQUEST, deep=True, base_path=''):
+def getObjToXml(self, REQUEST, incl_embedded=False, deep=True, base_path='', data2hex=False):
+  # Check Constraints.
+  root = getattr( self, '__root__', None)
+  if root is not None or self.meta_type == 'ZMSTrashcan':
+    return ''
+  ob = self
+  if ob.meta_type != 'ZMS':
+    base_path += self.id + '/'
+  if ob.meta_type == 'ZMSLinkElement' and ob.isEmbedded( REQUEST) and incl_embedded:
+    ob = ob.getRefObj()
   xml = []
   # Start tag.
-  xml.append('<%s'%self.xmlGetTagName())
+  xml.append('<%s'%ob.xmlGetTagName())
   id = self.id 
   prefix = _globals.id_prefix(id)
   if id == prefix:
     xml.append(' id_fix="%s"'%id)
   else:
     xml.append(' id="%s"'%id)
-  if self.getParentNode() is not None and self.getParentNode().meta_type == 'ZMSCustom':
-    xml.append('\n id_prefix="%s"'%_globals.id_prefix(self.id))
-  if self.meta_type == 'ZMSCustom':
-    xml.append('\n meta_id="%s"'%self.meta_id)
+  if ob.getParentNode() is not None and ob.getParentNode().meta_type == 'ZMSCustom':
+    xml.append('\n id_prefix="%s"'%_globals.id_prefix(ob.id))
+  if ob.meta_type == 'ZMSCustom':
+    xml.append('\n meta_id="%s"'%ob.meta_id)
   xml.append('>')
   # Attributes.
-  keys = self.getObjAttrs().keys()
-  if self.meta_type=='ZMSCustom' and self.getType()=='ZMSRecordSet':
-    keys = ['active',self.getMetaobjAttrIds(self.meta_id)[0]]
+  keys = ob.getObjAttrs().keys()
+  if ob.meta_type=='ZMSCustom' and ob.getType()=='ZMSRecordSet':
+    keys = ['active',ob.getMetaobjAttrIds(ob.meta_id)[0]]
   for key in keys:
-    obj_attr = self.getObjAttr(key)
+    obj_attr = ob.getObjAttr(key)
     if obj_attr['xml']:
-      ob_prop = getObjPropertyToXml( self, base, base_path, obj_attr, REQUEST)
+      ob_prop = getObjPropertyToXml( ob, base_path, data2hex, obj_attr, REQUEST)
       if len(ob_prop) > 0:
         xml.append('\n<%s>%s</%s>'%(key,ob_prop,key))
   # Process children.
   if deep:
-    xml.extend(map(lambda ob: getObjToXml( ob, base, REQUEST, deep, base_path), self.getChildNodes()))
+    xml.extend(map(lambda x: getObjToXml( x, REQUEST, incl_embedded, deep, base_path, data2hex), ob.getChildNodes()))
   # End tag.
-  xml.append('</%s>\n'%self.xmlGetTagName())
+  xml.append('</%s>\n'%ob.xmlGetTagName())
   # Return xml.
-  return "".join(xml)
+  return ''.join(xml)
 
 
 
