@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _zcatalogmanager.py
 #
 # $Id: _zcatalogmanager.py,v 1.8 2004/11/30 20:03:17 zmsdev Exp $
@@ -21,26 +21,33 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 import new
-from Products.ZCatalog import ZCatalog, Vocabulary, CatalogAwareness
+import re
+from Products.ZCatalog import ZCatalog, CatalogAwareness
 # Product Imports.
 import _globals
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+#  _zcatalogmanager.Empty
+# ------------------------------------------------------------------------------
+class Empty: pass
+
+
+# ------------------------------------------------------------------------------
 #  _zcatalogmanager.zcat_meta_types
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 zcat_meta_types = ['ZMS','ZMSFolder','ZMSDocument','ZMSCustom','ZMSSysFolder','ZMSFile']
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _zcatalogmanager.search_string:
 #
 #  Search string of given value.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def search_string(v):
   s = ''
   if v is not None:
@@ -55,48 +62,76 @@ def search_string(v):
         s += search_string(i)
   return s
 
-# -------------------------------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------------
 #  _zcatalogmanager.search_quote:
 #
 #  Remove HTML-Tags from given string.
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def search_quote(s, maxlen=255, tag='&middot;'):
   # remove all tags.
-  stop = False
-  while not stop:
-    iStartTag = s.find('<')
-    iEndTag = s.find('>',iStartTag)
-    if iStartTag >= 0 and iEndTag > iStartTag:
-      s = s[:iStartTag] + tag + s[iEndTag+1:]
-    else:
-      stop = True
+  s = re.sub( '<(.*?)>', '', s)
   # limit characters.
   if len(s) > maxlen:
     blank = s.find(' ',maxlen)
     s = s[:blank] + tag * 3
-  # search quote.
-  while s.find('>') >= 0:
-    i = s.find('>')
-    s = s[:i] + '&gt;' + s[i+1:]
-  while s.find('<') >= 0:
-    i = s.find('<')
-    s = s[:i] + '&lt;' + s[i+1:]
   # return quoted search string.
   return s
 
+# ------------------------------------------------------------------------------
+#  _zcatalogmanager.addVocabulary:
+# ------------------------------------------------------------------------------
+def addVocabulary(cat):
+  from Products.ZCatalog import Vocabulary
 
-###################################################################################################
-###################################################################################################
+  #-- Remove Default-Vocabulary
+  ids = cat.objectIds( ['Vocabulary'])
+  if len( ids) > 0:
+    cat.manage_delObjects( ids)
+      
+  #-- Add ISO 8859-1 Vocabulary
+  # see ZCatalogs with Umlauts
+  # http://www.zope.org/Members/strobl/HowTos/Iszcatalog
+  globbing = 1
+  splitter = "ISO_8859_1_Splitter"
+  voc = Vocabulary.Vocabulary( "Vocabulary", "Default vocabulary", globbing, splitter)
+  cat._setObject( voc.id, voc)
+
+# ------------------------------------------------------------------------------
+#  _zcatalogmanager.addLexicon:
+# ------------------------------------------------------------------------------
+def addLexicon(cat):
+  elem = []
+  wordSplitter = Empty()
+  wordSplitter.group = 'Word Splitter'
+  wordSplitter.name = 'HTML aware splitter'
+  caseNormalizer = Empty()
+  caseNormalizer.group = 'Case Normalizer'
+  caseNormalizer.name = 'Case Normalizer'
+  stopWords = Empty()
+  stopWords.group = 'Stop Words'
+  stopWords.name = 'Remove listed and single char words'
+  elem.append(wordSplitter)
+  elem.append(caseNormalizer)
+  elem.append(stopWords)
+  try:      
+    cat.manage_addProduct['ZCTextIndex'].manage_addLexicon('Lexicon', 'Default lexicon', elem)
+  except:
+    pass
+
+
+################################################################################
+################################################################################
 ###
 ###   class ZCatalogItem
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class ZCatalogItem(CatalogAwareness.CatalogAware): 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.txng_get_key:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def txng_get_key(self):
       keys = []
       for key in self.getObjAttrs().keys():
@@ -109,13 +144,13 @@ class ZCatalogItem(CatalogAwareness.CatalogAware):
       return None
       
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.txng_get:
     #
-    #  This code provides a hook called txng_get(), when you add a TextIndexNG index on
-    #  SearchableText the indexer 'senses' that you provided your content with the hook and 
-    #  automagically uses it.
-    # ------------------------------------------------------------------------------------------
+    #  This code provides a hook called txng_get(), when you add a TextIndexNG 
+    #  index on SearchableText the indexer 'senses' that you provided your 
+    #  content with the hook and automagically uses it.
+    # --------------------------------------------------------------------------
     def txng_get(self, attr=('SearchableText',)):
       """Special searchable text source for text indexng2"""
       key = self.txng_get_key()
@@ -133,20 +168,20 @@ class ZCatalogItem(CatalogAwareness.CatalogAware):
           return (source, mimetype, encoding)
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZCatalogItem.search_quote:
     #
     #	Remove HTML-Tags.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def search_quote(self, s, maxlen=255, tag='&middot;'):
       return search_quote(s,maxlen,tag)
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZCatalogItem.search_encode:
     #
     #	Encodes given string.
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def search_encode(self, s):
       try:
         s = unicode( s, 'utf-8').encode( 'latin-1')
@@ -161,28 +196,28 @@ class ZCatalogItem(CatalogAwareness.CatalogAware):
           while s.find( capital) >= 0:
             s = s.replace( capital, letter)
       except ( UnicodeDecodeError, UnicodeEncodeError):
-        pass
+        _globals.writeException(self,"[search_encode]")
       return s
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZCatalogItem.getCatalogNavUrl:
     #
     #	Returns catalog-navigation url.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getCatalogNavUrl(self, REQUEST):
       return self.url_inherit_params(REQUEST['URL'],REQUEST,['qs'])
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.catalogText:
     #
     #  Catalog text.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def catalogText(self, REQUEST):
       v = ''
       if self.isVisible(REQUEST):
-        for key in self.getObjAttrs().keys():
+        for key in filter( lambda x: x.find('_') != 0, self.getObjAttrs().keys()):
           obj_attr = self.getObjAttr(key)
           if obj_attr['xml']:
             datatype = obj_attr['datatype_key']
@@ -195,17 +230,17 @@ class ZCatalogItem(CatalogAwareness.CatalogAware):
               if obj_attr['key'] in ['title','titlealt','titleshort']:
                 value = value * 3
               v += value
-        for ob in self.getChildNodes( REQUEST):
+        for ob in self.getChildNodes():
           if not ob.isCatalogItem():
             v += ob.catalogText(REQUEST)
       return v
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.catalogData:
     #
     #  Catalog data.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def catalogData(self, REQUEST):
       source = ''
       if self.isVisible( REQUEST):
@@ -219,29 +254,30 @@ class ZCatalogItem(CatalogAwareness.CatalogAware):
       return source
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.zcat_data:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def zcat_data( self, lang):
       zcat = self.catalogData( {'lang':lang})
       return zcat
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.zcat_text:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def zcat_text( self, lang): 
       zcat = self.catalogText( {'lang':lang})
       zcat = self.search_encode( zcat)
       return zcat
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.synchronizeSearch:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def synchronizeSearch(self, REQUEST, forced=0):
       if self.getConfProperty('ZMS.CatalogAwareness.active',1) or forced:
-        _globals.writeBlock( self, '[synchronizeSearch]')
+        if _globals.debug( self):
+          _globals.writeLog( self, '[synchronizeSearch]')
         for ref_by in self.getRefByObjs(REQUEST):
           ref_ob = self.getLinkObj(ref_by,REQUEST)
           if ref_ob is not None and \
@@ -265,11 +301,11 @@ class ZCatalogItem(CatalogAwareness.CatalogAware):
           ob.reindex_object()
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.isCatalogItem:
     #
     #  Returns true if this is a catalog item.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isCatalogItem(self):
       b = False
       b = b or (self.isPage() or self.meta_type == 'ZMSFile')
@@ -277,9 +313,9 @@ class ZCatalogItem(CatalogAwareness.CatalogAware):
       return b
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.getCatalogItem:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getCatalogItem(self):
       ob = self
       while ob is not None:
@@ -289,37 +325,37 @@ class ZCatalogItem(CatalogAwareness.CatalogAware):
       return ob
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogItem.reindexCatalogItem:
     #
     #  Reindex catalog item.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def reindexCatalogItem(self, REQUEST):
       message = ''
       if self.isCatalogItem():
-	for lang in self.getLangIds():
-	  REQUEST.set('lang',lang)
-	  self.synchronizeSearch(REQUEST=REQUEST,forced=1)
+        for lang in self.getLangIds():
+          REQUEST.set('lang',lang)
+          self.synchronizeSearch(REQUEST=REQUEST,forced=1)
       for ob in self.getChildNodes():
         ob.reindexCatalogItem(REQUEST)
       # Return with message.
       return message
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class ZCatalogManager
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class ZCatalogManager:
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogManager.getCatalog:
     #
     #  Returns catalog.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getCatalog(self):
       context = self.getDocumentElement()
       obs = context.objectValues(['ZCatalog'])
@@ -328,11 +364,11 @@ class ZCatalogManager:
       return obs[0]
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogManager.recreateCatalog:
     #
     #  Recreates catalog.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def recreateCatalog(self):
       message = ''
       context = self.getDocumentElement()
@@ -341,7 +377,7 @@ class ZCatalogManager:
       obs = context.objectValues( [ 'ZCatalog'])
       if len( obs) == 0:
         cat_id = 'catalog'
-        cat_title = 'Catalog'
+        cat_title = 'Default catalog'
         vocab_id = 'create_default_catalog_'
         zcatalog = ZCatalog.ZCatalog(cat_id, cat_title, vocab_id, context)
         context._setObject(zcatalog.id, zcatalog)
@@ -349,20 +385,11 @@ class ZCatalogManager:
       else:
         zcatalog = obs[ 0]
       
-      #-- Remove Default-Vocabulary
-      ids = zcatalog.objectIds(['Vocabulary'])
-      if len(ids) > 0:
-        zcatalog.manage_delObjects(ids,None)
+      #-- Add vocabulary
+      addVocabulary( zcatalog)
       
-      #-- Add ISO 8859-1 Vocabulary
-      # see ZCatalogs with Umlauts
-      # http://www.zope.org/Members/strobl/HowTos/Iszcatalog
-      id = "Vocabulary"
-      title = id
-      globbing = 1
-      splitter = "ISO_8859_1_Splitter"
-      oVocabulary = Vocabulary.Vocabulary(id,title,globbing,splitter)
-      zcatalog._setObject(oVocabulary.id,oVocabulary)
+      #-- Add lexicon
+      addLexicon( zcatalog)
       
       #-- Clear catalog
       zcatalog.manage_catalogClear()
@@ -393,28 +420,33 @@ class ZCatalogManager:
         message += "Index ["
         index_name = 'zcat_text_%s'%lang
         setattr( ZCatalogItem, index_name, new.function(ZCatalogItem.zcat_text.func_code, {}, index_name, (lang,)))
-        index_type = 'TextIndex'
-        index_extras = None
+        index_type = 'ZCTextIndex'
+        index_extras = Empty()
+        index_extras.doc_attr = index_name
+        index_extras.index_type = 'Okapi BM25 Rank'
+        index_extras.lexicon_id = 'Lexicon'            
         zcatalog.manage_addColumn(index_name)
         zcatalog.manage_addIndex(index_name,index_type,index_extras)
         message += index_name
         index_type = None
-        for k in [ 'TextIndex', 'TextIndexNG2', 'TextIndexNG3']:
+        for k in [ 'ZCTextIndex', 'TextIndexNG2', 'TextIndexNG3']:
           if k in index_types: index_type = k
         if self.getConfProperty('ZCatalog.TextIndexNG',0)==1:
           index_name = 'zcat_data_%s'%lang
           setattr( ZCatalogItem, index_name, new.function(ZCatalogItem.zcat_data.func_code, {}, index_name, (lang,)))
-          if index_type == 'TextIndex':
-            index_extras = None
+          index_extras = Empty()
+          if index_type == 'ZCTextIndex':
+            index_extras.doc_attr = index_name
+            index_extras.index_type = 'Okapi BM25 Rank'
+            index_extras.lexicon_id = 'Lexicon'            
           else:
-            index_extras = _globals.MyClass()
-            setattr(index_extras,'default_encoding','utf-8')
-            setattr(index_extras,'indexed_fields',index_name)
-            setattr(index_extras,'near_distance',5)
-            setattr(index_extras,'splitter_casefolding',1)
-            setattr(index_extras,'splitter_max_len',64)
-            setattr(index_extras,'splitter_separators','.+-_@')
-            setattr(index_extras,'splitter_single_chars',0)
+            index_extras.default_encoding = 'utf-8'
+            index_extras.indexed_fields = index_name
+            index_extras.near_distance = 5
+            index_extras. splitter_casefolding = 1
+            index_extras.splitter_max_len = 64
+            index_extras.splitter_separators = '.+-_@'
+            index_extras.splitter_single_chars = 0
             if index_type == 'TextIndexNG2':
               setattr(index_extras,'use_converters',1)
               setattr(index_extras,'use_normalizer','')
@@ -433,11 +465,11 @@ class ZCatalogManager:
       return message
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogManager.reindexCatalog:
     #
     #  Reindex catalog.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def reindexCatalog(self, REQUEST):
       message = ''
       
@@ -452,9 +484,9 @@ class ZCatalogManager:
       return message
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZCatalogManager.getCatalogQueryString:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getCatalogQueryString(self, raw, option='AND'):
       qs = ''
       raw = raw.replace(' and ',' AND ')
@@ -487,11 +519,11 @@ class ZCatalogManager:
       return qs
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogManager.getCatalogPathObject:
     #
     #  Returns object from catalog-path.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getCatalogPathObject(self, path):
       ob = self.getHome()
       l = path.split( '/')
@@ -507,11 +539,11 @@ class ZCatalogManager:
       return ob
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZCatalogManager.submitCatalogQuery:
     #
     #  Submits query to catalog.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def submitCatalogQuery(self, search_query, search_order_by, search_meta_types, search_clients, REQUEST):
 
       #-- Initialize local variables.
@@ -519,7 +551,7 @@ class ZCatalogManager:
       rtn = []
     
       #-- Process clients.
-      if search_clients == 1:
+      if self.getConfProperty('ZCatalog.portalClients',1) == 1 and search_clients == 1:
         for portalClient in self.getPortalClients():
           rtn.extend(portalClient.submitCatalogQuery( search_query, search_order_by, search_meta_types, search_clients, REQUEST))
           
@@ -618,8 +650,6 @@ class ZCatalogManager:
               sum_url = self.url_append_params(sum_url,{'ZMS_PARAM0':'search','ZMS_PARAM1':search_query})
           result = {}
           result['ob'] = ob
-          result['title'] = ob.getTitle(REQUEST)
-          result['description'] = ob.getDCDescription(REQUEST)
           result['score'] = sum_score
           result['time'] = sum_time
           result['url'] = ob.getDeclUrl(REQUEST) + '/' + sum_url
@@ -635,4 +665,4 @@ class ZCatalogManager:
       #-- Return objects in correct sort-order.
       return rtn
 
-###################################################################################################
+################################################################################
