@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # _zreferableitem.py
 #
 # $Id: _zreferableitem.py,v 1.9 2004/11/30 20:03:17 zmsdev Exp $
@@ -21,21 +21,21 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from Globals import HTML, HTMLFile
-from OFS.CopySupport import absattr
 import copy
+import operator
 import time
 import urllib
 # Product Imports.
 import _globals
 import _objattrs
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _zreferableitem.getMedlineLink:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def getMedlineLink(url):
   try:
     http_prefix = 'http://'
@@ -46,38 +46,41 @@ def getMedlineLink(url):
     pass
   return url
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _zreferableitem.isMailLink:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def isMailLink(url):
-  return url.lower().find('mailto:') == 0
+  rtn = url.lower().find('mailto:') == 0
+  return rtn
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _zreferableitem.isInternalLink:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def isInternalLink(url):
-  return type(url) is type('') and len(url)>=3 and url[:2]=='{$' and url[-1]=='}'
+  rtn = type(url) is type('') and url.startswith('{$') and url.endswith('}')
+  return rtn
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  _zreferableitem.absolute_home:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def absolute_home(ob):
-  return ''.join( map( lambda x: x+'/', list(ob.getVirtualRootPhysicalPath( ob.getHome()))))[:-1]
+  rtn = ''.join( map( lambda x: x+'/', list(ob.getVirtualRootPhysicalPath( ob.getHome()))))[:-1]
+  return rtn
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   class ZReferableItem
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class ZReferableItem: 
 
   # Management Permissions.
   # -----------------------
   __authorPermissions__ = (
-		'manage_RefForm',
+		'manage_RefForm', 'manage_browse_objs',
 		)
   __ac_permissions__=(
 		('ZMS Author', __authorPermissions__),
@@ -86,12 +89,12 @@ class ZReferableItem:
   # Management Interface.
   # ---------------------
   manage_RefForm = HTMLFile('dtml/zmslinkelement/manage_refform', globals())
-  browse_objs = HTMLFile('dtml/zmslinkelement/browse_objs', globals()) 
+  manage_browse_objs = browse_objs = HTMLFile('dtml/zmslinkelement/browse_objs', globals()) 
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.getRelObjPath:
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getRelObjPath(self, ob):
     ref = '.'
     currntPath = self.getSelf( self.PAGES).absolute_url()
@@ -112,9 +115,9 @@ class ZReferableItem:
     return ref
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.getRefObjPath:
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getRefObjPath(self, ob):
     ref = ''
     if ob is not None:
@@ -140,18 +143,18 @@ class ZReferableItem:
 
 
   """
-  ###############################################################################################
+  ##############################################################################
   ###  
   ###  Links FROM other objects.
   ### 
-  ###############################################################################################
+  ##############################################################################
   """
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.getRefByObjs:
   #
   #  Returns references BY other objects.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getRefByObjs(self, REQUEST={}):
     ref_by = []
     if _objattrs.hasobjattr(self,'ref_by'):
@@ -162,11 +165,11 @@ class ZReferableItem:
     return ref_by
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.delRefByObjs:
   #
   #  Deletes references BY other objects.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def delRefByObjs(self, ids=[]):
     key = 'ref_by'
     v = getattr(self,key,[])
@@ -182,41 +185,42 @@ class ZReferableItem:
       setattr(self,'ref_by',ref_by)
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.synchronizeRefByObjs:
   #
   #  Synchronizes references BY other objects.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def synchronizeRefByObjs(self, strict=1):
     key = 'ref_by'
     v = getattr(self,key,[])
     ref_by = []
     for i in v:
       ob = self.getLinkObj(i)
-      if ob is not None and \
-         ob.meta_type[:3] == 'ZMS':
+      if ob is not None and ob.meta_type[:3] == 'ZMS':
         ob_path = self.getRefObjPath(ob)
         if not ob_path in ref_by:
           ref_by.append(ob_path)
+        if ob.meta_type == 'ZMSLinkElement' and ob.isEmbedded( self.REQUEST):
+          ob.synchronizePublicAccess()
     if strict or len(ref_by) < len(v):
       setattr(self,'ref_by',ref_by)
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.clearRegisteredRefObjs:
   #
   #  Clears registered referencing objects.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def clearRegisteredRefObjs(self, REQUEST):
     ref_by = []
     setattr(self,'ref_by',ref_by)
 
     
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.registerRefObj:
   #
   #  Registers referencing object.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def registerRefObj(self, ob, REQUEST):
     ref = self.getRefObjPath(ob)
     if _globals.debug( self): 
@@ -228,11 +232,11 @@ class ZReferableItem:
     setattr(self,'ref_by',ref_by)
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.unregisterRefObj:
   #
   #  Unregisters referencing object.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def unregisterRefObj(self, ob, REQUEST):
     if _globals.debug( self): 
       _globals.writeLog( self, "[unregisterRefObj]: %s(%s)"%(ob.id,ob.meta_type))
@@ -251,11 +255,11 @@ class ZReferableItem:
     setattr(self,'ref_by',ref_by)
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.refreshRefObj:
   #
   #  Refreshs referencing object.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def refreshRefObj(self, ob, REQUEST):
     if _globals.debug( self): 
       _globals.writeLog( self, "[refreshRefObj]: %s(%s) -> %s(%s)"%(self.id,self.meta_type,ob.id,ob.meta_type))
@@ -264,18 +268,18 @@ class ZReferableItem:
 
     
   """
-  ###############################################################################################
+  ##############################################################################
   ###  
   ###  References TO other objects.
   ### 
-  ###############################################################################################
+  ##############################################################################
   """
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.getRefToObjs:
   #
   #  Returns list of references TO other objects.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getRefToObjs(self, REQUEST):
     ref_to =  []
     for key in self.getObjAttrs().keys():
@@ -288,11 +292,11 @@ class ZReferableItem:
     return ref_to
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.synchronizeRefToObjs:
   #
   #  Synchronizes references TO other objects.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def synchronizeRefToObjs(self):
     if _globals.debug( self): 
       _globals.writeLog( self, "[synchronizeRefToObjs]")
@@ -308,11 +312,11 @@ class ZReferableItem:
             ref_obj.refreshRefObj(self,req)
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.refreshRefToObj:
   #
   #  Refreshs reference TO given destination.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def refreshRefToObj(self, dest_obj, REQUEST):
     if _globals.debug( self): 
       _globals.writeLog( self, "[refreshRefToObj]: %s -> dest_obj=%s(%s)"%(self.id,dest_obj.absolute_url(),dest_obj.meta_type))
@@ -331,18 +335,18 @@ class ZReferableItem:
 
 
   """
-  ###############################################################################################
+  ##############################################################################
   ###  
   ###  Process Events 
   ### 
-  ###############################################################################################
+  ##############################################################################
   """
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.onMoveRefObj:
   #
   #  This method is executed after an object has been moved.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def onMoveRefObj(self, REQUEST, deep=0):
     if _globals.debug( self): 
       _globals.writeLog( self, "[onMoveRefObj]")
@@ -360,11 +364,11 @@ class ZReferableItem:
         ob.refreshRefToObj(self,REQUEST)
 
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.onCopyRefObj:
   #
   #  This method is executed after an object has been copied.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def onCopyRefObj(self, REQUEST, deep=0):
     if _globals.debug( self): 
       _globals.writeLog( self, "[onCopyRefObj]")
@@ -380,18 +384,18 @@ class ZReferableItem:
 
 
   """
-  ###############################################################################################
+  ##############################################################################
   ###  
   ###  Resolve Links 
   ### 
-  ###############################################################################################
+  ##############################################################################
   """
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.getLinkObj:
   #
   #  Resolves internal/external links and returns Object.
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   def getLinkObj(self, url, REQUEST={}):
     ob = None
     if isInternalLink(url):
@@ -420,56 +424,170 @@ class ZReferableItem:
         else:
           docElmnt = self.getDocumentElement()
         if docElmnt is not None:
-          try:
-            ob = docElmnt.findObjId(path,REQUEST)
-          except:
-            _globals.writeException(self,'[getLinkObj]')
-        if ob is None:
-          _globals.writeLog( self,'[getLinkObj]: Invalid internal url %s'%url)
+          ob = docElmnt.findObjId(path,REQUEST)
     return ob
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.getLinkUrl:
   #
   #  Resolves internal/external links and returns URL.
-  # ---------------------------------------------------------------------------------------------
-  def getLinkUrl(self, url, REQUEST={}): 
+  # ----------------------------------------------------------------------------
+  def getLinkUrl( self, url, REQUEST={}): 
     if isInternalLink(url):
       ob = self.getLinkObj(url,REQUEST)
-      url = None
       if ob is not None:
         if ob.meta_type == 'ZMSFile':
           file = ob.getFile(REQUEST)
           if file is not None:
-            url = file.getHref(REQUEST)
+            return file.getHref(REQUEST)
         else:
-          url = ob.getHref2IndexHtml(REQUEST)
+          return ob.getHref2IndexHtml(REQUEST)
+      else:
+        return './index_%s.html?op=not_found&url=%s'%(REQUEST.get('lang',self.getPrimaryLanguage()),url)
     elif isMailLink (url): 
       prefix = 'mailto:'
-      url = prefix + self.encrypt_ordtype(url[len(prefix):])
+      return prefix + self.encrypt_ordtype(url[len(prefix):])
     return url
 
-  # ---------------------------------------------------------------------------------------------
+  # ----------------------------------------------------------------------------
   #  ZReferableItem.getLinkHtml:
   #
   #  Resolves internal/external links and returns Html.
-  # ---------------------------------------------------------------------------------------------
-  def getLinkHtml(self, url, html='<a href="%s">&raquo;</a>', REQUEST={}):
+  # ----------------------------------------------------------------------------
+  def getLinkHtml( self, url, html='<a href="%s">&raquo;</a>', REQUEST={}):
     s = ''
-    if html in self.getMetaobjIds():
-      metaObj = self.getMetaobj( html) 
-      for metaObjAttr in metaObj['attrs']:
-        if metaObjAttr['type'] == 'method' and \
-           metaObjAttr['id'] == 'getLinkHtml':
-          REQUEST.set( 'ref_id', url)
-          s = self.dt_html( metaObjAttr['custom'], REQUEST)
-    else:
-      ob = self.getLinkObj(url,REQUEST)
-      if ob is not None:
-        if ob.isActive(REQUEST) and \
-           ob.isVisible(REQUEST):
-          url = ob.getHref2IndexHtml(REQUEST)
-          s = html%url
+    ob = self
+    while ob is not None:
+      if html in ob.getMetaobjIds():
+        metaObj = ob.getMetaobj( html) 
+        for metaObjAttr in metaObj['attrs']:
+          if metaObjAttr['type'] == 'method' and \
+             metaObjAttr['id'] == 'getLinkHtml':
+            REQUEST.set( 'ref_id', url)
+            return self.dt_html( metaObjAttr['custom'], REQUEST)
+      ob = self.getPortalMaster()
+    ob = self.getLinkObj(url,REQUEST)
+    if ob is not None:
+      if ob.isActive(REQUEST) and \
+         ob.isVisible(REQUEST):
+        url = ob.getHref2IndexHtml(REQUEST)
+        s = html%url
     return s
 
-###################################################################################################
+  # ----------------------------------------------------------------------------
+  #  ZReferableItem.synchronizeRefs:
+  #  
+  #  @param
+  #  @return
+  # ----------------------------------------------------------------------------
+  def synchronizeRefs( self, ob_id=None):
+    portalMaster = self.getPortalMaster()
+    if portalMaster is not None:
+      return portalMaster.synchronizeRefs()
+    
+    message = ''
+    t0 = time.time()
+    
+    obs = {}
+    map( lambda x: operator.setitem(obs, x.absolute_url(), x), _globals.objectTree( self, True))
+    message += 'Load object-tree (in '+str(int((time.time()-t0)*100.0)/100.0)+' secs.)<br/>'
+    abs_urls = obs.keys()
+    abs_urls.sort()
+    langs = self.getLangIds()
+    
+    for abs_url in abs_urls:
+      ob  = obs[ abs_url]
+      
+      # Process recordset.
+      if ob.meta_type == 'ZMSCustom' and ob.getType()=='ZMSRecordSet':
+        key = ob.getMetaobjAttrIds(ob.meta_id)[0]
+        obj_attr = ob.getObjAttr(key)
+        for lang in langs:
+          for obj_vers in ob.getObjVersions():
+            v = _objattrs.getobjattr(ob,obj_vers,obj_attr,lang)
+            c = 0
+            for r in v:
+              for k in r.keys():
+                v = r[k]
+                o = v
+                if type(v) is type(''):
+                  l = v.split('{$')
+                  if l > 1:
+                    m = [l[0]]
+                    for i in l[1:]:
+                      ref = i[:i.find('}')]
+                      if ref.startswith('__') and ref.endswith('__'):
+                        ref = ref[2:-2]
+                      if len( ref.split('@')) == 1:
+                        home = ob.getHome().id
+                      else:
+                        home = ref.split('@')[0].split('/')[-1]
+                      id = ref.split('@')[-1].split('/')[-1]
+                      if len( id) == 0:
+                        id = 'content'
+                      f = filter( lambda x: x.find('/%s/content'%home) > 0 and x.endswith('/%s'%id), abs_urls)
+                      if len( f) == 0:
+                        ref = '__%s__'%ref
+                      else:
+                        ref = ob.getRefObjPath( obs[f[0]])[2:-1]
+                      if ref.startswith('__') and ref.endswith('__'):
+                        message += '<a href="%s/manage_main" target="_blank">%s(%s).%s[%i]=%s</a><br/>'%(ob.absolute_url(),ob.absolute_url(),ob.meta_type,k,c,ref)
+                      m.append(ref+i[i.find('}'):])
+                    v = '{$'.join(m)
+                    if v != o:
+                      r[k] = v
+              c += 1
+      
+      # Process object. 
+      else:
+        for key in ob.getObjAttrs().keys():
+          obj_attr = ob.getObjAttr(key)
+          datatype = obj_attr['datatype_key']
+          if datatype in _globals.DT_STRINGS:
+            for lang in langs:
+              for obj_vers in ob.getObjVersions():
+                v = _objattrs.getobjattr(ob,obj_vers,obj_attr,lang)
+                o = v
+                if type(v) is type(''):
+                  l = v.split('{$')
+                  if l > 1:
+                    m = [l[0]]
+                    for i in l[1:]:
+                      ref = i[:i.find('}')]
+                      if ref.startswith('__') and ref.endswith('__'):
+                        ref = ref[2:-2]
+                      if len( ref.split('@')) == 1:
+                        home = ob.getHome().id
+                      else:
+                        home = ref.split('@')[0].split('/')[-1]
+                      id = ref.split('@')[-1].split('/')[-1]
+                      if len( id) == 0:
+                        id = 'content'
+                      f = filter( lambda x: x.find('/%s/content'%home) > 0 and x.endswith('/%s'%id), abs_urls)
+                      if len( f) == 0:
+                        ref = '__%s__'%ref
+                      else:
+                        ref = ob.getRefObjPath( obs[f[0]])[2:-1]
+                      if ref.startswith('__') and ref.endswith('__'):
+                        message += '<a href="%s/manage_main" target="_blank">%s(%s).%s=%s</a><br/>'%(ob.absolute_url(),ob.absolute_url(),ob.meta_type,key,ref)
+                      m.append(ref+i[i.find('}'):])
+                    v = '{$'.join(m)
+                    if v != o:
+                      _objattrs.setobjattr(ob,obj_vers,obj_attr,v,lang)
+
+    if ob_id is not None:
+      # Return with desired object.
+      home = ob_id.split('@')[0]
+      id = ob_id.split('@')[1]
+      f = filter( lambda x: x.find('/%s/content'%home) > 0 and x.endswith('/%s'%id), abs_urls)
+      if len( f) == 0:
+        return None
+      else:
+        return obs[f[0]]
+    
+    else:
+      # Return with message.
+      message += ' (in '+str(int((time.time()-t0)*100.0)/100.0)+' secs.)'
+      return message
+
+################################################################################
