@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # zms.py
 #
 # $Id: zms.py,v 1.13 2004/03/24 18:05:13 zmsdev Exp $
@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
@@ -35,7 +35,6 @@ import urllib
 # Product imports.
 import _accessmanager
 import _builder
-import _cachemanager
 import _confmanager
 import _enummanager
 import _fileutil
@@ -43,6 +42,7 @@ import _ftpmanager
 import _globals
 import _importable
 import _language
+import _metaobjmanager
 import _multilangmanager
 import _objattrs
 import _textformatmanager
@@ -59,7 +59,6 @@ from zmsgraphic import ZMSGraphic
 from zmslinkcontainer import ZMSLinkContainer
 from zmslinkelement import ZMSLinkElement
 from zmsnote import ZMSNote
-from zmsrubrik import ZMSRubrik
 from zmssqldb import ZMSSqlDb
 from zmssysfolder import ZMSSysFolder
 from zmstable import ZMSTable
@@ -69,40 +68,22 @@ from zmstextarea import ZMSTextarea
 from zmstrashcan import ZMSTrashcan
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C o m m o n   F u n c t i o n ( s )
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  ZMS.recurse_updateVersionBuild:
 #
 #  Update version build.
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def recurse_updateVersionBuild(docElmnt, self, REQUEST):
   message = ''
 
-  ##### Build 124a: Remove sort_ids from object-versions. ####
-  if getattr( docElmnt, 'build', '000') < '124':
-    if self.version_live_id is not None:
-      setattr( self, 'sort_id', getattr( getattr( self, self.version_live_id), 'sort_id', 's0000'))
-    for ob_vers in self.objectValues( ['ZMSAttributeContainer']):
-      try:
-        delattr( ob_vers, 'sort_id')
-      except:
-        pass
-
-  ##### Build 125a: Remove work-versions. ####
-  if getattr( docElmnt, 'build', '000') < '125':
-    if len( getObjStates( self)) == 0 and self.version_live_id is not None and self.version_work_id in self.objectIds(['ZMSAttributeContainer']):
-      ids = []
-      ids.append( self.version_work_id)
-      self.version_work_id = None
-      self.manage_delObjects( ids=ids)
-  
   ##### Build 126a: ZMSFolder. ####
   if getattr( docElmnt, 'build', '000') < '126':
     if self.meta_type == 'ZMS':
@@ -142,15 +123,22 @@ def recurse_updateVersionBuild(docElmnt, self, REQUEST):
     # Copy ZMSRubriks into ZMSFolders.
     for rubrik in self.objectValues( ['ZMSRubrik']):
       rubrik_id = rubrik.id
+      rubrik_local_roles = list( rubrik.get_local_roles())      
       folder_id = rubrik.id[:-1]
       folder = ZMSFolder( folder_id)
       self._setObject( folder.id, folder)
+      # Copy attributes from ZMSRubrik to ZMSFolder.
       folder = getattr( self, folder.id)
       for key in rubrik.__dict__.keys():
         if key != 'id' and hasattr( rubrik, key):
           v = getattr( rubrik, key)
           if key == '__work_state__' or v is None or type( v) is type( ''):
             setattr( folder, key, v)
+      # Copy local-roles from ZMSRubrik to ZMSFolder.
+      for local_role in list( rubrik_local_roles):
+        id = local_role[ 0]
+        roles = local_role[ 1]
+        folder.manage_setLocalRoles( id, roles)
       # Move sub-objects from ZMSRubrik to ZMSFolder.
       cb_copy_data = rubrik.manage_cutObjects( rubrik.objectIds())
       folder.manage_pasteObjects( cb_copy_data)
@@ -217,11 +205,58 @@ def recurse_updateVersionBuild(docElmnt, self, REQUEST):
                   _globals.writeBlock( self, "[recurse_updateVersionBuild]: Attribute: %s"%key)
                   setobjattr(self,obj_vers,obj_attr,data,lang)
 
-  ##### Build 127a: ZMSFolder (ii). ####
+  ##### Build 128a: ZMSFolder (iii). ####
   if getattr( docElmnt, 'build', '000') < '128':
     if self.meta_type == 'ZMSFolder':
       self.synchronizePublicAccess()
-  
+
+  ##### Build 129a: Access-Rights ####
+  if getattr( docElmnt, 'build', '000') < '129':
+    mapping = { 
+      'attr_has_subscriber': 'attr_dc_accessrights_restricted',
+      'attr_dc_accessrights': 'attr_dc_accessrights_restrictedEditors'
+      }
+    if self.meta_type == 'ZMS':
+      # Meta-Attributes.
+      metaDictAttrs = self.getConfProperty('ZMS.custom.metas',[])
+      for i in range( len( metaDictAttrs) / 2):
+        id = metaDictAttrs[ i * 2]
+        if id in mapping.keys():
+          ob = metaDictAttrs[ i * 2 + 1]
+          ob[ 'id'] = mapping[ id][ 5:]
+          del metaDictAttrs[ i * 2]
+          metaDictAttrs.insert( i * 2, mapping[ id])
+      # Meta-Objects.
+      metaObjs = self.getConfProperty('ZMS.custom.objects',{})
+      for metaObjId in metaObjs.keys():
+        metaObj = metaObjs[ metaObjId]
+        for metaObjAttr in metaObj.get( '__obj_attrs__', []):
+          if metaObjAttr[ 'id'] in mapping.keys():
+            metaObjAttr[ 'id'] = mapping[ metaObjAttr[ 'id']]
+      # Synchronize.
+      self.synchronizeObjAttrs()
+    # Attributes.
+    changed = False
+    for key in mapping.keys():
+      for ob_vers in self.objectValues( ['ZMSAttributeContainer']):
+        for lang in self.getLangIds():
+          if hasattr( ob_vers, key+'_'+lang):
+            try:
+              setattr( ob_vers, mapping[ key]+'_'+lang, getattr( ob_vers, key+'_'+lang))
+              delattr( ob_vers, key+'_'+lang)
+              changed = True
+            except:
+              pass 
+        if hasattr( ob_vers, key):
+          try:
+            setattr( ob_vers, mapping[ key], getattr( ob_vers, key))
+            delattr( ob_vers, key)
+            changed = True
+          except:
+            pass 
+    if changed:
+      self.synchronizePublicAccess()
+
   # Recursion.
   for ob in self.objectValues( self.dGlobalAttrs.keys()):
     recurse_updateVersionBuild(docElmnt, ob, REQUEST)
@@ -230,22 +265,17 @@ def recurse_updateVersionBuild(docElmnt, self, REQUEST):
   return message
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  ZMS.recurse_updateVersionPatch:
 #
 #  Update version patch.
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def recurse_updateVersionPatch(docElmnt, self, REQUEST):
   message = ''
 
-  ##### Build 125k: ZMSFolder. ####
-  if getattr( docElmnt, 'build', '000') > '000' and \
-     getattr( docElmnt, 'build', '000') <= '125' and \
-     getattr( docElmnt, 'patch', '000') < 'k':
-    self.setConfProperty('ZMSFolder.enabled',self.getConfProperty('ZMSFolder.enabled',0))
-
+  _metaobjmanager.recurse_updateVersionPatch(docElmnt, self, REQUEST)
   _confmanager.updateConf(self,REQUEST)
-  self.getStylesheet()
+  _confmanager.initCSS(self)
   self.getSequence()
   self.synchronizeObjAttrs()
   self.initLangStr()
@@ -255,9 +285,9 @@ def recurse_updateVersionPatch(docElmnt, self, REQUEST):
   return message
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  initTheme:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def initTheme(self, theme, folder_id, REQUEST):
 
   ### Import theme from ZEXP.
@@ -271,14 +301,13 @@ def initTheme(self, theme, folder_id, REQUEST):
   return getattr(self,folder_id)
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  initZMS:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def initZMS(self, titleshort, title, lang, manage_lang, REQUEST):
   
   ### Constructor.
-  id = 'content'
-  obj = ZMS(id)
+  obj = ZMS()
   self._setObject(obj.id, obj)
   obj = getattr(self,obj.id)
   
@@ -301,7 +330,7 @@ def initZMS(self, titleshort, title, lang, manage_lang, REQUEST):
   _confmanager.initConf(obj, 'default_'+manage_lang, REQUEST)
   
   ### Init text-formats.
-  xml = open(package_home(globals())+'/import/textfmt.xml')
+  xml = open(package_home(globals())+'/import/default.textfmt.xml')
   _textformatmanager.importXml(obj,xml=xml)
   xml.close()
   
@@ -313,44 +342,32 @@ def initZMS(self, titleshort, title, lang, manage_lang, REQUEST):
   
   ### Init Properties: active, titlealt, title.
   obj.setObjStateNew(REQUEST)
-  obj.updateVersion(lang,manage_lang,REQUEST)
+  obj.updateVersion(lang,REQUEST)
   obj.setObjProperty('active',1,lang)
   obj.setObjProperty('titleshort',titleshort,lang)
   obj.setObjProperty('title',title,lang)
   obj.onChangeObj(REQUEST,forced=1)
   
-  ### Init CSS Stylesheets.
-  root = self.common
-  id = 'defaultCSS'
-  css = getattr( root, id)
-  root.manage_delObjects(ids=[id])
-  obj.getStylesheet( css.raw)
-  for id in root.objectIds(['DTML Method']):
-    if id.find( 'defaultCSS_') == 0 or id[-3:] == 'CSS':
-      cb_copy_data = root.manage_cutObjects(ids=[id])
-      obj.manage_pasteObjects(cb_copy_data)
-      obj.manage_renameObject(id=id,new_id=id[:-3]+'.css')
-
   ### Return new ZMS instance.
   return obj
 
 
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  initContent:
-# ---------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def initContent(self, filename, REQUEST):
   xmlfile = open(_fileutil.getOSPath(package_home(globals())+'/import/'+filename),'rb')
   _importable.importFile( self, xmlfile, REQUEST, _importable.importContent)
   xmlfile.close()
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   constructor ZMS:
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 manage_addZMSForm = HTMLFile('manage_addzmsform', globals()) 
 def manage_addZMS(self, lang, manage_lang, REQUEST, RESPONSE):
   """ manage_addZMS """
@@ -363,9 +380,8 @@ def manage_addZMS(self, lang, manage_lang, REQUEST, RESPONSE):
     homeElmnt = initTheme(self,REQUEST['theme'],REQUEST['folder_id'],REQUEST)
       
     #-- Zope Manager.
-    if not homeElmnt.objectValues(['User Folder']):
-      userFldr = UserFolder()
-      homeElmnt._setObject(userFldr.id, userFldr)
+    userFldr = UserFolder()
+    homeElmnt._setObject(userFldr.id, userFldr)
     name = REQUEST.get('manager_name','')
     password = REQUEST.get('manager_password','')
     confirm = password
@@ -397,21 +413,6 @@ def manage_addZMS(self, lang, manage_lang, REQUEST, RESPONSE):
       # Register Portal/Client.
       lcms.setConfProperty('Portal.Master',homeElmnt.id)
       obj.setConfProperty('Portal.Clients',[lcmsHomeElmnt.id])
-      # Add manage_login.
-      id = 'manage_login'
-      title = 'Template_L0: Member login'
-      raw = HTMLFile('import/lms.manage_login',globals())
-      obj.manage_addDTMLMethod(id,title,raw)
-      mthd = getattr(obj,id)
-      mthd.manage_role(role_to_manage='Authenticated',permissions=['View'])
-      mthd.manage_acquiredPermissions([])
-      # Add manage_register.
-      id = 'manage_register'
-      title = 'Template_L0: Member registration'
-      raw = HTMLFile('import/lms.manage_register',globals())
-      homeElmnt.manage_addDTMLMethod(id,title,raw)
-      mthd = getattr(homeElmnt,id)
-      mthd.manage_proxy(roles=['Manager'])
       # Init content.
       initContent(lcms,'lcms.default.xml',REQUEST)
       initContent(obj,'lms.default.zip',REQUEST)
@@ -454,28 +455,27 @@ def manage_addZMS(self, lang, manage_lang, REQUEST, RESPONSE):
     RESPONSE.redirect('%s/manage_main'%self.absolute_url())
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   class ZMS:
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class ZMS(
-	zmscontainerobject.ZMSContainerObject,
-	_accessmanager.AccessManager,
-	_builder.Builder,
-	_cachemanager.CacheManager,
+        zmscontainerobject.ZMSContainerObject,
+        _accessmanager.AccessManager,
+        _builder.Builder,
         _confmanager.ConfManager,
-	_ftpmanager.FtpManager,
-	_language.Language,
-	_objattrs.ObjAttrsManager,
-	_zcatalogmanager.ZCatalogManager,
-	):
+        _ftpmanager.FtpManager,
+        _language.Language,
+        _objattrs.ObjAttrsManager,
+        _zcatalogmanager.ZCatalogManager,
+        ):
 
     # Version-Info.
     # -------------
-    zms_build = '128'		# Internal use only, designates object model!
+    zms_build = '129'		# Internal use only, designates object model!
     zms_patch = 'd'		# Internal use only!
 
     # Properties.
@@ -553,8 +553,8 @@ class ZMS(
         'active':{'datatype':'boolean','multilang':1},
         'attr_active_start':{'datatype':'datetime','multilang':1},
         'attr_active_end':{'datatype':'datetime','multilang':1},
-        'title':{'datatype':'string','multilang':1,'size':40},
-        'titleshort':{'datatype':'string','multilang':1,'size':20},
+        'title':{'datatype':'string','multilang':1,'size':40, 'mandatory': True},
+        'titleshort':{'datatype':'string','multilang':1,'size':20, 'mandatory': True},
         'titleimage':{'datatype':'image','multilang':1},
         'levelnfc':{'datatype':'string','type':'select','options':[0,0,1,1,2,2],'label':'ATTR_LEVELNFC'},
         'attr_cacheable':{'datatype':'boolean','default':True},
@@ -592,8 +592,6 @@ class ZMS(
 	'ZMSNote':{		'obj_class':ZMSNote,
 				'constructor':'manage_addZMSNote',
 				'obj_attrs':ZMSNote.__obj_attrs__ },
-	'ZMSRubrik':{ 		'obj_class':ZMSRubrik,
-				'obj_attrs':ZMSRubrik.__obj_attrs__ },
 	'ZMSSqlDb':{ 		'obj_class':ZMSSqlDb,
 				'constructor':'manage_addzmssqldbform',
 				'obj_attrs':ZMSSqlDb.__obj_attrs__ },
@@ -620,12 +618,14 @@ class ZMS(
     # Interface.
     # ----------
     index_html = HTMLFile('dtml/zms/index', globals()) # index_html
+    not_found_html = HTMLFile('dtml/zms/not_found', globals()) # index_html
     f_inactive_html = HTMLFile('dtml/zms/f_inactive', globals()) # inactive_html
     f_headDoctype = HTMLFile('dtml/zms/f_headdoctype', globals()) # Template_L1: DOCTYPE
     f_bodyContent = HTMLFile('dtml/zms/f_bodycontent', globals()) # Template: Body-Content / Element
     f_bodyContent_Float = HTMLFile('dtml/zms/f_bodycontent_float', globals()) # Template: Body-Content
     f_bodyContent_Sitemap = HTMLFile('dtml/zms/f_bodycontent_sitemap', globals()) # Template: Sitemap
     f_bodyContent_Search = HTMLFile('dtml/zms/f_bodycontent_search', globals()) # Template: Search
+    f_bodyContent_NotFound = HTMLFile('dtml/zms/f_bodycontent_notfound', globals()) # Template: Not Found
     f_headTitle = HTMLFile('dtml/zms/f_headtitle', globals()) # Head.Title
     f_headMeta_DC = HTMLFile('dtml/zms/f_headmeta_dc', globals()) # Head.Meta.DC
     f_headMeta_Locale = HTMLFile('dtml/zms/f_headmeta_locale', globals()) # Head.Locale (Content-Type & Charset)
@@ -648,48 +648,48 @@ class ZMS(
     enumManager = _enummanager.EnumManager()
 
 
-    ###############################################################################################    
+    ############################################################################    
     #
     #   CONSTRUCTOR
     #
-    ###############################################################################################    
+    ############################################################################    
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.__init__: 
-    # ------------------------------------------------------------------------------------------
-    def __init__(self, id):
+    # --------------------------------------------------------------------------
+    def __init__(self):
       """
       Constructor.
       """
-      self.id = id
+      self.id = 'content'
       file = open(_fileutil.getOSPath(package_home(globals())+'/www/spacer.gif'),'rb')
       self.logo = Image(id='logo', title='', file=file.read())
       file.close()
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.zms_version:
     #
     #  Get version.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def zms_version(self):
       file = open(_fileutil.getOSPath(package_home(globals())+'/version.txt'),'r')
       rtn = file.read()
       file.close()
       return rtn
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.getDocumentElement
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getDocumentElement(self):
       """
       The root element of the site.
       """
       return self
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.getHome
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getHome(self):
       """
       Returns the home-folder of the site.
@@ -703,18 +703,18 @@ class ZMS(
         ob = getattr( docElmnt, docElmnt.absolute_url().split( '/')[-2])
       return ob
     
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.getNewId
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getNewId(self, id_prefix='e'):
       """
       Returns new (unique) Object-ID.
       """
       return '%s%i'%(id_prefix,self.getSequence().nextVal())
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.getMetaTypes:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetaTypes(self, REQUEST, excl_meta_types=['ZMS','ZMSCustom','ZMSTrashcan']): 
       """
       Returns list of meta-types.
@@ -725,18 +725,18 @@ class ZMS(
       meta_types.sort()
       return meta_types
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.getDCCoverage
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getDCCoverage(self, REQUEST={}):
       """
       Returns Dublin-Core Meta-Attribute Coverage.
       """
       return 'global.'+self.getPrimaryLanguage()
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.sendMail
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def sendMail(self, mto, msubject, mbody, REQUEST):
       """
       Sends Mail via MailHost.
@@ -779,62 +779,58 @@ class ZMS(
         return -1
 
 
-    ###############################################################################################    
+    ############################################################################    
     #
     #   ZMS - Portals
     #
-    ###############################################################################################    
+    ############################################################################    
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.getPortalMaster
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getPortalMaster(self):
       """
       Returns portal-master, none if it does not exist.
       """
-      masterDocElmnt = None
       v = self.getConfProperty('Portal.Master','')
       if len(v) > 0:
         try:
-          masterHome = getattr( self, v, None)
-          masterDocElmnt = masterHome.objectValues(['ZMS'])[0]
+          return getattr( self, v).content
         except:
           _globals.writeException(self, '[getPortalMaster]: %s not found!'%str(v))
-      return masterDocElmnt
+      return None
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.getPortalClients
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getPortalClients(self):
       """
       Returns portal-clients, empty list if none exist.
       """
-      clientDocElmnts = []
+      docElmnts = []
       v = self.getConfProperty('Portal.Clients',[])
       if len(v) > 0:
         thisHome = self.getHome()
         for id in v:
           try:
-            clientHome = getattr(thisHome,id,None)
-            clientDocElmnt = clientHome.objectValues(['ZMS'])[0]
-            clientDocElmnts.append(clientDocElmnt)
+            docElmnts.append(getattr(thisHome,id).content)
           except:
             _globals.writeException(self, '[getPortalClients]: %s not found!'%str(id))
-      return clientDocElmnts
+      return docElmnts
 
 
-    ###############################################################################################    
+    ############################################################################    
     #
     #   ZMS - Versions
     #
-    ###############################################################################################    
+    ############################################################################    
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.updateVersion:
     #
     #  Update version.
-    # ---------------------------------------------------------------------------------------------
-    def updateVersion(self, lang, manage_lang, REQUEST, maintenance=True):
+    # --------------------------------------------------------------------------
+    def updateVersion(self, lang, REQUEST, maintenance=True):
       message = ''
       build = getattr( self, 'build', '000')
       patch = getattr( self, 'patch', '000')
@@ -851,20 +847,20 @@ class ZMS(
       
       # Process clients.
       for portalClient in self.getPortalClients():
-        message += portalClient.updateVersion( lang, manage_lang, REQUEST, False)
+        message += portalClient.updateVersion( lang, REQUEST, False)
       
       return message
 
 
-    ###############################################################################################
+    ############################################################################
     ###  
     ###  DOM-Methoden 
     ### 
-    ###############################################################################################
+    ############################################################################
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMS.getParentNode
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getParentNode(self): 
       """
       The parent of this node. 
@@ -873,15 +869,15 @@ class ZMS(
       return None
 
 
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   XML-Builder
     ###
-    ###############################################################################################    
+    ############################################################################    
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # ZMS.xmlOnStartElement
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def xmlOnStartElement(self, sTagName, dTagAttrs, oParentNode, oRoot):
       """
       Handler for XML-Builder (_builder.py)
@@ -898,9 +894,10 @@ class ZMS(
       self.dTagStack = _globals.MyStack()
       self.dValueStack  = _globals.MyStack()
       
-      # WORKAROUND! The member variable "aq_parent" does not contain the right parent object at 
-      # this stage of the creation process (it will later on!). Therefore, we introduce a special
-      # attribute containing the parent object, which will be used by xmlGetParent() (see below).
+      # WORKAROUND! The member variable "aq_parent" does not contain the right 
+      # parent object at this stage of the creation process (it will later on!). 
+      # Therefore, we introduce a special attribute containing the parent 
+      # object, which will be used by xmlGetParent() (see below).
       self.oParent = None
 
-###################################################################################################
+################################################################################
