@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # zmscustom.py
 #
 # $Id: zmscustom.py,v 1.9 2004/11/30 20:04:16 zmsdev Exp $
@@ -21,12 +21,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
 from Globals import HTMLFile
 from types import StringTypes
+import ZPublisher.HTTPRequest
 import sys
 import time
 import urllib
@@ -34,15 +35,16 @@ import urllib
 from zmscontainerobject import ZMSContainerObject
 from zmsobject import ZMSObject
 import zmsteaserelement
+import _blobfields
 import _fileutil
 import _globals
 import _importable
 import _metaobjmanager
 
 
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  zmscustom.parseXmlString
-# -------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def parseXmlString(self, file):
   _globals.writeBlock( self, '[parseXmlString]')
   message = ''
@@ -59,19 +61,19 @@ def parseXmlString(self, file):
   return message
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C o n s t r u c t o r ( s )
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 manage_addZMSCustomForm = HTMLFile('manage_addzmscustomform', globals()) 
-def manage_addZMSCustom(self, meta_id, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
+def manage_addZMSCustom(self, meta_id, lang, _sort_id, REQUEST, RESPONSE):
   """ manage_addZMSCustom """
   
-  if REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
+  if REQUEST['btn'] == self.getZMILangStr('BTN_INSERT'):
     
     ##### Create ####
     id_prefix = _globals.id_prefix(REQUEST.get('id','e'))
@@ -85,7 +87,7 @@ def manage_addZMSCustom(self, meta_id, lang, manage_lang, _sort_id, REQUEST, RES
       redirect_self = redirect_self or attr_type in self.dGlobalAttrs.keys()
       redirect_self = redirect_self or attr_type in self.getMetaobjIds()
       redirect_self = redirect_self or attr_type in ['*']
-    redirect_self = redirect_self and not REQUEST.get('btn','') in  [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]
+    redirect_self = redirect_self and not REQUEST.get('btn','') in  [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]
   
     obj = getattr(self,obj.id)
     ##### Object State ####
@@ -97,29 +99,29 @@ def manage_addZMSCustom(self, meta_id, lang, manage_lang, _sort_id, REQUEST, RES
     else:
       obj.setObjProperty('attr_dc_coverage','global.'+lang)
     ##### Init Properties ####
-    obj.manage_changeProperties(lang,manage_lang,REQUEST,RESPONSE)
+    obj.manage_changeProperties(lang,REQUEST,RESPONSE)
   
     ##### Normalize Sort-IDs ####
     self.normalizeSortIds(id_prefix)
   
     # Return with message.        
-    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
+    message = self.getZMILangStr('MSG_INSERTED')%obj.display_type(REQUEST)
     if redirect_self:
-      RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,manage_lang,urllib.quote(message)))
+      RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,urllib.quote(message)))
     else:
-      RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.absolute_url(),lang,manage_lang,urllib.quote(message),obj.id))
+      RESPONSE.redirect('%s/manage_main?lang=%s&manage_tabs_message=%s#_%s'%(self.absolute_url(),lang,urllib.quote(message),obj.id))
 
   else:
-    RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s'%(self.absolute_url(),lang,manage_lang))
+    RESPONSE.redirect('%s/manage_main?lang=%s'%(self.absolute_url(),lang))
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C l a s s
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 class ZMSCustom(ZMSContainerObject): 
         
@@ -143,8 +145,8 @@ class ZMSCustom(ZMSContainerObject):
     # -----------------------
     __authorPermissions__ = (
 		'manage','manage_main','manage_workspace',
-                'manage_addZMSFolder','manage_addZMSDocument','manage_addZMSTextarea','manage_addZMSGraphic','manage_addZMSTable','manage_addZMSFile','manage_addZMSTeaserContainer','manage_addZMSNote','manage_addZMSLinkContainer','manage_addZMSLinkElement','manage_addZMSSqlDb',
-		'manage_properties','manage_changeProperties',
+		'manage_addZMSFolder','manage_addZMSDocument','manage_addZMSTextarea','manage_addZMSGraphic','manage_addZMSTable','manage_addZMSFile','manage_addZMSTeaserContainer','manage_addZMSNote','manage_addZMSLinkContainer','manage_addZMSLinkElement','manage_addZMSSqlDb',
+		'manage_changeProperties',
 		'manage_deleteObjs','manage_undoObjs','manage_moveObjUp','manage_moveObjDown','manage_cutObjects','manage_copyObjects','manage_pasteObjs',
 		'manage_wfTransition', 'manage_wfTransitionFinalize',
 		'manage_userForm', 'manage_user',
@@ -185,40 +187,48 @@ class ZMSCustom(ZMSContainerObject):
     # Management Interface.
     # ---------------------
     manage_main = HTMLFile('dtml/metaobj/manage_main', globals())
+    manage_form = HTMLFile('dtml/metaobj/manage_form', globals())
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     #
     #   CONSTRUCTOR
     #
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    ###############################################################################################
+    ############################################################################
     # ZMSCustom.__init__: 
     #
     # Constructor (initialise a new instance of ZMSCustom).
-    ###############################################################################################
+    ############################################################################
     def __init__(self, id='', sort_id='', meta_id=''): 
       """ ZMSCustom.__init__ """
       ZMSObject.__init__(self,id,sort_id)
       self.meta_id = meta_id
 
 
+    # --------------------------------------------------------------------------
+    #  ZMSCustom.meta_id_or_type:
+    # --------------------------------------------------------------------------
+    def meta_id_or_type(self):
+      return self.meta_id
+
+
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   H t t p
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.GET: 
     #
     #  Handle HTTP GET requests.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def GET(self, REQUEST, RESPONSE):
       """Handle HTTP GET requests."""
       metaObjAttrs = self.getMetaobj(self.meta_id)['attrs']
@@ -235,11 +245,11 @@ class ZMSCustom(ZMSContainerObject):
       return ''
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.PUT: 
     #
     #  Handle HTTP PUT requests.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def PUT(self, REQUEST, RESPONSE):
       """Handle HTTP PUT requests."""
       metaObjAttrs = self.getMetaobj(self.meta_id)['attrs']
@@ -260,23 +270,24 @@ class ZMSCustom(ZMSContainerObject):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   P r o p e r t i e s
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSCustom.manage_changeProperties: 
     #
     #  Change Custom properties.
-    ###############################################################################################
-    def manage_changeProperties(self, lang, manage_lang, REQUEST, RESPONSE):
+    ############################################################################
+    def manage_changeProperties(self, lang, REQUEST, RESPONSE):
       """ ZMSCustom.manage_changeProperties """
       
       self._checkWebDAVLock()
       message = ''
+      messagekey = 'manage_tabs_message'
       t0 = time.time()
       
       redirect_self = False
@@ -286,53 +297,117 @@ class ZMSCustom(ZMSContainerObject):
         redirect_self = redirect_self or attr_type in self.dGlobalAttrs.keys()
         redirect_self = redirect_self or attr_type in self.getMetaobjIds()
         redirect_self = redirect_self or attr_type in ['*']
-      redirect_self = redirect_self and not REQUEST.get('btn','') in  [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]
+      redirect_self = redirect_self and not REQUEST.get('btn','') in  [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]
+      target_ob = self.getParentNode()
+      if redirect_self:
+        target_ob = self
+      target = REQUEST.get( 'target', '%s/manage_main'%target_ob.absolute_url())
       
-      if REQUEST.get('btn','') not in [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]:
+      if REQUEST.get('btn','') not in [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]:
+        try:
+          
+          ##### Object State #####
+          self.setObjStateModified(REQUEST)
+          
+          ##### Resources #####
+          if 'resources' in self.getMetaobjAttrIds( self.meta_id):
+            resources = self.getObjProperty( 'resources', REQUEST)
+            l = map( lambda x: 0, range( len( resources)))
+            for key in self.getObjAttrs().keys():
+              obj_attr = self.getObjAttr( key)
+              el_name = self.getObjAttrName( obj_attr, lang)
+              if REQUEST.has_key( el_name) and REQUEST.has_key( 'resource_%s'%el_name):
+                el_value = REQUEST.get( el_name)
+                if el_value is not None:
+                  for i in range( len( resources)):
+                    v = resources[ i]
+                    if el_value.find( '/'+v.getFilename()) > 0:
+                      l[ i] = l[ i] + 1
+            c = 0 
+            for i in range( len( resources)):
+              v = resources[ c]
+              if l[ i] == 0:
+                del resources[ c]
+              else:
+                src_old = '%s/@%i/%s'%(self.id,i,v.getFilename())
+                src_new = '%s/@%i/%s'%(self.id,c,v.getFilename())
+                for key in self.getObjAttrs().keys():
+                  obj_attr = self.getObjAttr( key)
+                  el_name = self.getObjAttrName( obj_attr, lang)
+                  if REQUEST.has_key( el_name) and REQUEST.has_key( 'resource_%s'%el_name):
+                    el_value = REQUEST.get( el_name)
+                    if el_value is not None:
+                      el_value = el_value.replace( src_old, src_new)
+                      REQUEST.set( el_name, el_value)
+                c = c + 1
+            for key in self.getObjAttrs().keys():
+              obj_attr = self.getObjAttr( key)
+              el_name = self.getObjAttrName( obj_attr, lang)
+              if REQUEST.has_key( el_name) and REQUEST.has_key( 'resource_%s'%el_name):
+                v = REQUEST.get( 'resource_%s'%el_name)
+                if isinstance(v,ZPublisher.HTTPRequest.FileUpload):
+                  if len(getattr(v,'filename',''))>0:
+                    v = _blobfields.createBlobField(self,_globals.DT_FILE,v)
+                    resources.append( v)
+                    el_value = REQUEST.get( el_name)
+                    if el_value is not None:
+                      src_new = '%s/@%i/%s'%(self.absolute_url(),len(resources)-1,v.getFilename())
+                      if v.getContentType().find( 'image/') == 0:
+                        el_value = el_value + '<img src="%s" alt="" border="0" align="absmiddle"/>'%src_new
+                      else:
+                        el_value = el_value + '<a href="%s" target="_blank">%s</a>'%(src_new,v.getFilename())
+                      REQUEST.set( el_name, el_value)
+                      redirect_self = True
+            self.setObjProperty( 'resources', resources, lang)
+          
+          ##### Properties #####
+          for key in self.getObjAttrs().keys():
+            if key != 'resources':
+              self.setReqProperty(key,REQUEST)
+          
+          ##### Resource-Objects #####
+          for objAttr in self.getMetaobj(self.meta_id)['attrs']:
+            if objAttr['type'] in self.getMetaobjIds(sort=0) and \
+               self.getMetaobj(objAttr['type'])['type']=='ZMSResource':
+              for ob in self.getObjChildren(objAttr['id'],REQUEST):
+                ob.setObjStateModified(REQUEST)
+                for key in ob.getObjAttrs().keys():
+                  ob.setReqProperty(key,REQUEST)
+                ob.onChangeObj(REQUEST)
+          
+          ##### VersionManager ####
+          self.onChangeObj(REQUEST)
+          
+          ##### Message ####
+          message = self.getZMILangStr('MSG_CHANGED')
         
-        ##### Object State #####
-        self.setObjStateModified(REQUEST)
+        except:
+          tp, vl, tb = sys.exc_info()
+          message = '<b>Error-Type:</b> '+str(tp)+'<br/><b>Error-Value:</b> '+str(vl)+'<br/>'
+          messagekey = 'manage_tabs_error_message'
+          _globals.writeException(self,"[manage_changeProperties]")
         
-        ##### Properties #####
-        for key in self.getObjAttrs().keys():
-          self.setReqProperty(key,REQUEST)
-        
-        ##### Resource-Objects #####
-        for objAttr in self.getMetaobj(self.meta_id)['attrs']:
-          if objAttr['type'] in self.getMetaobjIds(sort=0) and \
-             self.getMetaobj(objAttr['type'])['type']=='ZMSResource':
-            for ob in self.getObjChildren(objAttr['id'],REQUEST):
-              ob.setObjStateModified(REQUEST)
-              for key in ob.getObjAttrs().keys():
-                ob.setReqProperty(key,REQUEST)
-              ob.onChangeObj(REQUEST)
-        
-        ##### VersionManager ####
-        self.onChangeObj(REQUEST)
-        
-        ##### Message #####
-        message = self.getLangStr('MSG_CHANGED',manage_lang) + ' (in '+str(int((time.time()-t0)*100.0)/100.0)+' secs.)'
+        message = message + ' (in '+str(int((time.time()-t0)*100.0)/100.0)+' secs.)'
       
       # Return with message.
-      if redirect_self:
-        return RESPONSE.redirect('manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(lang,manage_lang,urllib.quote(message)))
-      else:
-        self.checkIn(REQUEST)
-        return RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.getParentNode().absolute_url(),lang,manage_lang,urllib.quote(message),self.id))
+      self.checkIn(REQUEST)
+      target = self.url_append_params( target, { 'lang': lang, 'preview': 'preview',  messagekey: message})
+      target = '%s#_%s'%( target, self.id)
+      return RESPONSE.redirect( target)
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.getMetaobjZMI:
     # 
     #  Returns Meta-Object Management Interface identified by ID.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getMetaobjZMI(self, id, REQUEST):
       return _metaobjmanager.getMetaobjZMI(self,id,REQUEST)
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.setMetaType:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def setMetaType(self, new_meta_id):
       meta_id = self.meta_id
       metaObjAttrIds = self.getMetaobjAttrIds(meta_id)
@@ -364,9 +439,9 @@ class ZMSCustom(ZMSContainerObject):
       self.meta_id = new_meta_id
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.isMetaType:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isMetaType(self, meta_type, REQUEST={}):
       if meta_type is None:
         return 1
@@ -378,33 +453,33 @@ class ZMSCustom(ZMSContainerObject):
       return b
     
     
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.isPage:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isPage(self): 
       return self.getType() in [ 'ZMSDocument', 'ZMSReference']
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSObject.isPageElement:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isPageElement(self): 
       return self.getType() in [ 'ZMSObject', 'ZMSRecordSet']
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.getType
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getType(self): 
       return self.getMetaobj(self.meta_id)['type']
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.getDtmlTemplate
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getDtmlTemplate(self): 
       return getattr(self,self.getMetaobj(self.meta_id)['tmplt'],None)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.getPenetrance
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getPenetrance(self, REQUEST):
       penetrance = 0
       if 'attr_penetrance' in self.getObjAttrs().keys():
@@ -414,9 +489,9 @@ class ZMSCustom(ZMSContainerObject):
           penetrance = lst[lst.index(i)-1]
       return penetrance
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSCustom.getTitlealt
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitlealt(self,REQUEST):
       s = ''
       if self.getType() in ['ZMSRecordSet']:
@@ -441,9 +516,9 @@ class ZMSCustom(ZMSContainerObject):
       s = self.getLevelnfc(REQUEST) + s
       return s
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSCustom.getTitle
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitle(self,REQUEST): 
       s = ''
       if self.getType() in ['ZMSRecordSet']:
@@ -470,18 +545,18 @@ class ZMSCustom(ZMSContainerObject):
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###  H T M L - P r e s e n t a t i o n 
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom._getBodyContent:
     #
     #  HTML presentation of Special Document. 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _getBodyContent(self, REQUEST):
       l = []
       v = ''
@@ -504,11 +579,11 @@ class ZMSCustom(ZMSContainerObject):
         l.append(v)
       return ''.join(l)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.renderShort:
     #
     #  Renders short presentation of Special Document.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def renderShort(self, REQUEST):
       html = ''
       try:
@@ -527,11 +602,11 @@ class ZMSCustom(ZMSContainerObject):
       return html
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.printHtml:
     #
     #  Renders print presentation of Special Document.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def printHtml(self, level, sectionizer, REQUEST, deep=True):
       html = ''
     
@@ -565,24 +640,23 @@ class ZMSCustom(ZMSContainerObject):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   R e c o r d S e t
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.recordSet_Init:
     #
     #  Initializes RecordSet.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def recordSet_Init(self, REQUEST):
       metaObj = self.getMetaobj(self.meta_id)
 
       res_id = metaObj['attrs'][0]['id']
-      res_abs = self.getObjProperty(res_id,REQUEST)
-      res = self.copy_list(res_abs)
+      res = self.getObjProperty(res_id,REQUEST)
       
       REQUEST.set('res_id',res_id)
       REQUEST.set('res_abs',res)
@@ -591,11 +665,11 @@ class ZMSCustom(ZMSContainerObject):
       return res
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.recordSet_Filter:
     #
     #  Filters RecordSet.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def recordSet_Filter(self, REQUEST):
       metaObj = self.getMetaobj(self.meta_id)
       
@@ -612,7 +686,7 @@ class ZMSCustom(ZMSContainerObject):
       sessionvalue='%s_%s'%(filtervalue,self.id)
       SESSION.set(sessionattr,REQUEST.form.get(filterattr,SESSION.get(sessionattr,'')))
       SESSION.set(sessionvalue,REQUEST.form.get(filtervalue,SESSION.get(sessionvalue,'')))
-      if REQUEST.get('btn','')==self.getLangStr('BTN_RESET',REQUEST['manage_lang']):
+      if REQUEST.get('btn','')==self.getZMILangStr('BTN_RESET'):
         SESSION.set(sessionattr,'')
         SESSION.set(sessionvalue,'')
       if SESSION.get(sessionattr,'') != '' and \
@@ -637,10 +711,10 @@ class ZMSCustom(ZMSContainerObject):
         
         #-- Set filter parameters in Session
         if REQUEST.get('action','')=='':
-          if REQUEST.get('btn','')==self.getLangStr('BTN_RESET',REQUEST['manage_lang']):
+          if REQUEST.get('btn','')==self.getZMILangStr('BTN_RESET'):
             SESSION.set(sessionattr,'')
             SESSION.set(sessionvalue,'')
-          elif REQUEST.get('btn','')==self.getLangStr('BTN_REFRESH',REQUEST['manage_lang']):
+          elif REQUEST.get('btn','')==self.getZMILangStr('BTN_REFRESH'):
             SESSION.set(sessionattr,REQUEST.form.get(filterattr,''))
             SESSION.set(sessionvalue,REQUEST.form.get(filtervalue,''))
         
@@ -662,11 +736,11 @@ class ZMSCustom(ZMSContainerObject):
       return res
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.recordSet_Sort:
     #
     #  Sorts RecordSet.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def recordSet_Sort(self, REQUEST):
       metaObj = self.getMetaobj(self.meta_id)
       
@@ -693,12 +767,12 @@ class ZMSCustom(ZMSContainerObject):
       return res
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSCustom.recordSet_Export:
     #
     #  Export RecordSet to XML.
-    # ---------------------------------------------------------------------------------------------
-    def recordSet_Export(self, lang, manage_lang, qorder, qorderdir, qindex=[], REQUEST=None, RESPONSE=None):
+    # --------------------------------------------------------------------------
+    def recordSet_Export(self, lang, qorder, qorderdir, qindex=[], REQUEST=None, RESPONSE=None):
       """ ZMSCustom.recordSet_Export """
       self.recordSet_Init(REQUEST)
       self.recordSet_Filter(REQUEST)
@@ -714,12 +788,12 @@ class ZMSCustom(ZMSContainerObject):
       return export
 
 
-    ###############################################################################################    
+    ############################################################################    
     #  ZMSCustom.manage_import:
     #
     #  Import XML-file.
-    ###############################################################################################    
-    def manage_import(self, file, lang, manage_lang, REQUEST, RESPONSE):
+    ############################################################################    
+    def manage_import(self, file, lang, REQUEST, RESPONSE):
       """ ZMSCustom.manage_import """
       message = ''
       
@@ -731,6 +805,6 @@ class ZMSCustom(ZMSContainerObject):
       
       # Return with message.
       message = urllib.quote(message)
-      return REQUEST.RESPONSE.redirect('manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(lang,manage_lang,message))
+      return REQUEST.RESPONSE.redirect('manage_main?lang=%s&manage_tabs_message=%s'%(lang,message))
 
-###################################################################################################
+################################################################################
