@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # zmsdocument.py
 #
 # $Id: zmsdocument.py,v 1.5 2004/11/23 23:04:45 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from Globals import HTMLFile
@@ -32,19 +32,19 @@ from zmscontainerobject import ZMSContainerObject
 import _globals
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C o n s t r u c t o r ( s )
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 manage_addZMSDocumentForm = HTMLFile('manage_addzmsdocumentform', globals()) 
-def manage_addZMSDocument(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
+def manage_addZMSDocument(self, lang, _sort_id, REQUEST, RESPONSE):
   """ manage_addZMSDocument """
     
-  if REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
+  if REQUEST['btn'] == self.getZMILangStr('BTN_INSERT'):
     
     ##### Create ####
     id_prefix = _globals.id_prefix(REQUEST.get('id','e'))
@@ -55,28 +55,28 @@ def manage_addZMSDocument(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
     ##### Object State ####
     obj.setObjStateNew(REQUEST)
     ##### Init Properties ####
-    obj.manage_changeProperties(lang,manage_lang,REQUEST)
+    obj.manage_changeProperties(lang,REQUEST)
                 
     ##### Normalize Sort-IDs ####
     self.normalizeSortIds(id_prefix)
         
     # Return with message.
-    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
+    message = self.getZMILangStr('MSG_INSERTED')%obj.display_type(REQUEST)
     target = REQUEST.get( 'target', '%s/%s/manage_main'%( self.absolute_url(), obj.id))
-    RESPONSE.redirect('%s?preview=preview&lang=%s&manage_lang=%s&manage_tabs_message=%s'%(target,lang,manage_lang,urllib.quote(message)))
+    RESPONSE.redirect('%s?preview=preview&lang=%s&manage_tabs_message=%s'%(target,lang,urllib.quote(message)))
           
   else:         
     target = REQUEST.get( 'target', '%s/manage_main'%self.absolute_url())
-    RESPONSE.redirect('%s?preview=preview&lang=%s&manage_lang=%s'%(target,lang,manage_lang))
+    RESPONSE.redirect('%s?preview=preview&lang=%s'%(target,lang))
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   C l a s s
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class ZMSDocument(ZMSContainerObject):
 
     # Properties.
@@ -136,8 +136,8 @@ class ZMSDocument(ZMSContainerObject):
         'active':{'datatype':'boolean','multilang':True},
         'attr_active_start':{'datatype':'datetime','multilang':True},
         'attr_active_end':{'datatype':'datetime','multilang':True},
-        'title':{'datatype':'string','multilang':True,'size':40},
-        'titleshort':{'datatype':'string','multilang':True,'size':20},
+        'title':{'datatype':'string','multilang':True,'size':40, 'mandatory': True},
+        'titleshort':{'datatype':'string','multilang':True,'size':20, 'mandatory': True},
         'titleimage':{'datatype':'image','multilang':True},
         'levelnfc':{'datatype':'string','type':'select','options':[0,0,1,1,2,2],'label':'ATTR_LEVELNFC'},
         'attr_cacheable':{'datatype':'boolean','default':True},
@@ -147,4 +147,4 @@ class ZMSDocument(ZMSContainerObject):
         '$metadict':{'datatype':'MetaDict'},
     }
 
-###################################################################################################
+################################################################################
