@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # zmsfile.py
 #
 # $Id: zmsfile.py,v 1.4 2004/11/23 23:04:45 zmsdev Exp $
@@ -21,11 +21,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from Globals import HTMLFile, Persistent
-from sys import *
+import sys
 import time
 import urllib
 # Product imports.
@@ -35,19 +35,19 @@ import _fileutil
 import _globals
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C o n s t r u c t o r ( s )
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 manage_addZMSFileForm = HTMLFile('manage_addzmsfileform', globals()) 
-def manage_addZMSFile(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
+def manage_addZMSFile(self, lang, _sort_id, REQUEST, RESPONSE):
   """ manage_addZMSFile """
     
-  if REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
+  if REQUEST['btn'] == self.getZMILangStr('BTN_INSERT'):
     
     ##### Create ####
     id_prefix = _globals.id_prefix(REQUEST.get('id','e'))
@@ -64,27 +64,27 @@ def manage_addZMSFile(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
     else:
       obj.setObjProperty('attr_dc_coverage','global.'+lang)
     ##### Init Properties ####
-    obj.manage_changeProperties(lang,manage_lang,REQUEST,RESPONSE)
+    obj.manage_changeProperties(lang,REQUEST,RESPONSE)
 
     ##### Normalize Sort-IDs ####
     self.normalizeSortIds(id_prefix)
     
     # Return with message.
-    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
-    RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.absolute_url(),lang,manage_lang,urllib.quote(message),obj.id))
+    message = self.getZMILangStr('MSG_INSERTED')%obj.display_type(REQUEST)
+    RESPONSE.redirect('%s/manage_main?lang=%s&manage_tabs_message=%s#_%s'%(self.absolute_url(),lang,urllib.quote(message),obj.id))
                 
   else:         
-    RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s'%(self.absolute_url(),lang,manage_lang))
+    RESPONSE.redirect('%s/manage_main?lang=%s'%(self.absolute_url(),lang))
 
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C l a s s
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class ZMSFile(ZMSObject, Metadata): 
         
     # Properties.
@@ -147,18 +147,18 @@ class ZMSFile(ZMSObject, Metadata):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     #
     #   CONSTRUCTOR
     #
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSFile.getLinkList: 
     #
     #  Returns ZMSFile as link-URL.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLinkList(self,REQUEST, allow_none=0):
       rtn = []
       append = True
@@ -180,109 +180,118 @@ class ZMSFile(ZMSObject, Metadata):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   P r o p e r t i e s
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSFile.manage_changeProperties:
     #
     #  Change file properties.
-    ###############################################################################################
-    def manage_changeProperties(self, lang, manage_lang, REQUEST, RESPONSE):
+    ############################################################################
+    def manage_changeProperties(self, lang, REQUEST, RESPONSE):
       """ ZMSFile.manage_changeProperties """
       
       self._checkWebDAVLock()
       message = ''
+      messagekey = 'manage_tabs_message'
       t0 = time.time()
       
       redirect_self = False
       redirect_self = redirect_self or REQUEST.get('btn','') == '' 
-      redirect_self = redirect_self and not REQUEST.get('btn','') in  [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]
+      redirect_self = redirect_self and not REQUEST.get('btn','') in  [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]
       
-      if REQUEST.get('btn','') not in  [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]:
+      if REQUEST.get('btn','') not in  [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]:
+        try:
+        
+          ##### Object State ####
+          self.setObjStateModified(REQUEST)
+          
+          ##### Properties ####
+          # Metadata.
+          self.setMetadata(lang,REQUEST)
+          # Active.
+          self.setReqProperty('active',REQUEST)
+          self.setReqProperty('attr_active_start',REQUEST)
+          self.setReqProperty('attr_active_end',REQUEST)
+          # Title.
+          self.setReqProperty('title',REQUEST)
+          self.setReqProperty('titleshort',REQUEST)
+          # File.
+          self.setReqProperty('file',REQUEST)
+          file = self.getFile(REQUEST)
+          if file is not None:
+            if len(self.getObjProperty('title',REQUEST)) == 0:
+              self.setObjProperty('title',getattr(file,'filename',''),lang)
+            if len(self.getObjProperty('titleshort',REQUEST)) == 0:
+              self.setObjProperty('titleshort',getattr(file,'filename',''),lang)
+          
+          ##### VersionManager ####
+          self.onChangeObj(REQUEST)
+          
+          ##### Message ####
+          message = self.getZMILangStr('MSG_CHANGED')
+
+        except:
+          tp, vl, tb = sys.exc_info()
+          message = '<b>Error-Type:</b> '+str(tp)+'<br/><b>Error-Value:</b> '+str(vl)+'<br/>'
+          messagekey = 'manage_tabs_error_message'
+          _globals.writeException(self,"[manage_changeProperties]")
       
-        ##### Object State ####
-        self.setObjStateModified(REQUEST)
-        
-        ##### Properties ####
-        # Metadata.
-        self.setMetadata(lang,manage_lang,REQUEST)
-        # Active.
-        self.setReqProperty('active',REQUEST)
-        self.setReqProperty('attr_active_start',REQUEST)
-        self.setReqProperty('attr_active_end',REQUEST)
-        # Title.
-        self.setReqProperty('title',REQUEST)
-        self.setReqProperty('titleshort',REQUEST)
-        # File.
-        self.setReqProperty('file',REQUEST)
-        file = self.getFile(REQUEST)
-        if file is not None:
-          if len(self.getObjProperty('title',REQUEST)) == 0:
-            self.setObjProperty('title',getattr(file,'filename',''),lang)
-          if len(self.getObjProperty('titleshort',REQUEST)) == 0:
-            self.setObjProperty('titleshort',getattr(file,'filename',''),lang)
-        
-        ##### VersionManager ####
-        self.onChangeObj(REQUEST)
-        
-        ##### Message ####
-        message = self.getLangStr('MSG_CHANGED',manage_lang) + ' (in '+str(int((time.time()-t0)*100.0)/100.0)+' secs.)'
       
       # Return with message.
       if redirect_self:
-        return RESPONSE.redirect('manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(lang,manage_lang,urllib.quote(message)))
+        return RESPONSE.redirect('manage_main?lang=%s&%s=%s'%(lang,messagekey,urllib.quote(message)))
       else:
         self.checkIn(REQUEST)
-        return RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.getParentNode().absolute_url(),lang,manage_lang,urllib.quote(message),self.id))
+        return RESPONSE.redirect('%s/manage_main?lang=%s&%s=%s#_%s'%(self.getParentNode().absolute_url(),lang,messagekey,urllib.quote(message),self.id))
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #   ZMSFile.isPageElement:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isPageElement(self): 
       return True
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSFile.getTitle
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitle(self,REQUEST): 
       return self.getObjProperty('title',REQUEST)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSFile.getTitlealt
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitlealt(self,REQUEST): 
       return self.getObjProperty('titleshort',REQUEST)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSFile.getFile
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getFile(self,REQUEST): 
       return self.getObjProperty('file',REQUEST)
 
                
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###  H T M L - P r e s e n t a t i o n 
     ###
-    ###############################################################################################
+    ############################################################################
     """
     
     # preload display interface
     rendershort_default = HTMLFile('dtml/zmsfile/render_default', globals()) 
     rendershort_print = HTMLFile('dtml/zmsfile/render_print', globals()) 
     
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSFile.renderShort:
     #
     #  Renders short presentation of File.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def renderShort(self, REQUEST):
       # Retrieve properties.
       file = self.getFile(REQUEST)
@@ -295,11 +304,11 @@ class ZMSFile(ZMSObject, Metadata):
       # Return <html>.
       return html
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSFile.printHtml:
     #
     #  Renders print presentation of a File.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def printHtml(self, level, sectionizer, REQUEST, deep=True):
       # Retrieve properties.
       file = self.getFile(REQUEST)
@@ -309,4 +318,4 @@ class ZMSFile(ZMSObject, Metadata):
       # Return <html>-presentation.
       return self.rendershort_print(self,url=url,REQUEST=REQUEST)
 
-###################################################################################################
+################################################################################
