@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # zmslinkelement.py
 #
 # $Id: zmslinkelement.py,v 1.7 2004/11/23 23:04:47 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from Globals import HTML, HTMLFile
@@ -36,11 +36,11 @@ import _metadata
 import _zreferableitem
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  zmslinkelement.initZMSLinkElement: 
 #
 #  Inits properties of ZMSLinkElement.
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def initZMSLinkElement(oItem, REQUEST):
   lang = REQUEST['lang']
   ref_obj = oItem.getRefObj()
@@ -49,11 +49,11 @@ def initZMSLinkElement(oItem, REQUEST):
       oItem.setObjProperty('title',oItem.getObjProperty('attr_ref',REQUEST),lang)
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  zmslinkelement.setZMSLinkElement: 
 #
 #  Sets properties of ZMSLinkElement (from ZMSLinkContainer).
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def setZMSLinkElement(oItem, title, url, description, REQUEST):
   lang = REQUEST['lang']
   
@@ -83,14 +83,13 @@ def setZMSLinkElement(oItem, title, url, description, REQUEST):
     oItem.onChangeObj(REQUEST)
 
 
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  zmslinkelement.addZMSLinkElement: 
 #
 #  Adds ZMSLinkElement (to ZMSLinkContainer).
-# ------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 def addZMSLinkElement(self, title, url, description, REQUEST):
   lang = REQUEST['lang']
-  manage_lang = REQUEST['manage_lang']
   type = 'new'
   if _zreferableitem.isInternalLink(url):
     type = 'replace'
@@ -127,22 +126,22 @@ def addZMSLinkElement(self, title, url, description, REQUEST):
 
 
 """
-###############################################################################################
+################################################################################
 # class ConstraintViolation(Exception):
 #
 # General exception class to indicate constraint violations.
-###############################################################################################
+################################################################################
 """
 class ConstraintViolation(Exception): pass
 
 
-################################################################################################
+################################################################################
 # Constructor(s):
 #
 # Form and method to add new object.
-################################################################################################
+################################################################################
 manage_addZMSLinkElementForm = HTMLFile('manage_addzmslinkelementform', globals()) 
-def manage_addZMSLinkElement(self, lang, manage_lang, _sort_id, REQUEST):
+def manage_addZMSLinkElement(self, lang, _sort_id, REQUEST):
   """ manage_addZMSLinkElement """
   
   ##### Create ####
@@ -156,7 +155,7 @@ def manage_addZMSLinkElement(self, lang, manage_lang, _sort_id, REQUEST):
   obj.setObjStateNew(REQUEST)
 
   ##### Init Metadata (Important: DC.Coverage!) ####
-  obj.setMetadata(lang,manage_lang,REQUEST)
+  obj.setMetadata(lang,REQUEST)
 
   ##### Init Properties ####
   obj.setReqProperty('titleshort',REQUEST)
@@ -176,17 +175,17 @@ def manage_addZMSLinkElement(self, lang, manage_lang, _sort_id, REQUEST):
 
   # Return with message.        
   if REQUEST.RESPONSE:
-    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
-    REQUEST.RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,manage_lang,urllib.quote(message)))
+    message = self.getZMILangStr('MSG_INSERTED')%obj.display_type(REQUEST)
+    REQUEST.RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,urllib.quote(message)))
         
 
-################################################################################################
-################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C l a s s
 ###   
-################################################################################################
-################################################################################################
+################################################################################
+################################################################################
 
 class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
 
@@ -250,53 +249,54 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
 
 
     """
-    ###############################################################################################
+    ############################################################################
     #
     #   Constructor
     #
-    ###############################################################################################
+    ############################################################################
     """
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getSelf:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getSelfPROXY(self, proxy, meta_type=None):
       return ZMSObject.getSelf( proxy, meta_type)
 
     def getSelf(self, meta_type=None):
-      proxy = self.__proxy__()
-      return ZMSObject.getSelf( proxy, meta_type)
+      proxy = self.getProxy()
+      rtn = self.getSelfPROXY( proxy, meta_type)
+      return rtn
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getEmbedType: 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getEmbedType(self):
       rtn = self.getObjAttrValue( self.getObjAttr( 'attr_type'), self.REQUEST) 
       return rtn
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.isEmbedded: 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isEmbedded(self, REQUEST):
       rtn = self.getEmbedType() in [ 'embed', 'recursive']
       return rtn
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.isEmbeddedRecursive: 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isEmbeddedRecursive(self, REQUEST):
       rtn = self.getEmbedType() in [ 'recursive']
       return rtn
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getLinkList: 
     #
     #  Overrides getLinkList of zmscontainerobject.ZMSContainerObject.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLinkList(self, REQUEST, allow_none=0):
       rtn = []
       append = self.isVisible(REQUEST) and not self.isResource(REQUEST)
@@ -324,25 +324,25 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###   Properties
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSLinkElement.manage_changeProperties: 
     #
     #  Change Linkelement properties.
-    ###############################################################################################
-    def manage_changeProperties(self, lang, manage_lang, REQUEST, RESPONSE): 
+    ############################################################################
+    def manage_changeProperties(self, lang, REQUEST, RESPONSE): 
       """ ZMSLinkElement.manage_changeProperties """
       
       self._checkWebDAVLock()
       target = REQUEST.get( 'target', '%s/manage_main'%self.getParentNode().absolute_url())
       message = ''
-      if REQUEST.get('btn','') not in  [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]:
+      if REQUEST.get('btn','') not in  [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]:
         try:
           
           ##### Object State ####
@@ -361,13 +361,13 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
               self.setReqProperty(key,REQUEST)
           
           ##### Metadata ####
-          self.setMetadata(lang,manage_lang,REQUEST)
+          self.setMetadata(lang,REQUEST)
           
           ##### VersionManager ####
           self.onChangeObj(REQUEST)
           
           ##### Success Message ####
-          message = self.getLangStr('MSG_CHANGED',manage_lang)
+          message = self.getZMILangStr('MSG_CHANGED')
         
         ##### Failure Message ####
         except ConstraintViolation:
@@ -376,14 +376,14 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       
       # Return with message.
       self.checkIn(REQUEST)
-      target = self.url_append_params( target, { 'lang': lang, 'manage_lang': manage_lang, 'manage_tabs_message': message})
+      target = self.url_append_params( target, { 'lang': lang, 'manage_tabs_message': message})
       target = '%s#_%s'%( target, self.id)
       return RESPONSE.redirect( target)
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getRef:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getRef(self): 
       coverage = self.getDCCoverage()
       req = {'preview':'preview','lang':coverage[coverage.find('.')+1:]}
@@ -391,9 +391,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return ref
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getRefObj:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getRefObj(self): 
       coverage = self.getDCCoverage()
       req = {'preview':'preview','lang':coverage[coverage.find('.')+1:]}
@@ -405,9 +405,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return ref_obj
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.isMetaType:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isMetaTypePROXY(self, proxy, meta_type, REQUEST={'preview':'preview'}):
       if proxy != self and proxy is not None and self.isEmbeddedRecursive( self.REQUEST):
         b = proxy.isMetaType( meta_type, REQUEST)
@@ -427,9 +427,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getLevel:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getLevelPROXY(self, proxy):
       if proxy != self and proxy is not None and self.isEmbeddedRecursive( self.REQUEST):
         rtn = proxy.getLevel()
@@ -443,9 +443,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getParentNode:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getParentNodePROXY(self, proxy):
       if proxy != self and proxy is not None and self.isEmbeddedRecursive( self.REQUEST):
         rtn = proxy.getParentNode()
@@ -459,9 +459,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getTitlealt:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitlealtPROXY(self, proxy, REQUEST):
       if proxy != self and proxy is not None and self.isEmbeddedRecursive( REQUEST):
         rtn = proxy.getTitlealt( REQUEST)
@@ -483,9 +483,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
       
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getTitle:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitlePROXY(self, proxy, REQUEST):
       if proxy != self and proxy is not None and self.isEmbeddedRecursive( REQUEST):
         rtn = proxy.getTitle( REQUEST)
@@ -507,9 +507,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
       
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.display_icon:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def display_icon(self, REQUEST, meta_type=''): 
       ref_obj = self.getRefObj()
       if ref_obj is None or not self.isEmbedded(REQUEST):
@@ -523,9 +523,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
         return ref_obj.display_icon(REQUEST,meta_type)
 
     
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.isActive:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isActive(self, REQUEST):
       active = ZMSContainerObject.isActive(self,REQUEST) 
       ref_obj = self.getRefObj()
@@ -534,9 +534,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return active
 
     
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.isPage
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isPage(self):
       rtnVal = False
       req = {'lang':self.getPrimaryLanguage(),'preview':'preview'}
@@ -548,9 +548,9 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtnVal
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.isPageElement
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isPageElement(self): 
       rtnVal = False
       ref_obj = self.getRefObj()
@@ -559,11 +559,11 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtnVal
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getType
     #
     #  Overrides getType of zmscustom.ZMSCustom. 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTypePROXY(self, proxy): 
       rtn = 'ZMSObject'
       if proxy != self and proxy is not None and self.isEmbeddedRecursive( self.REQUEST):
@@ -580,11 +580,11 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getObjProperty
     #
     #  Overrides getObjProperty of _objattrs.ObjAttrs. 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getObjPropertyPROXY(self, proxy, key, REQUEST={}, default=None): 
       obj_attr = proxy.getObjAttr( key)
       value = proxy.getObjAttrValue( obj_attr, REQUEST) 
@@ -592,7 +592,7 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
 
     def getObjProperty(self, key, REQUEST={}, default=None): 
       value = self.getObjPropertyPROXY( self, key, REQUEST, default)
-      if not key in ['attr_ref','attr_dc_coverage'] and (value is None or len(str(value)) == 0):
+      if key not in ['attr_ref','attr_dc_coverage'] and (value is None or len(str(value)) == 0 or value == 0):
         recursive = self.isEmbeddedRecursive( REQUEST)
         if recursive:
           proxy = self.getProxy()
@@ -605,25 +605,27 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return value
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getFormat
     #
     #  Includes getFormat of zmsgraphic.ZMSGraphic and zmstextarea.ZMSTextarea.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getFormat(self,REQUEST): 
       return self.getObjProperty('format',REQUEST)
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getTeaserElements:
     #
     #  Overrides getTeaserElements of zmscontainerobject.ZMSContainerObject.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTeaserElementsPROXY(self, proxy, REQUEST, current=None):
       rtn = []
       recursive = self.isEmbeddedRecursive( REQUEST)
       if proxy != self and proxy is not None and recursive:
-        pass
+        for el in ZMSContainerObject.getTeaserElements( proxy, REQUEST): 
+          if not el in rtn:
+            rtn.append(el)
       else:
         if self.isPage():
           for el in ZMSContainerObject.getTeaserElements( self, REQUEST):
@@ -637,16 +639,47 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
     def getTeaserElements(self, REQUEST, current=None):
+      rtn = []
+      embedded = self.isEmbedded( REQUEST)
+      if embedded:
+        if self.isPage():
+          for el in ZMSContainerObject.getTeaserElements( self.aq_parent, REQUEST, self):
+            if not el in rtn:
+              rtn.append(el)
       proxy = self.getProxy()
-      rtn = self.getTeaserElementsPROXY( proxy, REQUEST, current)
+      for el in self.getTeaserElementsPROXY( proxy, REQUEST, current):
+        if not el in rtn:
+          rtn.append(el)
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
+    #  ZMSLinkElement.getNavItems:
+    #
+    #  Overrides getNavItems of zmscontainerobject.ZMSContainerObject.
+    # --------------------------------------------------------------------------
+    def getNavItemsPROXY(self, proxy, current, REQUEST, opt={}):
+      rtn = []
+      recursive = self.isEmbeddedRecursive( REQUEST)
+      if proxy != self and proxy is not None and recursive:
+        rtn = proxy.getNavItems( current, REQUEST, opt)
+      else:
+        ref_obj = self.getRefObj()
+        if isinstance(ref_obj,ZMSContainerObject):
+          rtn = ZMSContainerObject.getNavItems( self, current, REQUEST, opt)
+      return rtn
+
+    def getNavItems(self, current, REQUEST, opt={}):
+      proxy = self.getProxy()
+      rtn = self.getNavItemsPROXY( proxy, current, REQUEST, opt)
+      return rtn
+
+
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getNavElements:
     #
     #  Overrides getNavElements of zmscontainerobject.ZMSContainerObject.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getNavElementsPROXY(self, proxy, REQUEST, expand_tree=1, current_child=None, subElements=[]):
       rtn = []
       recursive = self.isEmbeddedRecursive( REQUEST)
@@ -665,16 +698,16 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###  HTML-Presentation
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getHref2IndexHtml:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getHref2IndexHtmlPROXY(self, proxy, REQUEST, deep=1): 
       if proxy != self and proxy is not None and self.isEmbeddedRecursive( self.REQUEST):
         rtn = proxy.getHref2IndexHtml( REQUEST, deep)
@@ -688,11 +721,11 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSLinkElement._getBodyContent:
     #
     #	HTML presentation of Linkelement. 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _getBodyContent(self, REQUEST):
       rtn = ''
       proxy = self.getProxy()
@@ -705,11 +738,11 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSLinkElement.renderShort:
     #
     #	Renders short presentation of Linkelement.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def renderShort(self, REQUEST):
       s = ''
       ref = self.getObjProperty('attr_ref',REQUEST)
@@ -723,7 +756,7 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
         else:
           img_src = 'internal_link.gif'
           if self.isPreviewRequest(REQUEST):
-            ref = '%s/manage_main?lang=%s&manage_lang=%s'%(ref_obj.absolute_url(),REQUEST['lang'],REQUEST['manage_lang'])
+            ref = '%s/manage_main?lang=%s'%(ref_obj.absolute_url(),REQUEST['lang'])
           else:
             ref = ref_obj.getHref2IndexHtml(REQUEST)
       elif _zreferableitem.isMailLink(ref):
@@ -758,11 +791,11 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return s
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.catalogText:
     #
     #  Catalog text of Link (overwrite method from ZCatalogItem).
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def catalogText(self, REQUEST):
       s = ''
       ref_obj = self.getRefObj()
@@ -774,16 +807,16 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###  
     ###  DOM-Methods
     ### 
-    ###############################################################################################
+    ############################################################################
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.breadcrumbs_obj_path:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def breadcrumbs_obj_pathPROXY(self, proxy):
       if proxy != self and proxy is not None and self.isEmbeddedRecursive( self.REQUEST):
         rtn = proxy.breadcrumbs_obj_path()
@@ -797,61 +830,65 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getTreeNodes:
     #
-    #  Returns an empty NodeList that contains all children of this subtree in correct order.
-    #  If none, this is a empty NodeList. 
-    # ---------------------------------------------------------------------------------------------
+    #  Returns an empty NodeList that contains all children of this subtree in 
+    #  correct order. If none, this is a empty NodeList. 
+    # --------------------------------------------------------------------------
     def getTreeNodes(self, REQUEST={}, meta_types=None):
       return []
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.initProxy: 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def initProxy(self, base, url_base, proxy, recursive=False):
-      return ZMSProxyObject( base, url_base, proxy, recursive)
+      return ZMSProxyObject( self, base, url_base, proxy.id, proxy, recursive)
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.__proxy__:
     #
     #  Returns self or referenced object (if embedded) as ZMSProxyObject
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __proxy__(self):
       rtn = self
       req = self.REQUEST
-      if req.get( 'URL', '').find( '/manage') < 0 or \
-         req.get( 'ZMS_PATH_HANDLER', False):
-        if self.isEmbeddedRecursive( req):
-          ref_obj = self.getRefObj()
-          if ref_obj is not None:
-            recursive = True
-            rtn = ZMSProxyObject( self.aq_parent, self.absolute_url(), ref_obj, recursive)
+      if req.get( 'ZMS_PROXY', True):
+        if req.get( 'URL', '').find( '/manage') < 0 or req.get( 'ZMS_PATH_HANDLER', False):
+          if self.isEmbeddedRecursive( req):
+            ref_obj = self.getRefObj()
+            if ref_obj is not None:
+              recursive = True
+              rtn = ZMSProxyObject( self, self.aq_parent, self.absolute_url(), self.id, ref_obj, recursive)
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getProxy:
     #
-    #  Returns self or proxy-object from Path-Handler (if embedded) as ZMSProxyObject
-    # ---------------------------------------------------------------------------------------------
+    #  Returns self or proxy-object from Path-Handler (if embedded) as 
+    #  ZMSProxyObject.
+    # --------------------------------------------------------------------------
     def getProxy(self):
-      rtn = self.REQUEST.get( 'ZMS_PROXY', self.__proxy__())
+      rtn = self
+      req = self.REQUEST
+      if req.get( 'ZMS_PROXY', True):
+        rtn = req.get( 'ZMS_PROXY_%s'%self.id, self.__proxy__())
       return rtn
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.getChildNodes:
     #
     #  Overrides original method of zmscontainerobject.ZMSContainerObject. 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getChildNodesPROXY(self, proxy, REQUEST={}, meta_types=None):
       rtn = []
       if proxy != self and proxy is not None and self.isEmbeddedRecursive( REQUEST):
         recursive = True
-        rtn = map( lambda x: ZMSProxyObject( proxy.getParentNode(), proxy.absolute_url()+'/'+x.id, x, recursive), proxy.getChildNodes( REQUEST, meta_types))
+        rtn = map( lambda x: self.initProxy( proxy, proxy.absolute_url()+'/'+x.id, x, recursive), proxy.getChildNodes( REQUEST, meta_types))
       elif proxy == self and proxy is not None and self.isEmbedded( REQUEST):
         ref_obj = self.getRefObj()
         if ref_obj is not None:
@@ -866,18 +903,18 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       return rtn
 
     """
-    ###############################################################################################    
+    ############################################################################    
     #
     #   Printable
     #
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSLinkElement.printHtml:
     #
     #  Renders print presentation of a ContainerObject.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def printHtmlPROXY(self, proxy, level, sectionizer, REQUEST, deep=True):
       rtn = ''
       recursive = self.isEmbeddedRecursive( REQUEST)
@@ -894,4 +931,4 @@ class ZMSLinkElement(ZMSContainerObject, _metadata.Metadata):
       rtn = self.printHtmlPROXY( proxy, level, sectionizer, REQUEST, deep)
       return rtn
 
-###################################################################################################
+################################################################################
