@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # zmsnote.py
 #
 # $Id: zmsnote.py,v 1.4 2004/11/23 23:04:48 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from Globals import HTML, HTMLFile
@@ -32,15 +32,15 @@ from zmsobject import ZMSObject
 import _globals
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C o n s t r u c t o r ( s )
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
-def manage_addZMSNote(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
+def manage_addZMSNote(self, lang, _sort_id, REQUEST, RESPONSE):
   """ manage_addZMSNote """
 
   ##### Create ####    
@@ -58,7 +58,7 @@ def manage_addZMSNote(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
   else:
     obj.setObjProperty('attr_dc_coverage','global.'+lang)
   ##### Init Properties ####
-  obj.manage_changeProperties(lang,manage_lang,REQUEST,RESPONSE)
+  obj.manage_changeProperties(lang,REQUEST,RESPONSE)
   ##### VersionManager ####
   obj.onChangeObj(REQUEST)
             
@@ -67,17 +67,17 @@ def manage_addZMSNote(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
         
   # Return with message.        
   if REQUEST.RESPONSE:
-    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
-    REQUEST.RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,manage_lang,urllib.quote(message)))
+    message = self.getZMILangStr('MSG_INSERTED')%obj.display_type(REQUEST)
+    REQUEST.RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,urllib.quote(message)))
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C l a s s
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 class ZMSNote(ZMSObject):
 
@@ -132,25 +132,25 @@ class ZMSNote(ZMSObject):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   P r o p e r t i e s
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSNote.manage_changeProperties: 
     #
     #  Change Note properties.
-    ###############################################################################################
-    def manage_changeProperties(self, lang, manage_lang, REQUEST, RESPONSE): 
+    ############################################################################
+    def manage_changeProperties(self, lang, REQUEST, RESPONSE): 
       """ ZMSNote.manage_changeProperties """
       
       self._checkWebDAVLock()
       message = ''
       
-      if REQUEST.get('btn','') not in  [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]:
+      if REQUEST.get('btn','') not in  [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]:
         
         ##### Object State #####
         self.setObjStateModified(REQUEST)
@@ -163,59 +163,59 @@ class ZMSNote(ZMSObject):
         self.onChangeObj(REQUEST)
           
         ##### Message #####
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
         
       # Return with message.
       self.checkIn(REQUEST)
-      return RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.getParentNode().absolute_url(),lang,manage_lang,urllib.quote(message),self.id))
+      return RESPONSE.redirect('%s/manage_main?lang=%s&manage_tabs_message=%s#_%s'%(self.getParentNode().absolute_url(),lang,urllib.quote(message),self.id))
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSNote.isActive
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isActive(self,REQUEST): return 1 # Always active.
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSNote.isVisible
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isVisible(self,REQUEST): return 0 # Always invisible.
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSNote.getTitlealt
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitlealt(self,REQUEST): return self.display_type(REQUEST)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSNote.getText
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getText(self,REQUEST): return self.getObjProperty('text',REQUEST,'')
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###  H T M L - P r e s e n t a t i o n 
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
     # preload display interface for notes
     rendershort_default = HTMLFile('dtml/zmsnote/rendershort_default', globals()) 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSNote.renderShort:
     #
     #  Renders short presentation of a Note.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def renderShort(self, REQUEST):
       return self.rendershort_default(self,text=self.getText(REQUEST),REQUEST=REQUEST)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSNote.printHtml:
     #
     #  Renders print presentation of a Note.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def printHtml(self, level, sectionizer, REQUEST, deep=True):
       return '<!--%s-->'%self.getText(REQUEST)
 
-###################################################################################################
+################################################################################
