@@ -1,4 +1,4 @@
-                                ###################################################################################################
+################################################################################
 # zmssqldb.py
 #
 # $Id: zmssqldb.py,v 1.9 2004/11/23 23:04:49 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from __future__ import nested_scopes
@@ -40,16 +40,16 @@ import _objattrs
 import _xmllib
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C o n s t r u c t o r ( s )
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 manage_addZMSSqlDbForm = HTMLFile('manage_addzmssqldbform', globals()) 
-def manage_addZMSSqlDb(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
+def manage_addZMSSqlDb(self, lang, _sort_id, REQUEST, RESPONSE):
   """ manage_addZMSSqlDb """
     
   ##### Create ####
@@ -61,7 +61,7 @@ def manage_addZMSSqlDb(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
   ##### Object State ####
   obj.setObjStateNew(REQUEST)
   ##### Init Properties ####
-  obj.manage_changeProperties(lang,manage_lang,REQUEST,RESPONSE)
+  obj.manage_changeProperties(lang,REQUEST,RESPONSE)
   ##### VersionManager ####
   obj.onChangeObj(REQUEST)
             
@@ -70,17 +70,17 @@ def manage_addZMSSqlDb(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
         
   # Return with message.        
   if REQUEST.RESPONSE:
-    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
-    REQUEST.RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,manage_lang,urllib.quote(message)))
+    message = self.getZMILangStr('MSG_INSERTED')%obj.display_type(REQUEST)
+    REQUEST.RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,urllib.quote(message)))
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   C l a s s
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 class ZMSSqlDb(ZMSObject):
 
@@ -106,6 +106,7 @@ class ZMSSqlDb(ZMSObject):
 		'manage_cutObjects','manage_copyObjects','manage_pasteObjs',
 		'manage_userForm', 'manage_user',
 		'manage_importexport', 'manage_import', 'manage_export',
+		'manage_ajaxQuery',
 		)
     __administratorPermissions__ = (
 		'manage_properties','manage_changeProperties',
@@ -132,7 +133,9 @@ class ZMSSqlDb(ZMSObject):
 
     # Management Interface.
     # ---------------------
+    actions = HTMLFile('dtml/zmssqldb/actions', globals())
     input_form = HTMLFile('dtml/zmssqldb/input_form', globals())
+    browse_db = HTMLFile('dtml/zmssqldb/browse_db', globals())
     intersection_sql = HTMLFile('dtml/zmssqldb/intersection_sql', globals())
     manage_main = HTMLFile('dtml/zmssqldb/manage_main', globals())
     manage_importexport = HTMLFile('dtml/zmssqldb/manage_importexport', globals())
@@ -140,16 +143,16 @@ class ZMSSqlDb(ZMSObject):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     #
     #   CONSTRUCTOR
     #
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.sql_quote__:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def sql_quote__(self, tablename, columnname, v):
       entities = self.getEntities()
       entity = filter(lambda x: x['id'].upper() == tablename.upper(), entities)[0]
@@ -177,9 +180,30 @@ class ZMSSqlDb(ZMSObject):
         if v.find("\'") >= 0: v=''.join(v.split("\'"),"''")
         return "'%s'"%v
 
-    # ------------------------------------------------------------------------------------------
+
+    # --------------------------------------------------------------------------
+    # ZMSSqlDb.commit:
+    # --------------------------------------------------------------------------
+    def commit(self):
+      databaseAdptr = getattr(self,self.connection_id)
+      dbc = databaseAdptr._v_database_connection
+      conn = dbc.getconn(False)
+      conn.commit()
+
+
+    # --------------------------------------------------------------------------
+    # ZMSSqlDb.rollback:
+    # --------------------------------------------------------------------------
+    def rollback(self):
+      databaseAdptr = getattr(self,self.connection_id)
+      dbc = databaseAdptr._v_database_connection
+      conn = dbc.getconn(False)
+      conn.rollback()
+
+
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.query:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def query(self, qs, max_rows=None):
       from cStringIO import StringIO
       from Shared.DC.ZRDB.Results import Results
@@ -216,14 +240,48 @@ class ZMSSqlDb(ZMSObject):
         column['sort'] = 1
         columns.append(column)
       keys = map(lambda x: x['id'], columns)
-      records = result
-      # records = map(lambda x: _globals.map_key_vals(keys, x), result)
-      return {'columns':columns,'records':records}
+      return {'columns':columns,'records':result}
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
+    #  ZMSSqlDb.manage_ajaxQuery:
+    # --------------------------------------------------------------------------
+    def manage_ajaxQuery(self, qs, REQUEST):
+      """ ZMSObject.manage_ajaxQuery """
+      #-- Build xml.
+      RESPONSE = REQUEST.RESPONSE
+      content_type = 'text/xml; charset=utf-8'
+      filename = 'ajaxQuery.xml'
+      RESPONSE.setHeader('Content-Type',content_type)
+      RESPONSE.setHeader('Content-Disposition','inline;filename=%s'%filename)
+      RESPONSE.setHeader('Cache-Control', 'no-cache')
+      RESPONSE.setHeader('Pragma', 'no-cache')
+      self.f_standard_html_request( self, REQUEST)
+      xml = '<?xml version="1.0" encoding="%s"?>'%REQUEST.get('encoding','iso-8859-1')
+      xml += '<records>'
+      result = self.query( qs, REQUEST.get('max_rows'))
+      c = 0
+      for record in result['records']:
+        c = c + 1
+        xml += '<record index="%i">'%c
+        for column in result['columns']:
+          id = column['id']
+          v = record[id]
+          if v:
+            v = str(v)
+            if column['type'] == 'string':
+              xml += '<%s><![CDATA[%s]]></%s>'%(id,v,id)
+            else:
+              xml += '<%s>%s</%s>'%(id,str(v),id)
+        xml += '</record>'
+      xml += '</records>'
+      return xml
+      
+
+
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.executeQuery:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def executeQuery(self, qs):
       from cStringIO import StringIO
       from Shared.DC.ZRDB.Results import Results
@@ -241,17 +299,25 @@ class ZMSSqlDb(ZMSObject):
       return len(result)
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
+    #  ZMSSqlDb.getEntityColumn:
+    # --------------------------------------------------------------------------
+    def getEntityColumn(self, tableName, columnName):
+      columns = self.getEntity( tableName)['columns']
+      return filter(lambda x: x['id'].upper() == columnName.upper(), columns)[0]
+
+
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.getEntity:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getEntity(self, tableName):
       entities = self.getEntities()
       return filter(lambda x: x['id'].upper() == tableName.upper(), entities)[0]
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.getEntities:
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getEntities(self):
 
       #-- [ReqBuff]: Fetch buffered value from Http-Request.
@@ -266,112 +332,119 @@ class ZMSSqlDb(ZMSObject):
       model = getattr(self,'model',[])
       databaseAdptr = getattr(self,self.connection_id)
       tableBrwsrs = databaseAdptr.tpValues()
+
       # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
-      # +- ENTITES (for Oracle_Database_Connection (please refer to $ZMS_HOME/conf/db/getEntities.Oracle.dtml)
+      # +- ENTITES
       # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
-      if len( tableBrwsrs) == 0:
-        method = getattr(self,'getEntities%s'%self.connection_id,None)
-        if method is not None:
-          for entity in method( self, REQUEST):
-            entities.append((entity['label'],entity))
-      for tableBrwsr in tableBrwsrs:
-        tableName = tableBrwsr.Name()
-        tableType = tableBrwsr.Type().upper()
-        tableInterface = ''
-        if tableType == 'TABLE':
-          # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
-          # +- COLUMNS
-          # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
-          cols = []
-          colIds = []
-          for columnBrwsr in tableBrwsr.tpValues():
-            colId = columnBrwsr.tpId()
-            colDescr = columnBrwsr.Description().upper()
-            colType = 'string'
-            colSize = None
-            if colDescr.find('INT') >= 0:
-              colType = 'int'
-            elif colDescr.find('DATE') >= 0 or \
-                 colDescr.find('TIME') >= 0:
-              colType = 'datetime'
-            elif colDescr.find('CHAR') >= 0 or \
-                 colDescr.find('STRING') >= 0:
-              colSize = 50
-              i = colDescr.find('(')
-              if i >= 0:
-                j = colDescr.find(')')
-                if j >= 0:
-                  colSize = int(colDescr[i+1:j])
-              if colSize > 50:
-                colType = 'text'
-              else:
-                colType = 'string'
-            col = {}
-            col['key'] = colId
-            col['id'] = col['key']
-            col['label'] = ' '.join( map( lambda x: x.capitalize(), colId.split('_'))).strip()
-            col['name'] = col['label']
-            col['mandatory'] = colDescr.find('NOT NULL')>0
-            col['type'] = colType
-            col['sort'] = 1
-            col['nullable'] = 1
-            # Custom Column Properties.
+
+      #-- for custom entities please refer to $ZMS_HOME/conf/db/getEntities.Oracle.dtml
+      method = getattr(self,'getEntities%s'%self.connection_id,None)
+      if method is not None:
+        for entity in method( self, REQUEST):
+          entities.append((entity['label'],entity))
+          
+      #-- retrieve entities from table-browsers
+      if len( entities) == 0:
+        for tableBrwsr in tableBrwsrs:
+          tableName = tableBrwsr.Name()
+          tableType = tableBrwsr.Type().upper()
+          tableInterface = ''
+          if tableType == 'TABLE':
+            # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
+            # +- COLUMNS
+            # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
+            cols = []
+            colIds = []
+            for columnBrwsr in tableBrwsr.tpValues():
+              colId = columnBrwsr.tpId()
+              colDescr = columnBrwsr.Description().upper()
+              colType = 'string'
+              colSize = None
+              if colDescr.find('INT') >= 0:
+                colType = 'int'
+              elif colDescr.find('DATE') >= 0 or \
+                   colDescr.find('TIME') >= 0:
+                colType = 'datetime'
+              elif colDescr.find('CHAR') >= 0 or \
+                   colDescr.find('STRING') >= 0:
+                colSize = 50
+                i = colDescr.find('(')
+                if i >= 0:
+                  j = colDescr.find(')')
+                  if j >= 0:
+                    colSize = int(colDescr[i+1:j])
+                if colSize > 50:
+                  colType = 'text'
+                else:
+                  colType = 'string'
+              col = {}
+              col['key'] = colId
+              col['id'] = col['key']
+              col['label'] = ' '.join( map( lambda x: x.capitalize(), colId.split('_'))).strip()
+              col['name'] = col['label']
+              col['mandatory'] = colDescr.find('NOT NULL')>0
+              col['type'] = colType
+              col['sort'] = 1
+              col['nullable'] = 1
+              # Custom Column Properties.
+              for modelTable in filter(lambda x: x['id'].upper() == tableName.upper(), model):
+                for modelTableCol in filter(lambda x: x['id'].upper() == colId.upper(), modelTable.get('columns',[])):
+                  for modelTableColProp in filter(lambda x: x not in ['id'], modelTableCol.keys()):
+                    col[modelTableColProp] = modelTableCol[modelTableColProp]
+              # Add Column.
+              cols.append(col)
+              colIds.append(colId.upper())
+            # Model.
             for modelTable in filter(lambda x: x['id'].upper() == tableName.upper(), model):
-              for modelTableCol in filter(lambda x: x['id'].upper() == colId.upper(), modelTable.get('columns',[])):
-                for modelTableColProp in filter(lambda x: x not in ['id'], modelTableCol.keys()):
-                  col[modelTableColProp] = modelTableCol[modelTableColProp]
-            # Add Column.
-            cols.append(col)
-            colIds.append(colId.upper())
-          # Model.
-          for modelTable in filter(lambda x: x['id'].upper() == tableName.upper(), model):
-            tableInterface = modelTable.get('interface','')
-            # Add Custom Columns.
-            for modelTableCol in filter(lambda x: x['id'].upper() not in colIds, modelTable.get('columns',[])):
-              col = modelTableCol
-              col['id'] = col.get('id','?')
-              col['index'] = col.get('index',len(cols))
-              col['type'] = col.get('type','?')
-              col['key'] = col.get('key',col.get('id'))
-              col['label'] = col.get('label',col.get('id'))
-              cols.insert(col['index'], col)
-              colIds.append(col['id'].upper())
-          # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
-          # +- TABLE
-          # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
-          if len(cols) > 0:
-            entity = {}
-            entity['id'] = tableName
-            entity['interface'] = tableInterface
-            entity['label'] = ' '.join( map( lambda x: x.capitalize(), tableName.split('_'))).strip()
-            entity['type'] = 'table'
-            entity['columns'] = cols
-            # Custom Table Properties.
-            for modelTable in filter(lambda x: x['id'].upper() ==tableName.upper(), model):
-              for modelTableProp in filter(lambda x: x not in ['columns'], modelTable.keys()):
-                entity[modelTableProp] = modelTable[modelTableProp]
-            # Add Table.
-            entities.append((entity['label'],entity))
+              tableInterface = modelTable.get('interface','')
+              # Add Custom Columns.
+              for modelTableCol in filter(lambda x: x['id'].upper() not in colIds, modelTable.get('columns',[])):
+                col = modelTableCol
+                col['id'] = col.get('id','?')
+                col['index'] = col.get('index',len(cols))
+                col['type'] = col.get('type','?')
+                col['key'] = col.get('key',col.get('id'))
+                col['label'] = col.get('label',col.get('id'))
+                cols.insert(col['index'], col)
+                colIds.append(col['id'].upper())
+            # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
+            # +- TABLE
+            # +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
+            if len(cols) > 0:
+              entity = {}
+              entity['id'] = tableName
+              entity['interface'] = tableInterface
+              entity['label'] = ' '.join( map( lambda x: x.capitalize(), tableName.split('_'))).strip()
+              entity['type'] = 'table'
+              entity['columns'] = cols
+              # Custom Table Properties.
+              for modelTable in filter(lambda x: x['id'].upper() ==tableName.upper(), model):
+                for modelTableProp in filter(lambda x: x not in ['columns'], modelTable.keys()):
+                  entity[modelTableProp] = modelTable[modelTableProp]
+              # Add Table.
+              entities.append((entity['label'],entity))
+
+      #-- Sort entities
       entities.sort()
       entities = map(lambda x: x[1], entities)
 
       #-- [ReqBuff]: Returns value and stores it in buffer of Http-Request.
-      return self.storeReqBuff( reqBuffId, entities, REQUEST, True)
+      return self.storeReqBuff( reqBuffId, entities, REQUEST)
       
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   R e c o r d S e t
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.recordSet_Init:
     #
     #  Initializes RecordSet.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def recordSet_Init(self, REQUEST):
       SESSION = REQUEST.SESSION      
       tabledefs = self.getEntities()
@@ -395,17 +468,18 @@ class ZMSSqlDb(ZMSObject):
       REQUEST.set('primary_key',primary_key[0])
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.recordSet_Filter:
     #
     #  Filters RecordSet.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def recordSet_Filter(self, REQUEST):
       SESSION = REQUEST.SESSION      
       tablename = SESSION['qentity_%s'%self.id]
       tabledefs = self.getEntities()
       tabledef = filter(lambda x: x['id'].upper() == tablename.upper(), tabledefs)[0]
       tablecols = tabledef['columns']
+      tablefilter = tabledef.get('filter','')
       #-- WHERE
       SESSION.set('qfilters_%s'%self.id,REQUEST.form.get('qfilters',SESSION.get('qfilters_%s'%self.id,1)))
       q = 'WHERE '
@@ -417,11 +491,11 @@ class ZMSSqlDb(ZMSObject):
         sessionop='%s_%s'%(filterop,self.id)
         sessionvalue='%s_%s'%(filtervalue,self.id)
         if REQUEST.get('action','')=='':
-          if REQUEST.get('btn','')==self.getLangStr('BTN_RESET',REQUEST['manage_lang']):
+          if REQUEST.get('btn','')==self.getZMILangStr('BTN_RESET'):
             SESSION.set(sessionattr,'')
             SESSION.set(sessionop,'')
             SESSION.set(sessionvalue,'')
-          elif REQUEST.get('btn','')==self.getLangStr('BTN_REFRESH',REQUEST['manage_lang']):
+          elif REQUEST.get('btn','')==self.getZMILangStr('BTN_REFRESH'):
             SESSION.set(sessionattr,REQUEST.form.get(filterattr,''))
             SESSION.set(sessionop,REQUEST.form.get(filterop,''))
             SESSION.set(sessionvalue,REQUEST.form.get(filtervalue,''))
@@ -434,13 +508,18 @@ class ZMSSqlDb(ZMSObject):
             sqlStatement.append(q + columnname + ' ' + op + ' ' + self.sql_quote__(tablename, columnname, v) + ' ')
             REQUEST.set('sqlStatement',sqlStatement)
             q = 'AND '
+      if len(tablefilter) > 0:
+        sqlStatement = REQUEST.get('sqlStatement',[])
+        sqlStatement.append(q + tablefilter + ' ')
+        REQUEST.set('sqlStatement',sqlStatement)
+        q = 'AND '
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.recordSet_Sort:
     #
     #  Sorts RecordSet.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def recordSet_Sort(self, REQUEST):
       SESSION = REQUEST.SESSION      
       tablename = SESSION['qentity_%s'%self.id]
@@ -465,81 +544,81 @@ class ZMSSqlDb(ZMSObject):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   P r o p e r t i e s
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSSqlDb.manage_changeProperties: 
     #
     #  Change Sql-Database properties.
-    ###############################################################################################
-    def manage_changeProperties(self, lang, manage_lang, REQUEST=None, RESPONSE=None): 
+    ############################################################################
+    def manage_changeProperties(self, lang, REQUEST=None, RESPONSE=None): 
       """ ZMSSqlDb.manage_changeProperties """
       message = ''
 
-      if REQUEST.get('btn','') not in  [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]:
+      if REQUEST.get('btn','') not in  [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]:
         self.connection_id = REQUEST['connection_id']
         self.max_rows = REQUEST['max_rows']
         self.charset = REQUEST['charset']
         self.model_xml = REQUEST['model']
         self.model = self.parseXmlString(REQUEST['model'])
-        message = self.getLangStr('MSG_CHANGED',manage_lang)
+        message = self.getZMILangStr('MSG_CHANGED')
       
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_properties?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(lang,manage_lang,message))
+      return RESPONSE.redirect('manage_properties?lang=%s&manage_tabs_message=%s'%(lang,message))
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.getTitlealt
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitlealt( self, REQUEST): 
       return self.display_type( REQUEST)
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###  H T M L - P r e s e n t a t i o n 
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
     # preload display interface
     rendershort_default = HTMLFile('dtml/zmssqldb/rendershort_default', globals()) 
     
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSSqlDb._getBodyContent:
     #
     #	HTML presentation of Textarea. 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _getBodyContent(self, REQUEST):
       return self.rendershort_default( self, REQUEST=REQUEST)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSSqlDb.renderShort:
     #
     #	Renders short presentation of Textarea.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def renderShort(self, REQUEST):
       return self._getBodyContent( REQUEST)
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   I m / E x p o r t
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSSqlDb.importFile
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def importFile(self, file, REQUEST):
       message = ''
       
@@ -603,33 +682,33 @@ class ZMSSqlDb(ZMSObject):
       _fileutil.remove(folder, deep=1)
       
       # Return with message.
-      message += self.getLangStr('MSG_IMPORTED',REQUEST['manage_lang'])%('<i>%s</i>'%_fileutil.extractFilename(filename))
+      message += self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%_fileutil.extractFilename(filename))
       return message
 
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSSqlDb.manage_import: 
     #
     #  Import data to Sql-Database.
-    ###############################################################################################
-    def manage_import(self, lang, manage_lang, REQUEST=None, RESPONSE=None): 
+    ############################################################################
+    def manage_import(self, lang, REQUEST=None, RESPONSE=None): 
       """ ZMSSqlDb.manage_import """
       message = ''
       
-      if REQUEST.get('btn','') not in  [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]:
+      if REQUEST.get('btn','') not in  [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]:
         message = self.importFile(REQUEST.get('file'),REQUEST)
       
       # Return with message.
       message = urllib.quote(message)
-      return RESPONSE.redirect('manage_importexport?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(lang,manage_lang,message))
+      return RESPONSE.redirect('manage_importexport?lang=%s&manage_tabs_message=%s'%(lang,message))
 
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSSqlDb.manage_export: 
     #
     #  Export data from Sql-Database.
-    ###############################################################################################
-    def manage_export(self, lang, manage_lang, REQUEST=None, RESPONSE=None): 
+    ############################################################################
+    def manage_export(self, lang, REQUEST=None, RESPONSE=None): 
       """ ZMSSqlDb.manage_export """
       export = []
       export.append(self.getXmlHeader())
@@ -675,13 +754,13 @@ class ZMSSqlDb(ZMSObject):
       return ''.join(export)
 
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSSqlDb.pub_export:
     #
     #  Export data from Sql-Database.
-    ###############################################################################################
-    def pub_export(self, lang, manage_lang, REQUEST=None, RESPONSE=None): 
+    ############################################################################
+    def pub_export(self, lang, REQUEST=None, RESPONSE=None): 
       """ Exportable.pub_export """
-      return self.manage_export( lang, manage_lang, REQUEST, RESPONSE)
+      return self.manage_export( lang, REQUEST, RESPONSE)
 
-###################################################################################################
+################################################################################
