@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # zmstable.py
 #
 # $Id: zmstable.py,v 1.6 2004/11/23 23:04:51 zmsdev Exp $
@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
 from Globals import HTMLFile
@@ -33,18 +33,18 @@ import _globals
 import _metadata
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   constructor ZMSTable:
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 manage_addZMSTableForm = HTMLFile('manage_addzmstableform', globals()) 
-def manage_addZMSTable(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
+def manage_addZMSTable(self, lang, _sort_id, REQUEST, RESPONSE):
   """ manage_addZMSTable """
   
-  if REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
+  if REQUEST['btn'] == self.getZMILangStr('BTN_INSERT'):
     
     ##### Create ####
     id_prefix = _globals.id_prefix(REQUEST.get('id','e'))
@@ -151,20 +151,20 @@ def manage_addZMSTable(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
     ##### Normalize Sort-IDs ####
     self.normalizeSortIds(id_prefix)
     
-    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
-    RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,manage_lang,urllib.quote(message)))
+    message = self.getZMILangStr('MSG_INSERTED')%obj.display_type(REQUEST)
+    RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,urllib.quote(message)))
   
   else:
-    RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s'%(self.absolute_url(),lang,manage_lang))
+    RESPONSE.redirect('%s/manage_main?lang=%s'%(self.absolute_url(),lang))
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###   
 ###   class ZMSTable:
 ###   
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class ZMSTable(ZMSObject, _metadata.Metadata):
 
     # Properties.
@@ -185,15 +185,15 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
     # Management Permissions.
     # -----------------------
     __authorPermissions__ = (
-                'manage','manage_main','manage_workspace',
-                'manage_properties', 'manage_changeProperties',
-                'manage_moveObjUp','manage_moveObjDown',
-                'manage_cutObjects','manage_copyObjects','manage_pasteObjs',
+		'manage','manage_main','manage_workspace',
+		'manage_changeProperties',
+		'manage_moveObjUp','manage_moveObjDown',
+		'manage_cutObjects','manage_copyObjects','manage_pasteObjs',
 		'manage_userForm','manage_user',
-                )
+		)
     __ac_permissions__=(
-                ('ZMS Author', __authorPermissions__),
-                )
+		('ZMS Author', __authorPermissions__),
+		)
 
     # Properties.
     # -----------
@@ -216,7 +216,7 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
         'cols':{'datatype':'int' ,'multilang':True},
         'table':{'datatype':'list' ,'multilang':True},
         'caption':{'datatype':'string' ,'multilang':True},
-        'align':{'datatype':'string', 'type':'select','default':'TOP','options':['TOP','TOP','BOTTOM','BOTTOM','LEFT','LEFT','RIGHT','RIGHT']},
+        'align':{'datatype':'string', 'type':'select','default':'TOP','options':['TOP','TOP','BOTTOM','BOTTOM','LEFT','LEFT','RIGHT','RIGHT'], 'mandatory': True},
         # Meta-Data
         'attr_dc_coverage':{'datatype':'string'},
         # Meta-Dictionaries        
@@ -226,21 +226,21 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
 
     # Management Interface
     # ---------------------
-    manage_main = manage_properties = HTMLFile('dtml/zmstable/manage_main', globals()) 
+    manage_main = HTMLFile('dtml/zmstable/manage_main', globals()) 
     table_cell_edit_html = HTMLFile('dtml/zmstable/table_cell_edit', globals())
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     #
     #   CONSTRUCTOR
     #
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSTable.getSpanOptions:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getSpanOptions(self, i, n):
       options = []
       for o in range(1, n-i+1):
@@ -249,25 +249,25 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   P r o p e r t i e s
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSTable.manage_changeProperties: 
     #
     #  Change Table properties.
-    ###############################################################################################
-    def manage_changeProperties(self, lang, manage_lang, REQUEST, RESPONSE): 
+    ############################################################################
+    def manage_changeProperties(self, lang, REQUEST, RESPONSE): 
         """ ZMSTable.manage_changeProperties """
         
         self._checkWebDAVLock()
         message = ''
         if len(REQUEST.get('function','')) > 0 or \
-           REQUEST.get('btn','') not in [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]:
+           REQUEST.get('btn','') not in [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]:
         
           ##### Object State #####
           self.setObjStateModified(REQUEST)
@@ -285,7 +285,7 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
           self.setReqProperty('align',REQUEST)
 
           ##### Metadata ####
-          self.setMetadata(lang,manage_lang,REQUEST)
+          self.setMetadata(lang,REQUEST)
         
           table = self.getTable( REQUEST)
 
@@ -329,59 +329,59 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
           self.onChangeObj(REQUEST)
           
           ##### Message #####
-          message = self.getLangStr('MSG_CHANGED',manage_lang)
+          message = self.getZMILangStr('MSG_CHANGED')
           
           if (REQUEST.has_key('function') and len(REQUEST['function'])>0):
-            return RESPONSE.redirect('manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(lang,manage_lang,urllib.quote(message)))
+            return RESPONSE.redirect('manage_main?lang=%s&manage_tabs_message=%s'%(lang,urllib.quote(message)))
         
         # Return with message.
         self.checkIn(REQUEST)
-        return RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.getParentNode().absolute_url(),lang,manage_lang,urllib.quote(message),self.id))
+        return RESPONSE.redirect('%s/manage_main?lang=%s&manage_tabs_message=%s#_%s'%(self.getParentNode().absolute_url(),lang,urllib.quote(message),self.id))
 
 
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTable.isPageElement:
-    # -------------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isPageElement(self): 
       return True
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTable.getTitlealt
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitlealt(self,REQUEST): 
       return self.display_type(REQUEST)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTable.getTable
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTable(self, REQUEST): 
       table = self.getObjProperty('table',REQUEST)
       return table
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTable.getRow
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getRow(self, rownum, REQUEST): 
       table = self.getTable( REQUEST)
       row = table[ rownum]
       return row
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTable.getCell
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getCell(self, rownum, colnum, REQUEST): 
       row = self.getRow( rownum, REQUEST)
       cell = row[ colnum]
       return cell
 
 
-    ###############################################################################################    
+    ############################################################################    
     # Column
-    ###############################################################################################    
+    ############################################################################    
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSTable.insert_col:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def insert_col(self, table, colnum, lang, REQUEST):
       type = self.getObjProperty('type',REQUEST)
       rownum = 0
@@ -402,9 +402,9 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
         cell = table[0][0]
         cell['colspan'] = cols
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSTable.delete_col:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def delete_col(self, table, colnum, lang, REQUEST):
       type = self.getObjProperty('type',REQUEST)
       rownum = 0
@@ -420,11 +420,11 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
         cell = table[0][0]
         cell['colspan'] = cols
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSTable.move_col:
     #
     #	Move column left or right.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def move_col(self, table, colnum, direction, lang, REQUEST):
       rownum = 0
       for oRow in table:
@@ -437,13 +437,13 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
         rownum = rownum + 1
 
 
-    ###############################################################################################    
+    ############################################################################    
     # Row
-    ###############################################################################################    
+    ############################################################################    
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSTable.insert_row:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def insert_row(self, table, rownum, lang, REQUEST):
       # increase number of rows
       self.setObjProperty('rows',self.getObjProperty('rows',REQUEST)+1,lang)
@@ -462,20 +462,20 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
       # insert new row
       table.insert(rownum,row)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSTable.delete_row:
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def delete_row(self, table, rownum, lang, REQUEST):
       # decrease number of rows
       self.setObjProperty('rows',self.getObjProperty('rows',REQUEST)-1,lang)
       # remove row
       table.remove(table[rownum])
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSTable.move_row:
     #
     #	Move row up or down.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def move_row(self, table, rownum, direction, lang, REQUEST):
       row1 = copy.deepcopy(table[rownum+direction])
       row2 = copy.deepcopy(table[rownum])
@@ -484,18 +484,18 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###  H T M L - P r e s e n t a t i o n 
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTable.getBodyContent:
     #         
     #  HTML presentation of Table. 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _getBodyContent(self, REQUEST):
       type = self.getObjProperty('type',REQUEST)
       table = self.getObjProperty('table',REQUEST)
@@ -584,20 +584,20 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
       return ''.join(s)
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTable.renderShort:
     #
     #  Renders short presentation of Table.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def renderShort(self,REQUEST):
       return self._getBodyContent(REQUEST)
 
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTable.catalogText:
     #
     #  Catalog text of Table (overwrite method from ZCatalogItem).
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def catalogText(self, REQUEST):
       s = ''
       if self.isVisible(REQUEST):
@@ -609,18 +609,18 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     #
     #   C e l l 
     #
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTable.__init_cell__:
     #
     #  Initialise table-cell.
-    # ------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def __init_cell__(self, tag='', colspan=1, content=''):
       cell = {}
       cell['tag'] = tag
@@ -629,5 +629,4 @@ class ZMSTable(ZMSObject, _metadata.Metadata):
       cell['format'] = self.getTextFormatDefault()
       return cell
 
-###################################################################################################
-
+################################################################################
