@@ -1,4 +1,4 @@
-###################################################################################################
+################################################################################
 # zmstextarea.py
 #
 # $Id: zmstextarea.py,v 1.6 2004/11/23 23:19:31 zmsdev Exp $
@@ -21,10 +21,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-###################################################################################################
+################################################################################
 
 # Imports.
-from Globals import HTML, HTMLFile
+from Globals import HTMLFile
+import sys
 import time
 import urllib
 # Product Imports.
@@ -33,19 +34,19 @@ import _globals
 import _metadata
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   Constructor(s)
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 
 manage_addZMSTextareaForm = HTMLFile('manage_addzmstextareaform', globals()) 
-def manage_addZMSTextarea(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
+def manage_addZMSTextarea(self, lang, _sort_id, REQUEST, RESPONSE):
   """ manage_addZMSTextarea """
     
-  if REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
+  if REQUEST['btn'] == self.getZMILangStr('BTN_INSERT'):
     
     ##### Create ####
     id_prefix = _globals.id_prefix(REQUEST.get('id','e'))
@@ -62,7 +63,7 @@ def manage_addZMSTextarea(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
     else:
       obj.setObjProperty( 'attr_dc_coverage' ,'global.'+lang)
     ##### Init Properties ####
-    obj.manage_changeProperties(lang,manage_lang,REQUEST,RESPONSE)
+    obj.manage_changeProperties(lang,REQUEST,RESPONSE)
     ##### VersionManager ####
     obj.onChangeObj(REQUEST)
   
@@ -70,20 +71,20 @@ def manage_addZMSTextarea(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
     self.normalizeSortIds( id_prefix)
   
     # Return with message.
-    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
-    RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.absolute_url(),lang,manage_lang,urllib.quote(message),obj.id))
+    message = self.getZMILangStr('MSG_INSERTED')%obj.display_type(REQUEST)
+    RESPONSE.redirect('%s/manage_main?lang=%s&manage_tabs_message=%s#_%s'%(self.absolute_url(),lang,urllib.quote(message),obj.id))
                 
   else:         
-    RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s'%(self.absolute_url(),lang,manage_lang))
+    RESPONSE.redirect('%s/manage_main?lang=%s'%(self.absolute_url(),lang))
 
 
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 ###
 ###   Class
 ###
-###################################################################################################
-###################################################################################################
+################################################################################
+################################################################################
 class ZMSTextarea(ZMSObject, _metadata.Metadata):
 
     # Properties.
@@ -146,70 +147,80 @@ class ZMSTextarea(ZMSObject, _metadata.Metadata):
 
 
     """
-    ###############################################################################################    
+    ############################################################################    
     ###
     ###   Properties
     ###
-    ###############################################################################################    
+    ############################################################################    
     """
 
-    ###############################################################################################
+    ############################################################################
     #  ZMSTextarea.manage_changeProperties: 
     #
     #  Change Textarea properties.
-    ###############################################################################################
-    def manage_changeProperties(self, lang, manage_lang, REQUEST, RESPONSE): 
+    ############################################################################
+    def manage_changeProperties(self, lang, REQUEST, RESPONSE): 
       """ ZMSTextarea.manage_changeProperties """
       
       self._checkWebDAVLock()
       message = ''
+      messagekey = 'manage_tabs_message'
       t0 = time.time()
       
       target_ob = self.getParentNode()
       if REQUEST.get( 'btn', '') == '':
         target_ob = self
       target = REQUEST.get( 'target', '%s/manage_main'%target_ob.absolute_url())
-
-      if REQUEST.get('btn','') not in  [ self.getLangStr('BTN_CANCEL',manage_lang), self.getLangStr('BTN_BACK',manage_lang)]:
+      
+      if REQUEST.get('btn','') not in  [ self.getZMILangStr('BTN_CANCEL'), self.getZMILangStr('BTN_BACK')]:
+        try:
         
-        ##### Object State ####
-        self.setObjStateModified(REQUEST)
+          ##### Object State ####
+          self.setObjStateModified(REQUEST)
+          
+          ##### Properties ####
+          # Metadata.
+          self.setMetadata(lang,REQUEST)
+          # Attributes.
+          for key in self.getObjAttrs().keys():
+            self.setReqProperty(key,REQUEST)
+          
+          ##### VersionManager ####
+          self.onChangeObj(REQUEST)
+          
+          ##### Message ####
+          message = self.getZMILangStr('MSG_CHANGED')
         
-        ##### Properties ####
-        # Metadata.
-        self.setMetadata(lang,manage_lang,REQUEST)
-        # Attributes.
-        for key in self.getObjAttrs().keys():
-          self.setReqProperty(key,REQUEST)
+        except:
+          type, val, tb = sys.exc_info()
+          message = '<b>Error-Type:</b> '+type+'<br/><b>Error-Value:</b> '+val+'<br/>'
+          messagekey = 'manage_tabs_error_message'
+          _globals.writeException(self,"[manage_changeProperties]")
         
-        ##### VersionManager ####
-        self.onChangeObj(REQUEST)
-        
-        ##### Message ####
-        message = self.getLangStr('MSG_CHANGED',manage_lang) + ' (in '+str(int((time.time()-t0)*100.0)/100.0)+' secs.)'
+        message = message + ' (in '+str(int((time.time()-t0)*100.0)/100.0)+' secs.)'
       
       # Return with message.
       self.checkIn(REQUEST)
-      target = self.url_append_params( target, { 'lang': lang, 'manage_lang': manage_lang, 'preview': 'preview', 'manage_tabs_message': message})
+      target = self.url_append_params( target, { 'lang': lang, 'preview': 'preview',  messagekey: message})
       target = '%s#_%s'%( target, self.id)
       return RESPONSE.redirect( target)
 
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTextarea.isPageElement
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def isPageElement(self):
       return True
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTextarea.getTitlealt
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getTitlealt(self,REQUEST): 
       return self.display_type(REQUEST)
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTextarea.getText
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getText(self,REQUEST): 
       text = self.getObjProperty('text',REQUEST)
       # Number headlines
@@ -218,9 +229,9 @@ class ZMSTextarea(ZMSObject, _metadata.Metadata):
         text = levelnfc + ' ' + text
       return text
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTextarea.getFormat
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def getFormat(self,REQUEST):
       format = self.getObjProperty('format',REQUEST)
       if format is None or len(format) == 0:
@@ -229,39 +240,47 @@ class ZMSTextarea(ZMSObject, _metadata.Metadata):
 
 
     """
-    ###############################################################################################
+    ############################################################################
     ###
     ###  Presentation 
     ###
-    ###############################################################################################
+    ############################################################################
     """
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  ZMSTextarea.getLevelnfc
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _getLevelnfc(self, REQUEST):
-      s = ''
-      textformat = self.getFormat(REQUEST)
-      if textformat.find('headline')==0:
-        parent = self.getParentNode()
-        levelnfc = parent.getObjProperty('levelnfc',REQUEST)
-        if len(levelnfc) > 0:
-          s = parent._getLevelnfc(REQUEST)
-          sectionizer = _globals.MySectionizer()
-          for sibling in parent.filteredChildNodes(REQUEST,['ZMSTextarea']):
-            textformat = sibling.getFormat(REQUEST)
-            if textformat.find('headline')==0:
-              level = int(textformat[len(_globals.id_prefix(textformat)):])-1
-              sectionizer.processLevel(level)
-              if self == sibling:
-                s += str(sectionizer)
-      return s
+      #-- [ReqBuff]: Fetch buffered value from Http-Request.
+      parent = self.getParentNode()
+      reqBuffId = '_getLevelnfc'
+      try:
+        s = parent.fetchReqBuff( '%s_%s'%(reqBuffId,self.id), REQUEST, forced=True)
+        return s
+      except:
+        s = ''
+        textformat = self.getFormat(REQUEST)
+        if textformat.find('headline') == 0:
+          levelnfc = parent.getObjProperty('levelnfc',REQUEST)
+          if len(levelnfc) > 0:
+            parent_levelnfc = parent._getLevelnfc(REQUEST)
+            sectionizer = _globals.MySectionizer()
+            for sibling in parent.filteredChildNodes(REQUEST,['ZMSTextarea']):
+              textformat = sibling.getFormat(REQUEST)
+              if textformat.find('headline')==0:
+                level = int(textformat[len(_globals.id_prefix(textformat)):])-1
+                sectionizer.processLevel(level)
+                parent.storeReqBuff( '%s_%s'%(reqBuffId,sibling.id), parent_levelnfc + str(sectionizer), REQUEST)
+                if self == sibling:
+                  s = parent_levelnfc + str(sectionizer)
+        #-- [ReqBuff]: Returns value and stores it in buffer of Http-Request.
+        return s
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSTextarea._getBodyContent:
     #
     #	HTML presentation of Textarea. 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def _getBodyContent(self, REQUEST):
       # Retrieve properties.
       text = self.getText(REQUEST)
@@ -273,12 +292,12 @@ class ZMSTextarea(ZMSObject, _metadata.Metadata):
       # Return body-content.
       return text
 
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #	ZMSTextarea.renderShort:
     #
     #	Renders short presentation of Textarea.
-    # ---------------------------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     def renderShort(self, REQUEST):
       return self._getBodyContent(REQUEST)
 
-###################################################################################################
+################################################################################
